<!--- app-name: Apache Superset -->

# Bitnami package for Apache Superset

Superset is a modern data exploration and data visualization platform.

[Overview of Apache Superset](https://superset.apache.org/)

Trademarks: This software listing is packaged by Bitnami. The respective trademarks mentioned in the offering are owned by the respective companies, and use of them does not imply any affiliation or endorsement.

## TL;DR

```console
helm install my-release oci://registry-1.docker.io/bitnamicharts/superset
```

Looking to use Superset in production? Try [VMware Tanzu Application Catalog](https://bitnami.com/enterprise), the enterprise edition of Bitnami Application Catalog.

## Introduction

Bitnami charts for Helm are carefully engineered, actively maintained and are the quickest and easiest way to deploy containers on a Kubernetes cluster that are ready to handle production workloads.

This chart bootstraps a [Superset](https://superset.apache.org/) Deployment in a [Kubernetes](https://kubernetes.io) cluster using the [Helm](https://helm.sh) package manager.

## Prerequisites

- Kubernetes 1.23+
- Helm 3.8.0+
- PV provisioner support in the underlying infrastructure

## Installing the Chart

To install the chart with the release name `my-release`:

```console
helm install my-release oci://REGISTRY_NAME/REPOSITORY_NAME/superset
```

> Note: You need to substitute the placeholders `REGISTRY_NAME` and `REPOSITORY_NAME` with a reference to your Helm chart registry and repository. For example, in the case of Bitnami, you need to use `REGISTRY_NAME=registry-1.docker.io` and `REPOSITORY_NAME=bitnamicharts`.

The command deploys Superset on the Kubernetes cluster in the default configuration. The [Parameters](#parameters) section lists the parameters that can be configured during installation.

> **Tip**: List all releases using `helm list`

## Configuration and installation details

### [Rolling VS Immutable tags](https://docs.vmware.com/en/VMware-Tanzu-Application-Catalog/services/tutorials/GUID-understand-rolling-tags-containers-index.html)

It is strongly recommended to use immutable tags in a production environment. This ensures your deployment does not change automatically if the same tag is updated with a different image.

Bitnami will release a new chart updating its containers if a new version of the main container, significant changes, or critical vulnerabilities exist.

### External database support

You may want to have Superset connect to an external database rather than installing one inside your cluster. Typical reasons for this are to use a managed database service, or to share a common database server for all your applications. To achieve this, the chart allows you to specify credentials for an external database with the [`externalDatabase` parameter](#parameters). You should also disable the MariaDB installation with the `postgresql.enabled` option. Here is an example:

```console
postgresql.enabled=false
externalDatabase.host=myexternalhost
externalDatabase.user=myuser
externalDatabase.password=mypassword
externalDatabase.database=mydatabase
externalDatabase.port=5432
```

Similarly, you can specify an external Redis&reg; instance rather than installing one inside your cluster. First, you may disable the Redis&reg; installation with the `redis.enabled` option. As aforementioned, used the provided parameters to provide data about your instance:

```console
redis.enabled=false
externalRedis.host=myexternalhost
externalRedis.password=mypassword
externalRedis.port=5432
```

### Ingress

This chart provides support for Ingress resources. If you have an ingress controller installed on your cluster, such as [nginx-ingress-controller](https://github.com/bitnami/charts/tree/main/bitnami/nginx-ingress-controller) or [contour](https://github.com/bitnami/charts/tree/main/bitnami/contour) you can utilize the ingress controller to serve your application.To enable Ingress integration, set `ingress.enabled` to `true`.

The most common scenario is to have one host name mapped to the deployment. In this case, the `ingress.hostname` property can be used to set the host name. The `ingress.tls` parameter can be used to add the TLS configuration for this host.

However, it is also possible to have more than one host. To facilitate this, the `ingress.extraHosts` parameter (if available) can be set with the host names specified as an array. The `ingress.extraTLS` parameter (if available) can also be used to add the TLS configuration for extra hosts.

> NOTE: For each host specified in the `ingress.extraHosts` parameter, it is necessary to set a name, path, and any annotations that the Ingress controller should know about. Not all annotations are supported by all Ingress controllers, but [this annotation reference document](https://github.com/kubernetes/ingress-nginx/blob/master/docs/user-guide/nginx-configuration/annotations.md) lists the annotations supported by many popular Ingress controllers.

Adding the TLS parameter (where available) will cause the chart to generate HTTPS URLs, and the  application will be available on port 443. The actual TLS secrets do not have to be generated by this chart. However, if TLS is enabled, the Ingress record will not work until the TLS secret exists.

[Learn more about Ingress controllers](https://kubernetes.io/docs/concepts/services-networking/ingress-controllers/).

### Additional environment variables

In case you want to add extra environment variables (useful for advanced operations like custom init scripts), you can use the `extraEnvVars` property.

```yaml
web:
  extraEnvVars:
    - name: LOG_LEVEL
      value: error
```

Alternatively, you can use a ConfigMap or a Secret with the environment variables. To do so, use the `extraEnvVarsCM` or the `extraEnvVarsSecret` values.

### Sidecars

If additional containers are needed in the same pod as Superset (such as additional metrics or logging exporters), they can be defined using the `*.sidecars` parameter, where `*` would be the section corresponding to each of the pods deployed by the chart, e.g. `web`, `worker`, `beat`, `flower`, `init`.

```yaml
web:
  sidecars:
    - name: your-image-name
      image: your-image
      imagePullPolicy: Always
      ports:
        - name: portname
      containerPort: 1234
```

If these sidecars export extra ports, extra port definitions can be added using the `service.*.extraPorts` parameter (where available), as shown in the example below:

```yaml
web:
  service:
    extraPorts:
      - name: extraPort
        port: 11311
        targetPort: 11311
```

If additional init containers are needed in the same pod, they can be defined using the `*.initContainers` parameter. Here is an example adding an extra init container to the Superset `web` pods:

```yaml
web:
  initContainers:
    - name: your-image-name
      image: your-image
      imagePullPolicy: Always
      ports:
        - name: portname
          containerPort: 1234
```

Learn more about [sidecar containers](https://kubernetes.io/docs/concepts/workloads/pods/) and [init containers](https://kubernetes.io/docs/concepts/workloads/pods/init-containers/).

### Pod affinity

This chart allows you to set your custom affinity using the `affinity` parameter. Find more information about Pod affinity in the [kubernetes documentation](https://kubernetes.io/docs/concepts/configuration/assign-pod-node/#affinity-and-anti-affinity).

As an alternative, use one of the preset configurations for pod affinity, pod anti-affinity, and node affinity available at the [bitnami/common](https://github.com/bitnami/charts/tree/main/bitnami/common#affinities) chart. To do so, set the `podAffinityPreset`, `podAntiAffinityPreset`, or `nodeAffinityPreset` parameters.

## Parameters

### Global parameters

| Name                                                  | Description                                                                                                                                                                                                                                                                                                                                                         | Value  |
| ----------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------ |
| `global.imageRegistry`                                | Global Docker image registry                                                                                                                                                                                                                                                                                                                                        | `""`   |
| `global.imagePullSecrets`                             | Global Docker registry secret names as an array                                                                                                                                                                                                                                                                                                                     | `[]`   |
| `global.storageClass`                                 | Global StorageClass for Persistent Volume(s)                                                                                                                                                                                                                                                                                                                        | `""`   |
| `global.compatibility.openshift.adaptSecurityContext` | Adapt the securityContext sections of the deployment to make them compatible with Openshift restricted-v2 SCC: remove runAsUser, runAsGroup and fsGroup and let the platform use their allowed default IDs. Possible values: auto (apply if the detected running cluster is Openshift), force (perform the adaptation always), disabled (do not perform adaptation) | `auto` |

### Common parameters

| Name                     | Description                                                                             | Value           |
| ------------------------ | --------------------------------------------------------------------------------------- | --------------- |
| `kubeVersion`            | Override Kubernetes version                                                             | `""`            |
| `apiVersions`            | Override Kubernetes API versions reported by .Capabilities                              | `[]`            |
| `nameOverride`           | String to partially override common.names.name                                          | `""`            |
| `fullnameOverride`       | String to fully override common.names.fullname                                          | `""`            |
| `namespaceOverride`      | String to fully override common.names.namespace                                         | `""`            |
| `commonLabels`           | Labels to add to all deployed objects                                                   | `{}`            |
| `commonAnnotations`      | Annotations to add to all deployed objects                                              | `{}`            |
| `clusterDomain`          | Kubernetes cluster domain name                                                          | `cluster.local` |
| `extraDeploy`            | Array of extra objects to deploy with the release                                       | `[]`            |
| `usePasswordFiles`       | Mount credentials as files instead of using an environment variable                     | `true`          |
| `diagnosticMode.enabled` | Enable diagnostic mode (all probes will be disabled and the command will be overridden) | `false`         |
| `diagnosticMode.command` | Command to override all containers in the chart release                                 | `["sleep"]`     |
| `diagnosticMode.args`    | Args to override all containers in the chart release                                    | `["infinity"]`  |

### Superset Parameters

| Name                                                                    | Description                                                                                                                                                                                                                                     | Value                      |
| ----------------------------------------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | -------------------------- |
| `image.registry`                                                        | Superset image registry                                                                                                                                                                                                                         | `REGISTRY_NAME`            |
| `image.repository`                                                      | Superset image repository                                                                                                                                                                                                                       | `REPOSITORY_NAME/superset` |
| `image.digest`                                                          | Superset image digest in the way sha256:aa.... Please note this parameter, if set, will override the tag image tag (immutable tags are recommended)                                                                                             | `""`                       |
| `image.pullPolicy`                                                      | Superset image pull policy                                                                                                                                                                                                                      | `IfNotPresent`             |
| `image.pullSecrets`                                                     | Superset image pull secrets                                                                                                                                                                                                                     | `[]`                       |
| `image.debug`                                                           | Enable Superset image debug mode                                                                                                                                                                                                                | `false`                    |
| `config`                                                                | The name of an existing ConfigMap with your custom configuration for Superset                                                                                                                                                                   | `""`                       |
| `existingConfigmap`                                                     | The name of an existing ConfigMap with your custom configuration for Superset                                                                                                                                                                   | `""`                       |
| `loadExamples`                                                          | If set to true, the Superset examples database will be loaded at startup                                                                                                                                                                        | `false`                    |
| `auth.username`                                                         | Username to access web UI                                                                                                                                                                                                                       | `""`                       |
| `auth.email`                                                            | Username email                                                                                                                                                                                                                                  | `""`                       |
| `auth.password`                                                         | Password to access web UI                                                                                                                                                                                                                       | `""`                       |
| `auth.secretKey`                                                        | Secret key to run your flask app                                                                                                                                                                                                                | `""`                       |
| `auth.existingSecret`                                                   | Name of an existing secret to use for Superset credentials                                                                                                                                                                                      | `""`                       |
| `web.replicaCount`                                                      | Number of Superset webserver replicas to deploy                                                                                                                                                                                                 | `1`                        |
| `web.containerPorts.http`                                               | Superset webserver HTTP container port                                                                                                                                                                                                          | `8080`                     |
| `web.extraContainerPorts`                                               | Optionally specify extra list of additional ports for WordPress container(s)                                                                                                                                                                    | `[]`                       |
| `web.livenessProbe.enabled`                                             | Enable livenessProbe on Superset webserver containers                                                                                                                                                                                           | `false`                    |
| `web.livenessProbe.initialDelaySeconds`                                 | Initial delay seconds for livenessProbe                                                                                                                                                                                                         | `15`                       |
| `web.livenessProbe.periodSeconds`                                       | Period seconds for livenessProbe                                                                                                                                                                                                                | `15`                       |
| `web.livenessProbe.timeoutSeconds`                                      | Timeout seconds for livenessProbe                                                                                                                                                                                                               | `1`                        |
| `web.livenessProbe.failureThreshold`                                    | Failure threshold for livenessProbe                                                                                                                                                                                                             | `3`                        |
| `web.livenessProbe.successThreshold`                                    | Success threshold for livenessProbe                                                                                                                                                                                                             | `1`                        |
| `web.readinessProbe.enabled`                                            | Enable readinessProbe on Superset webserver containers                                                                                                                                                                                          | `true`                     |
| `web.readinessProbe.initialDelaySeconds`                                | Initial delay seconds for readinessProbe                                                                                                                                                                                                        | `15`                       |
| `web.readinessProbe.periodSeconds`                                      | Period seconds for readinessProbe                                                                                                                                                                                                               | `15`                       |
| `web.readinessProbe.timeoutSeconds`                                     | Timeout seconds for readinessProbe                                                                                                                                                                                                              | `1`                        |
| `web.readinessProbe.failureThreshold`                                   | Failure threshold for readinessProbe                                                                                                                                                                                                            | `3`                        |
| `web.readinessProbe.successThreshold`                                   | Success threshold for readinessProbe                                                                                                                                                                                                            | `1`                        |
| `web.startupProbe.enabled`                                              | Enable startupProbe on Superset webserver containers                                                                                                                                                                                            | `false`                    |
| `web.startupProbe.initialDelaySeconds`                                  | Initial delay seconds for startupProbe                                                                                                                                                                                                          | `15`                       |
| `web.startupProbe.periodSeconds`                                        | Period seconds for startupProbe                                                                                                                                                                                                                 | `5`                        |
| `web.startupProbe.timeoutSeconds`                                       | Timeout seconds for startupProbe                                                                                                                                                                                                                | `1`                        |
| `web.startupProbe.failureThreshold`                                     | Failure threshold for startupProbe                                                                                                                                                                                                              | `60`                       |
| `web.startupProbe.successThreshold`                                     | Success threshold for startupProbe                                                                                                                                                                                                              | `1`                        |
| `web.customLivenessProbe`                                               | Custom livenessProbe that overrides the default one                                                                                                                                                                                             | `{}`                       |
| `web.customReadinessProbe`                                              | Custom readinessProbe that overrides the default one                                                                                                                                                                                            | `{}`                       |
| `web.customStartupProbe`                                                | Custom startupProbe that overrides the default one                                                                                                                                                                                              | `{}`                       |
| `web.resourcesPreset`                                                   | Set Superset webserver container resources according to one common preset (allowed values: none, nano, small, medium, large, xlarge, 2xlarge). This is ignored if web.resources is set (web.resources is recommended for production).           | `small`                    |
| `web.resources`                                                         | Set Superset webserver container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                            | `{}`                       |
| `web.podSecurityContext.enabled`                                        | Enable Superset webserver pods' Security Context                                                                                                                                                                                                | `true`                     |
| `web.podSecurityContext.fsGroupChangePolicy`                            | Set filesystem group change policy for Superset webserver pods                                                                                                                                                                                  | `Always`                   |
| `web.podSecurityContext.sysctls`                                        | Set kernel settings using the sysctl interface for Superset webserver pods                                                                                                                                                                      | `[]`                       |
| `web.podSecurityContext.supplementalGroups`                             | Set filesystem extra groups for Superset webserver pods                                                                                                                                                                                         | `[]`                       |
| `web.podSecurityContext.fsGroup`                                        | Set fsGroup in Superset webserver pods' Security Context                                                                                                                                                                                        | `1001`                     |
| `web.containerSecurityContext.enabled`                                  | Enabled Superset webserver container' Security Context                                                                                                                                                                                          | `true`                     |
| `web.containerSecurityContext.seLinuxOptions`                           | Set SELinux options in Superset webserver container                                                                                                                                                                                             | `{}`                       |
| `web.containerSecurityContext.runAsUser`                                | Set runAsUser in Superset webserver container' Security Context                                                                                                                                                                                 | `1001`                     |
| `web.containerSecurityContext.runAsGroup`                               | Set runAsGroup in Superset webserver container' Security Context                                                                                                                                                                                | `1001`                     |
| `web.containerSecurityContext.runAsNonRoot`                             | Set runAsNonRoot in Superset webserver container' Security Context                                                                                                                                                                              | `true`                     |
| `web.containerSecurityContext.readOnlyRootFilesystem`                   | Set readOnlyRootFilesystem in Superset webserver container' Security Context                                                                                                                                                                    | `false`                    |
| `web.containerSecurityContext.privileged`                               | Set privileged in Superset webserver container' Security Context                                                                                                                                                                                | `false`                    |
| `web.containerSecurityContext.allowPrivilegeEscalation`                 | Set allowPrivilegeEscalation in Superset webserver container' Security Context                                                                                                                                                                  | `false`                    |
| `web.containerSecurityContext.capabilities.drop`                        | List of capabilities to be dropped in Superset webserver container                                                                                                                                                                              | `["ALL"]`                  |
| `web.containerSecurityContext.seccompProfile.type`                      | Set seccomp profile in Superset webserver container                                                                                                                                                                                             | `RuntimeDefault`           |
| `web.command`                                                           | Override default Superset webserver container command (useful when using custom images)                                                                                                                                                         | `[]`                       |
| `web.args`                                                              | Override default Superset webserver container args (useful when using custom images)                                                                                                                                                            | `[]`                       |
| `web.automountServiceAccountToken`                                      | Mount Service Account token in Superset webserver pods                                                                                                                                                                                          | `false`                    |
| `web.hostAliases`                                                       | Superset webserver pods host aliases                                                                                                                                                                                                            | `[]`                       |
| `web.deploymentAnnotations`                                             | Annotations for Superset webserver deployment                                                                                                                                                                                                   | `{}`                       |
| `web.podLabels`                                                         | Extra labels for Superset webserver pods                                                                                                                                                                                                        | `{}`                       |
| `web.podAnnotations`                                                    | Annotations for Superset webserver pods                                                                                                                                                                                                         | `{}`                       |
| `web.podAffinityPreset`                                                 | Pod affinity preset. Ignored if `web.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                         | `""`                       |
| `web.podAntiAffinityPreset`                                             | Pod anti-affinity preset. Ignored if `web.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                    | `soft`                     |
| `web.nodeAffinityPreset.type`                                           | Node affinity preset type. Ignored if `web.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                   | `""`                       |
| `web.nodeAffinityPreset.key`                                            | Node label key to match. Ignored if `web.affinity` is set                                                                                                                                                                                       | `""`                       |
| `web.nodeAffinityPreset.values`                                         | Node label values to match. Ignored if `web.affinity` is set                                                                                                                                                                                    | `[]`                       |
| `web.affinity`                                                          | Affinity for Superset webserver pods assignment                                                                                                                                                                                                 | `{}`                       |
| `web.nodeSelector`                                                      | Node labels for Superset webserver pods assignment                                                                                                                                                                                              | `{}`                       |
| `web.tolerations`                                                       | Tolerations for Superset webserver pods assignment                                                                                                                                                                                              | `[]`                       |
| `web.updateStrategy.type`                                               | Superset webserver deployment strategy type                                                                                                                                                                                                     | `RollingUpdate`            |
| `web.priorityClassName`                                                 | Superset webserver pods' priorityClassName                                                                                                                                                                                                      | `""`                       |
| `web.topologySpreadConstraints`                                         | Topology Spread Constraints for Superset webserver pod assignment spread across your cluster among failure-domains                                                                                                                              | `[]`                       |
| `web.schedulerName`                                                     | Name of the k8s scheduler (other than default) for Superset webserver pods                                                                                                                                                                      | `""`                       |
| `web.terminationGracePeriodSeconds`                                     | Seconds Superset webserver pods need to terminate gracefully                                                                                                                                                                                    | `""`                       |
| `web.lifecycleHooks`                                                    | for Superset webserver containers to automate configuration before or after startup                                                                                                                                                             | `{}`                       |
| `web.extraEnvVars`                                                      | Array with extra environment variables to add to Superset webserver containers                                                                                                                                                                  | `[]`                       |
| `web.extraEnvVarsCM`                                                    | Name of existing ConfigMap containing extra env vars for Superset webserver containers                                                                                                                                                          | `""`                       |
| `web.extraEnvVarsSecret`                                                | Name of existing Secret containing extra env vars for Superset webserver containers                                                                                                                                                             | `""`                       |
| `web.extraVolumes`                                                      | Optionally specify extra list of additional volumes for the Superset webserver pods                                                                                                                                                             | `[]`                       |
| `web.extraVolumeMounts`                                                 | Optionally specify extra list of additional volumeMounts for the Superset webserver containers                                                                                                                                                  | `[]`                       |
| `web.sidecars`                                                          | Add additional sidecar containers to the Superset webserver pods                                                                                                                                                                                | `[]`                       |
| `web.initContainers`                                                    | Add additional init containers to the Superset webserver pods                                                                                                                                                                                   | `[]`                       |
| `web.pdb.create`                                                        | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                                 | `false`                    |
| `web.pdb.minAvailable`                                                  | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                                  | `1`                        |
| `web.pdb.maxUnavailable`                                                | Maximum number/percentage of pods that may be made unavailable                                                                                                                                                                                  | `""`                       |
| `web.autoscaling.vpa.enabled`                                           | Enable VPA                                                                                                                                                                                                                                      | `false`                    |
| `web.autoscaling.vpa.annotations`                                       | Annotations for VPA resource                                                                                                                                                                                                                    | `{}`                       |
| `web.autoscaling.vpa.controlledResources`                               | VPA List of resources that the vertical pod autoscaler can control. Defaults to cpu and memory                                                                                                                                                  | `[]`                       |
| `web.autoscaling.vpa.maxAllowed`                                        | VPA Max allowed resources for the pod                                                                                                                                                                                                           | `{}`                       |
| `web.autoscaling.vpa.minAllowed`                                        | VPA Min allowed resources for the pod                                                                                                                                                                                                           | `{}`                       |
| `web.autoscaling.vpa.updatePolicy.updateMode`                           | Autoscaling update policy Specifies whether recommended updates are applied when a Pod is started and whether recommended updates are applied during the life of a Pod                                                                          | `Auto`                     |
| `web.autoscaling.hpa.enabled`                                           | Enable HPA                                                                                                                                                                                                                                      | `false`                    |
| `web.autoscaling.hpa.minReplicas`                                       | Minimum number of replicas                                                                                                                                                                                                                      | `""`                       |
| `web.autoscaling.hpa.maxReplicas`                                       | Maximum number of replicas                                                                                                                                                                                                                      | `""`                       |
| `web.autoscaling.hpa.targetCPU`                                         | Target CPU utilization percentage                                                                                                                                                                                                               | `""`                       |
| `web.autoscaling.hpa.targetMemory`                                      | Target Memory utilization percentage                                                                                                                                                                                                            | `""`                       |
| `web.service.type`                                                      | Superset webserver service type                                                                                                                                                                                                                 | `LoadBalancer`             |
| `web.service.ports.http`                                                | Superset webserver service HTTP port                                                                                                                                                                                                            | `80`                       |
| `web.service.nodePorts.http`                                            | Node port for HTTP                                                                                                                                                                                                                              | `""`                       |
| `web.service.clusterIP`                                                 | Superset webserver service Cluster IP                                                                                                                                                                                                           | `""`                       |
| `web.service.loadBalancerIP`                                            | Superset webserver service Load Balancer IP                                                                                                                                                                                                     | `""`                       |
| `web.service.loadBalancerSourceRanges`                                  | Superset webserver service Load Balancer sources                                                                                                                                                                                                | `[]`                       |
| `web.service.externalTrafficPolicy`                                     | Superset webserver service external traffic policy                                                                                                                                                                                              | `Cluster`                  |
| `web.service.annotations`                                               | Additional custom annotations for Superset webserver service                                                                                                                                                                                    | `{}`                       |
| `web.service.extraPorts`                                                | Extra ports to expose in Superset webserver service (normally used with the `sidecars` value)                                                                                                                                                   | `[]`                       |
| `web.service.sessionAffinity`                                           | Control where client requests go, to the same pod or round-robin                                                                                                                                                                                | `None`                     |
| `web.service.sessionAffinityConfig`                                     | Additional settings for the sessionAffinity                                                                                                                                                                                                     | `{}`                       |
| `web.networkPolicy.enabled`                                             | Specifies whether a NetworkPolicy should be created                                                                                                                                                                                             | `true`                     |
| `web.networkPolicy.allowExternal`                                       | Don't require server label for connections                                                                                                                                                                                                      | `true`                     |
| `web.networkPolicy.allowExternalEgress`                                 | Allow the pod to access any range of port and all destinations.                                                                                                                                                                                 | `true`                     |
| `web.networkPolicy.addExternalClientAccess`                             | Allow access from pods with client label set to "true". Ignored if `networkPolicy.allowExternal` is true.                                                                                                                                       | `true`                     |
| `web.networkPolicy.extraIngress`                                        | Add extra ingress rules to the NetworkPolicy                                                                                                                                                                                                    | `[]`                       |
| `web.networkPolicy.extraEgress`                                         | Add extra ingress rules to the NetworkPolicy (ignored if allowExternalEgress=true)                                                                                                                                                              | `[]`                       |
| `web.networkPolicy.ingressPodMatchLabels`                               | Labels to match to allow traffic from other pods. Ignored if `networkPolicy.allowExternal` is true.                                                                                                                                             | `{}`                       |
| `web.networkPolicy.ingressNSMatchLabels`                                | Labels to match to allow traffic from other namespaces                                                                                                                                                                                          | `{}`                       |
| `web.networkPolicy.ingressNSPodMatchLabels`                             | Pod labels to match to allow traffic from other namespaces                                                                                                                                                                                      | `{}`                       |
| `web.waitForExamples.enabled`                                           | Enable init container that waits for the load_examples command to finish before starting the webserver                                                                                                                                          | `false`                    |
| `web.waitForExamples.resourcesPreset`                                   | Set init container resources according to one common preset (allowed values: none, nano, small, medium, large, xlarge, 2xlarge). This is ignored if waitForExamples.resources is set (waitForExamples.resources is recommended for production). | `nano`                     |
| `web.waitForExamples.resources`                                         | Set init container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                          | `{}`                       |
| `web.waitForExamples.containerSecurityContext.enabled`                  | Enabled wait-for-redis initcontainer's Security Context                                                                                                                                                                                         | `true`                     |
| `web.waitForExamples.containerSecurityContext.seLinuxOptions`           | Set SELinux options in wait-for-redis initcontainer                                                                                                                                                                                             | `{}`                       |
| `web.waitForExamples.containerSecurityContext.runAsUser`                | Set runAsUser in wait-for-redis initcontainer's Security Context                                                                                                                                                                                | `1001`                     |
| `web.waitForExamples.containerSecurityContext.runAsGroup`               | Set runAsGroup in wait-for-redis initcontainer's Security Context                                                                                                                                                                               | `1001`                     |
| `web.waitForExamples.containerSecurityContext.runAsNonRoot`             | Set runAsNonRoot in wait-for-redis initcontainer's Security Context                                                                                                                                                                             | `true`                     |
| `web.waitForExamples.containerSecurityContext.readOnlyRootFilesystem`   | Set readOnlyRootFilesystem in wait-for-redis initcontainer's Security Context                                                                                                                                                                   | `false`                    |
| `web.waitForExamples.containerSecurityContext.privileged`               | Set privileged in wait-for-redis initcontainer's Security Context                                                                                                                                                                               | `false`                    |
| `web.waitForExamples.containerSecurityContext.allowPrivilegeEscalation` | Set allowPrivilegeEscalation in wait-for-redis initcontainer's Security Context                                                                                                                                                                 | `false`                    |
| `web.waitForExamples.containerSecurityContext.capabilities.drop`        | List of capabilities to be dropped in wait-for-redis initcontainer                                                                                                                                                                              | `["ALL"]`                  |
| `web.waitForExamples.containerSecurityContext.seccompProfile.type`      | Set seccomp profile in wait-for-redis initcontainer                                                                                                                                                                                             | `RuntimeDefault`           |
| `worker.replicaCount`                                                   | Number of Superset Celery worker replicas to deploy                                                                                                                                                                                             | `1`                        |
| `worker.livenessProbe.enabled`                                          | Enable livenessProbe on Superset Celery worker containers                                                                                                                                                                                       | `true`                     |
| `worker.livenessProbe.initialDelaySeconds`                              | Initial delay seconds for livenessProbe                                                                                                                                                                                                         | `15`                       |
| `worker.livenessProbe.periodSeconds`                                    | Period seconds for livenessProbe                                                                                                                                                                                                                | `60`                       |
| `worker.livenessProbe.timeoutSeconds`                                   | Timeout seconds for livenessProbe                                                                                                                                                                                                               | `30`                       |
| `worker.livenessProbe.failureThreshold`                                 | Failure threshold for livenessProbe                                                                                                                                                                                                             | `3`                        |
| `worker.livenessProbe.successThreshold`                                 | Success threshold for livenessProbe                                                                                                                                                                                                             | `1`                        |
| `worker.readinessProbe.enabled`                                         | Enable readinessProbe on Superset Celery worker containers                                                                                                                                                                                      | `true`                     |
| `worker.readinessProbe.initialDelaySeconds`                             | Initial delay seconds for readinessProbe                                                                                                                                                                                                        | `15`                       |
| `worker.readinessProbe.periodSeconds`                                   | Period seconds for readinessProbe                                                                                                                                                                                                               | `60`                       |
| `worker.readinessProbe.timeoutSeconds`                                  | Timeout seconds for readinessProbe                                                                                                                                                                                                              | `30`                       |
| `worker.readinessProbe.failureThreshold`                                | Failure threshold for readinessProbe                                                                                                                                                                                                            | `3`                        |
| `worker.readinessProbe.successThreshold`                                | Success threshold for readinessProbe                                                                                                                                                                                                            | `1`                        |
| `worker.startupProbe.enabled`                                           | Enable startupProbe on Superset Celery worker containers                                                                                                                                                                                        | `false`                    |
| `worker.startupProbe.initialDelaySeconds`                               | Initial delay seconds for startupProbe                                                                                                                                                                                                          | `15`                       |
| `worker.startupProbe.periodSeconds`                                     | Period seconds for startupProbe                                                                                                                                                                                                                 | `15`                       |
| `worker.startupProbe.timeoutSeconds`                                    | Timeout seconds for startupProbe                                                                                                                                                                                                                | `30`                       |
| `worker.startupProbe.failureThreshold`                                  | Failure threshold for startupProbe                                                                                                                                                                                                              | `60`                       |
| `worker.startupProbe.successThreshold`                                  | Success threshold for startupProbe                                                                                                                                                                                                              | `1`                        |
| `worker.customLivenessProbe`                                            | Custom livenessProbe that overrides the default one                                                                                                                                                                                             | `{}`                       |
| `worker.customReadinessProbe`                                           | Custom readinessProbe that overrides the default one                                                                                                                                                                                            | `{}`                       |
| `worker.customStartupProbe`                                             | Custom startupProbe that overrides the default one                                                                                                                                                                                              | `{}`                       |
| `worker.resourcesPreset`                                                | Set Superset Celery worker container resources according to one common preset (allowed values: none, nano, small, medium, large, xlarge, 2xlarge). This is ignored if worker.resources is set (worker.resources is recommended for production). | `large`                    |
| `worker.resources`                                                      | Set Superset Celery worker container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                        | `{}`                       |
| `worker.podSecurityContext.enabled`                                     | Enable Superset Celery worker pods' Security Context                                                                                                                                                                                            | `true`                     |
| `worker.podSecurityContext.fsGroupChangePolicy`                         | Set filesystem group change policy for Superset Celery worker pods                                                                                                                                                                              | `Always`                   |
| `worker.podSecurityContext.sysctls`                                     | Set kernel settings using the sysctl interface for Superset Celery worker pods                                                                                                                                                                  | `[]`                       |
| `worker.podSecurityContext.supplementalGroups`                          | Set filesystem extra groups for Superset Celery worker pods                                                                                                                                                                                     | `[]`                       |
| `worker.podSecurityContext.fsGroup`                                     | Set fsGroup in Superset Celery worker pods' Security Context                                                                                                                                                                                    | `1001`                     |
| `worker.containerSecurityContext.enabled`                               | Enabled Superset Celery worker container' Security Context                                                                                                                                                                                      | `true`                     |
| `worker.containerSecurityContext.seLinuxOptions`                        | Set SELinux options in Superset Celery worker container                                                                                                                                                                                         | `{}`                       |
| `worker.containerSecurityContext.runAsUser`                             | Set runAsUser in Superset Celery worker container' Security Context                                                                                                                                                                             | `1001`                     |
| `worker.containerSecurityContext.runAsGroup`                            | Set runAsGroup in Superset Celery worker container' Security Context                                                                                                                                                                            | `1001`                     |
| `worker.containerSecurityContext.runAsNonRoot`                          | Set runAsNonRoot in Superset Celery worker container' Security Context                                                                                                                                                                          | `true`                     |
| `worker.containerSecurityContext.readOnlyRootFilesystem`                | Set readOnlyRootFilesystem in Superset Celery worker container' Security Context                                                                                                                                                                | `false`                    |
| `worker.containerSecurityContext.privileged`                            | Set privileged in Superset Celery worker container' Security Context                                                                                                                                                                            | `false`                    |
| `worker.containerSecurityContext.allowPrivilegeEscalation`              | Set allowPrivilegeEscalation in Superset Celery worker container' Security Context                                                                                                                                                              | `false`                    |
| `worker.containerSecurityContext.capabilities.drop`                     | List of capabilities to be dropped in Superset Celery worker container                                                                                                                                                                          | `["ALL"]`                  |
| `worker.containerSecurityContext.seccompProfile.type`                   | Set seccomp profile in Superset Celery worker container                                                                                                                                                                                         | `RuntimeDefault`           |
| `worker.command`                                                        | Override default Superset Celery worker container command (useful when using custom images)                                                                                                                                                     | `[]`                       |
| `worker.args`                                                           | Override default Superset Celery worker container args (useful when using custom images)                                                                                                                                                        | `[]`                       |
| `worker.automountServiceAccountToken`                                   | Mount Service Account token in Superset Celery worker pods                                                                                                                                                                                      | `false`                    |
| `worker.hostAliases`                                                    | Superset Celery worker pods host aliases                                                                                                                                                                                                        | `[]`                       |
| `worker.deploymentAnnotations`                                          | Annotations for Superset Celery worker deployment                                                                                                                                                                                               | `{}`                       |
| `worker.podLabels`                                                      | Extra labels for Superset Celery worker pods                                                                                                                                                                                                    | `{}`                       |
| `worker.podAnnotations`                                                 | Annotations for Superset Celery worker pods                                                                                                                                                                                                     | `{}`                       |
| `worker.podAffinityPreset`                                              | Pod affinity preset. Ignored if `worker.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                      | `""`                       |
| `worker.podAntiAffinityPreset`                                          | Pod anti-affinity preset. Ignored if `worker.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                 | `soft`                     |
| `worker.nodeAffinityPreset.type`                                        | Node affinity preset type. Ignored if `worker.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                | `""`                       |
| `worker.nodeAffinityPreset.key`                                         | Node label key to match. Ignored if `worker.affinity` is set                                                                                                                                                                                    | `""`                       |
| `worker.nodeAffinityPreset.values`                                      | Node label values to match. Ignored if `worker.affinity` is set                                                                                                                                                                                 | `[]`                       |
| `worker.affinity`                                                       | Affinity for Superset Celery worker pods assignment                                                                                                                                                                                             | `{}`                       |
| `worker.nodeSelector`                                                   | Node labels for Superset Celery worker pods assignment                                                                                                                                                                                          | `{}`                       |
| `worker.tolerations`                                                    | Tolerations for Superset Celery worker pods assignment                                                                                                                                                                                          | `[]`                       |
| `worker.updateStrategy.type`                                            | Superset celery worker deployment strategy type                                                                                                                                                                                                 | `RollingUpdate`            |
| `worker.priorityClassName`                                              | Superset Celery worker pods' priorityClassName                                                                                                                                                                                                  | `""`                       |
| `worker.topologySpreadConstraints`                                      | Topology Spread Constraints for Superset Celery worker pod assignment spread across your cluster among failure-domains                                                                                                                          | `[]`                       |
| `worker.schedulerName`                                                  | Name of the k8s scheduler (other than default) for Superset Celery worker pods                                                                                                                                                                  | `""`                       |
| `worker.terminationGracePeriodSeconds`                                  | Seconds Superset Celery worker pods need to terminate gracefully                                                                                                                                                                                | `""`                       |
| `worker.lifecycleHooks`                                                 | for Superset Celery worker containers to automate configuration before or after startup                                                                                                                                                         | `{}`                       |
| `worker.extraEnvVars`                                                   | Array with extra environment variables to add to Superset Celery worker containers                                                                                                                                                              | `[]`                       |
| `worker.extraEnvVarsCM`                                                 | Name of existing ConfigMap containing extra env vars for Superset Celery worker containers                                                                                                                                                      | `""`                       |
| `worker.extraEnvVarsSecret`                                             | Name of existing Secret containing extra env vars for Superset Celery worker containers                                                                                                                                                         | `""`                       |
| `worker.extraVolumes`                                                   | Optionally specify extra list of additional volumes for the Superset Celery worker pods                                                                                                                                                         | `[]`                       |
| `worker.extraVolumeMounts`                                              | Optionally specify extra list of additional volumeMounts for the Superset Celery worker containers                                                                                                                                              | `[]`                       |
| `worker.sidecars`                                                       | Add additional sidecar containers to the Superset Celery worker pods                                                                                                                                                                            | `[]`                       |
| `worker.initContainers`                                                 | Add additional init containers to the Superset Celery worker pods                                                                                                                                                                               | `[]`                       |
| `worker.pdb.create`                                                     | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                                 | `false`                    |
| `worker.pdb.minAvailable`                                               | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                                  | `1`                        |
| `worker.pdb.maxUnavailable`                                             | Maximum number/percentage of pods that may be made unavailable                                                                                                                                                                                  | `""`                       |
| `worker.autoscaling.vpa.enabled`                                        | Enable VPA                                                                                                                                                                                                                                      | `false`                    |
| `worker.autoscaling.vpa.annotations`                                    | Annotations for VPA resource                                                                                                                                                                                                                    | `{}`                       |
| `worker.autoscaling.vpa.controlledResources`                            | VPA List of resources that the vertical pod autoscaler can control. Defaults to cpu and memory                                                                                                                                                  | `[]`                       |
| `worker.autoscaling.vpa.maxAllowed`                                     | VPA Max allowed resources for the pod                                                                                                                                                                                                           | `{}`                       |
| `worker.autoscaling.vpa.minAllowed`                                     | VPA Min allowed resources for the pod                                                                                                                                                                                                           | `{}`                       |
| `worker.autoscaling.vpa.updatePolicy.updateMode`                        | Autoscaling update policy Specifies whether recommended updates are applied when a Pod is started and whether recommended updates are applied during the life of a Pod                                                                          | `Auto`                     |
| `worker.autoscaling.hpa.enabled`                                        | Enable HPA                                                                                                                                                                                                                                      | `false`                    |
| `worker.autoscaling.hpa.minReplicas`                                    | Minimum number of replicas                                                                                                                                                                                                                      | `""`                       |
| `worker.autoscaling.hpa.maxReplicas`                                    | Maximum number of replicas                                                                                                                                                                                                                      | `""`                       |
| `worker.autoscaling.hpa.targetCPU`                                      | Target CPU utilization percentage                                                                                                                                                                                                               | `""`                       |
| `worker.autoscaling.hpa.targetMemory`                                   | Target Memory utilization percentage                                                                                                                                                                                                            | `""`                       |
| `worker.networkPolicy.enabled`                                          | Specifies whether a NetworkPolicy should be created                                                                                                                                                                                             | `true`                     |
| `worker.networkPolicy.allowExternal`                                    | Don't require server label for connections                                                                                                                                                                                                      | `true`                     |
| `worker.networkPolicy.allowExternalEgress`                              | Allow the pod to access any range of port and all destinations.                                                                                                                                                                                 | `true`                     |
| `worker.networkPolicy.extraIngress`                                     | Add extra ingress rules to the NetworkPolicy                                                                                                                                                                                                    | `[]`                       |
| `worker.networkPolicy.extraEgress`                                      | Add extra ingress rules to the NetworkPolicy (ignored if allowExternalEgress=true)                                                                                                                                                              | `[]`                       |
| `init.enabled`                                                          | Enables the Superset init job, which is in charge of initialising the database, admin user credentials, DB upgrade, etc.                                                                                                                        | `true`                     |
| `init.extraEnvVars`                                                     | Array with extra environment variables to add to Superset init-job containers                                                                                                                                                                   | `[]`                       |
| `init.extraEnvVarsCM`                                                   | Name of existing ConfigMap containing extra env vars for Superset init-job containers                                                                                                                                                           | `""`                       |
| `init.extraEnvVarsSecret`                                               | Name of existing Secret containing extra env vars for Superset init-job containers                                                                                                                                                              | `""`                       |
| `init.extraVolumes`                                                     | Optionally specify extra list of additional volumes for the Superset init-job pods                                                                                                                                                              | `[]`                       |
| `init.extraVolumeMounts`                                                | Optionally specify extra list of additional volumeMounts for the Superset init-job containers                                                                                                                                                   | `[]`                       |
| `init.sidecars`                                                         | Add additional sidecar containers to the Superset init-job pods                                                                                                                                                                                 | `[]`                       |
| `init.initContainers`                                                   | Add additional init containers to the Superset init-job pods                                                                                                                                                                                    | `[]`                       |
| `init.command`                                                          | Override default Superset init-job container command (useful when using custom images)                                                                                                                                                          | `[]`                       |
| `init.args`                                                             | Override default Superset init-job container args (useful when using custom images)                                                                                                                                                             | `[]`                       |
| `init.resourcesPreset`                                                  | Set Superset init-job container resources according to one common preset (allowed values: none, nano, small, medium, large, xlarge, 2xlarge). This is ignored if init.resources is set (init.resources is recommended for production).          | `medium`                   |
| `init.resources`                                                        | Set Superset init-job container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                             | `{}`                       |
| `init.podSecurityContext.enabled`                                       | Enable Superset init-job pods' Security Context                                                                                                                                                                                                 | `true`                     |
| `init.podSecurityContext.fsGroupChangePolicy`                           | Set filesystem group change policy for Superset init-job pods                                                                                                                                                                                   | `Always`                   |
| `init.podSecurityContext.sysctls`                                       | Set kernel settings using the sysctl interface for Superset init-job pods                                                                                                                                                                       | `[]`                       |
| `init.podSecurityContext.supplementalGroups`                            | Set filesystem extra groups for Superset init-job pods                                                                                                                                                                                          | `[]`                       |
| `init.podSecurityContext.fsGroup`                                       | Set fsGroup in Superset init-job pods' Security Context                                                                                                                                                                                         | `1001`                     |
| `init.containerSecurityContext.enabled`                                 | Enabled Superset init-job container' Security Context                                                                                                                                                                                           | `true`                     |
| `init.containerSecurityContext.seLinuxOptions`                          | Set SELinux options in Superset init-job container                                                                                                                                                                                              | `{}`                       |
| `init.containerSecurityContext.runAsUser`                               | Set runAsUser in Superset init-job container' Security Context                                                                                                                                                                                  | `1001`                     |
| `init.containerSecurityContext.runAsGroup`                              | Set runAsGroup in Superset init-job container' Security Context                                                                                                                                                                                 | `1001`                     |
| `init.containerSecurityContext.runAsNonRoot`                            | Set runAsNonRoot in Superset init-job container' Security Context                                                                                                                                                                               | `true`                     |
| `init.containerSecurityContext.readOnlyRootFilesystem`                  | Set readOnlyRootFilesystem in Superset init-job container' Security Context                                                                                                                                                                     | `false`                    |
| `init.containerSecurityContext.privileged`                              | Set privileged in Superset init-job container' Security Context                                                                                                                                                                                 | `false`                    |
| `init.containerSecurityContext.allowPrivilegeEscalation`                | Set allowPrivilegeEscalation in Superset init-job container' Security Context                                                                                                                                                                   | `false`                    |
| `init.containerSecurityContext.capabilities.drop`                       | List of capabilities to be dropped in Superset init-job container                                                                                                                                                                               | `["ALL"]`                  |
| `init.containerSecurityContext.seccompProfile.type`                     | Set seccomp profile in Superset init-job container                                                                                                                                                                                              | `RuntimeDefault`           |
| `init.backoffLimit`                                                     | set backoff limit of the job                                                                                                                                                                                                                    | `10`                       |
| `init.automountServiceAccountToken`                                     | Mount Service Account token in Superset init-job pods                                                                                                                                                                                           | `false`                    |
| `init.hostAliases`                                                      | Superset init-job pods host aliases                                                                                                                                                                                                             | `[]`                       |
| `init.jobAnnotations`                                                   | Annotations for Superset init-job job                                                                                                                                                                                                           | `{}`                       |
| `init.podLabels`                                                        | Extra labels for Superset init-job pods                                                                                                                                                                                                         | `{}`                       |
| `init.podAnnotations`                                                   | Annotations for Superset init-job pods                                                                                                                                                                                                          | `{}`                       |
| `init.networkPolicy.enabled`                                            | Specifies whether a NetworkPolicy should be created                                                                                                                                                                                             | `true`                     |
| `init.networkPolicy.allowExternal`                                      | Don't require server label for connections                                                                                                                                                                                                      | `true`                     |
| `init.networkPolicy.allowExternalEgress`                                | Allow the pod to access any range of port and all destinations.                                                                                                                                                                                 | `true`                     |
| `init.networkPolicy.extraIngress`                                       | Add extra ingress rules to the NetworkPolicy                                                                                                                                                                                                    | `[]`                       |
| `init.networkPolicy.extraEgress`                                        | Add extra ingress rules to the NetworkPolicy (ignored if allowExternalEgress=true)                                                                                                                                                              | `[]`                       |
| `beat.enabled`                                                          | Set to true to enable Superset celery beat. Required if you intend to use alerts and reports                                                                                                                                                    | `false`                    |
| `beat.livenessProbe.enabled`                                            | Enable livenessProbe on Superset celery beat containers                                                                                                                                                                                         | `true`                     |
| `beat.livenessProbe.initialDelaySeconds`                                | Initial delay seconds for livenessProbe                                                                                                                                                                                                         | `15`                       |
| `beat.livenessProbe.periodSeconds`                                      | Period seconds for livenessProbe                                                                                                                                                                                                                | `15`                       |
| `beat.livenessProbe.timeoutSeconds`                                     | Timeout seconds for livenessProbe                                                                                                                                                                                                               | `1`                        |
| `beat.livenessProbe.failureThreshold`                                   | Failure threshold for livenessProbe                                                                                                                                                                                                             | `3`                        |
| `beat.livenessProbe.successThreshold`                                   | Success threshold for livenessProbe                                                                                                                                                                                                             | `1`                        |
| `beat.readinessProbe.enabled`                                           | Enable readinessProbe on Superset celery beat containers                                                                                                                                                                                        | `true`                     |
| `beat.readinessProbe.initialDelaySeconds`                               | Initial delay seconds for readinessProbe                                                                                                                                                                                                        | `15`                       |
| `beat.readinessProbe.periodSeconds`                                     | Period seconds for readinessProbe                                                                                                                                                                                                               | `15`                       |
| `beat.readinessProbe.timeoutSeconds`                                    | Timeout seconds for readinessProbe                                                                                                                                                                                                              | `1`                        |
| `beat.readinessProbe.failureThreshold`                                  | Failure threshold for readinessProbe                                                                                                                                                                                                            | `3`                        |
| `beat.readinessProbe.successThreshold`                                  | Success threshold for readinessProbe                                                                                                                                                                                                            | `1`                        |
| `beat.startupProbe.enabled`                                             | Enable startupProbe on Superset celery beat containers                                                                                                                                                                                          | `false`                    |
| `beat.startupProbe.initialDelaySeconds`                                 | Initial delay seconds for startupProbe                                                                                                                                                                                                          | `15`                       |
| `beat.startupProbe.periodSeconds`                                       | Period seconds for startupProbe                                                                                                                                                                                                                 | `5`                        |
| `beat.startupProbe.timeoutSeconds`                                      | Timeout seconds for startupProbe                                                                                                                                                                                                                | `1`                        |
| `beat.startupProbe.failureThreshold`                                    | Failure threshold for startupProbe                                                                                                                                                                                                              | `60`                       |
| `beat.startupProbe.successThreshold`                                    | Success threshold for startupProbe                                                                                                                                                                                                              | `1`                        |
| `beat.customLivenessProbe`                                              | Custom livenessProbe that overrides the default one                                                                                                                                                                                             | `{}`                       |
| `beat.customReadinessProbe`                                             | Custom readinessProbe that overrides the default one                                                                                                                                                                                            | `{}`                       |
| `beat.customStartupProbe`                                               | Custom startupProbe that overrides the default one                                                                                                                                                                                              | `{}`                       |
| `beat.resourcesPreset`                                                  | Set Superset celery beat container resources according to one common preset (allowed values: none, nano, small, medium, large, xlarge, 2xlarge). This is ignored if beat.resources is set (beat.resources is recommended for production).       | `small`                    |
| `beat.resources`                                                        | Set Superset celery beat container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                          | `{}`                       |
| `beat.podSecurityContext.enabled`                                       | Enable Superset celery beat pods' Security Context                                                                                                                                                                                              | `true`                     |
| `beat.podSecurityContext.fsGroupChangePolicy`                           | Set filesystem group change policy for Superset celery beat pods                                                                                                                                                                                | `Always`                   |
| `beat.podSecurityContext.sysctls`                                       | Set kernel settings using the sysctl interface for Superset celery beat pods                                                                                                                                                                    | `[]`                       |
| `beat.podSecurityContext.supplementalGroups`                            | Set filesystem extra groups for Superset celery beat pods                                                                                                                                                                                       | `[]`                       |
| `beat.podSecurityContext.fsGroup`                                       | Set fsGroup in Superset celery beat pods' Security Context                                                                                                                                                                                      | `1001`                     |
| `beat.containerSecurityContext.enabled`                                 | Enabled Superset celery beat container' Security Context                                                                                                                                                                                        | `true`                     |
| `beat.containerSecurityContext.seLinuxOptions`                          | Set SELinux options in Superset celery beat container                                                                                                                                                                                           | `{}`                       |
| `beat.containerSecurityContext.runAsUser`                               | Set runAsUser in Superset celery beat container' Security Context                                                                                                                                                                               | `1001`                     |
| `beat.containerSecurityContext.runAsGroup`                              | Set runAsGroup in Superset celery beat container' Security Context                                                                                                                                                                              | `1001`                     |
| `beat.containerSecurityContext.runAsNonRoot`                            | Set runAsNonRoot in Superset celery beat container' Security Context                                                                                                                                                                            | `true`                     |
| `beat.containerSecurityContext.readOnlyRootFilesystem`                  | Set readOnlyRootFilesystem in Superset celery beat container' Security Context                                                                                                                                                                  | `false`                    |
| `beat.containerSecurityContext.privileged`                              | Set privileged in Superset celery beat container' Security Context                                                                                                                                                                              | `false`                    |
| `beat.containerSecurityContext.allowPrivilegeEscalation`                | Set allowPrivilegeEscalation in Superset celery beat container' Security Context                                                                                                                                                                | `false`                    |
| `beat.containerSecurityContext.capabilities.drop`                       | List of capabilities to be dropped in Superset celery beat container                                                                                                                                                                            | `["ALL"]`                  |
| `beat.containerSecurityContext.seccompProfile.type`                     | Set seccomp profile in Superset celery beat container                                                                                                                                                                                           | `RuntimeDefault`           |
| `beat.command`                                                          | Override default Superset celery beat container command (useful when using custom images)                                                                                                                                                       | `[]`                       |
| `beat.args`                                                             | Override default Superset celery beat container args (useful when using custom images)                                                                                                                                                          | `[]`                       |
| `beat.automountServiceAccountToken`                                     | Mount Service Account token in Superset celery beat pods                                                                                                                                                                                        | `false`                    |
| `beat.hostAliases`                                                      | Superset celery beat pods host aliases                                                                                                                                                                                                          | `[]`                       |
| `beat.deploymentAnnotations`                                            | Annotations for Superset celery beat deployment                                                                                                                                                                                                 | `{}`                       |
| `beat.podLabels`                                                        | Extra labels for Superset celery beat pods                                                                                                                                                                                                      | `{}`                       |
| `beat.podAnnotations`                                                   | Annotations for Superset celery beat pods                                                                                                                                                                                                       | `{}`                       |
| `beat.podAffinityPreset`                                                | Pod affinity preset. Ignored if `beat.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                        | `""`                       |
| `beat.podAntiAffinityPreset`                                            | Pod anti-affinity preset. Ignored if `beat.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                   | `soft`                     |
| `beat.nodeAffinityPreset.type`                                          | Node affinity preset type. Ignored if `beat.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                  | `""`                       |
| `beat.nodeAffinityPreset.key`                                           | Node label key to match. Ignored if `beat.affinity` is set                                                                                                                                                                                      | `""`                       |
| `beat.nodeAffinityPreset.values`                                        | Node label values to match. Ignored if `beat.affinity` is set                                                                                                                                                                                   | `[]`                       |
| `beat.affinity`                                                         | Affinity for Superset celery beat pods assignment                                                                                                                                                                                               | `{}`                       |
| `beat.nodeSelector`                                                     | Node labels for Superset celery beat pods assignment                                                                                                                                                                                            | `{}`                       |
| `beat.tolerations`                                                      | Tolerations for Superset celery beat pods assignment                                                                                                                                                                                            | `[]`                       |
| `beat.updateStrategy.type`                                              | Superset celery beat deployment strategy type                                                                                                                                                                                                   | `RollingUpdate`            |
| `beat.priorityClassName`                                                | Superset celery beat pods' priorityClassName                                                                                                                                                                                                    | `""`                       |
| `beat.topologySpreadConstraints`                                        | Topology Spread Constraints for Superset celery beat pod assignment spread across your cluster among failure-domains                                                                                                                            | `[]`                       |
| `beat.schedulerName`                                                    | Name of the k8s scheduler (other than default) for Superset celery beat pods                                                                                                                                                                    | `""`                       |
| `beat.terminationGracePeriodSeconds`                                    | Seconds Superset celery beat pods need to terminate gracefully                                                                                                                                                                                  | `""`                       |
| `beat.lifecycleHooks`                                                   | for Superset celery beat containers to automate configuration before or after startup                                                                                                                                                           | `{}`                       |
| `beat.extraEnvVars`                                                     | Array with extra environment variables to add to Superset celery beat containers                                                                                                                                                                | `[]`                       |
| `beat.extraEnvVarsCM`                                                   | Name of existing ConfigMap containing extra env vars for Superset celery beat containers                                                                                                                                                        | `""`                       |
| `beat.extraEnvVarsSecret`                                               | Name of existing Secret containing extra env vars for Superset celery beat containers                                                                                                                                                           | `""`                       |
| `beat.extraVolumes`                                                     | Optionally specify extra list of additional volumes for the Superset celery beat pods                                                                                                                                                           | `[]`                       |
| `beat.extraVolumeMounts`                                                | Optionally specify extra list of additional volumeMounts for the Superset celery beat containers                                                                                                                                                | `[]`                       |
| `beat.sidecars`                                                         | Add additional sidecar containers to the Superset celery beat pods                                                                                                                                                                              | `[]`                       |
| `beat.initContainers`                                                   | Add additional init containers to the Superset celery beat pods                                                                                                                                                                                 | `[]`                       |
| `beat.pdb.create`                                                       | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                                 | `false`                    |
| `beat.pdb.minAvailable`                                                 | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                                  | `1`                        |
| `beat.pdb.maxUnavailable`                                               | Maximum number/percentage of pods that may be made unavailable                                                                                                                                                                                  | `""`                       |
| `beat.networkPolicy.enabled`                                            | Specifies whether a NetworkPolicy should be created                                                                                                                                                                                             | `true`                     |
| `beat.networkPolicy.allowExternal`                                      | Don't require server label for connections                                                                                                                                                                                                      | `true`                     |
| `beat.networkPolicy.allowExternalEgress`                                | Allow the pod to access any range of port and all destinations.                                                                                                                                                                                 | `true`                     |
| `beat.networkPolicy.extraIngress`                                       | Add extra ingress rules to the NetworkPolicy                                                                                                                                                                                                    | `[]`                       |
| `beat.networkPolicy.extraEgress`                                        | Add extra ingress rules to the NetworkPolicy (ignored if allowExternalEgress=true)                                                                                                                                                              | `[]`                       |
| `flower.enabled`                                                        | Set to true to enable Superset celery flower. Required if you intend to use alerts and reports                                                                                                                                                  | `false`                    |
| `flower.replicaCount`                                                   | Number of Superset Celery flower replicas to deploy                                                                                                                                                                                             | `1`                        |
| `flower.containerPorts.flower`                                          | Superset celery flower container port                                                                                                                                                                                                           | `5555`                     |
| `flower.extraContainerPorts`                                            | Optionally specify extra list of additional ports for WordPress container(s)                                                                                                                                                                    | `[]`                       |
| `flower.auth.enabled`                                                   | Enables Apache Celery flower HTTP basic authentication                                                                                                                                                                                          | `true`                     |
| `flower.auth.username`                                                  | Apache Celery flower username                                                                                                                                                                                                                   | `user`                     |
| `flower.auth.password`                                                  | Apache Celery flower password                                                                                                                                                                                                                   | `""`                       |
| `flower.auth.existingSecret`                                            | Name of existing secret to use for Superset Celery flower                                                                                                                                                                                       | `""`                       |
| `flower.livenessProbe.enabled`                                          | Enable livenessProbe on Superset celery flower containers                                                                                                                                                                                       | `true`                     |
| `flower.livenessProbe.initialDelaySeconds`                              | Initial delay seconds for livenessProbe                                                                                                                                                                                                         | `30`                       |
| `flower.livenessProbe.periodSeconds`                                    | Period seconds for livenessProbe                                                                                                                                                                                                                | `15`                       |
| `flower.livenessProbe.timeoutSeconds`                                   | Timeout seconds for livenessProbe                                                                                                                                                                                                               | `1`                        |
| `flower.livenessProbe.failureThreshold`                                 | Failure threshold for livenessProbe                                                                                                                                                                                                             | `3`                        |
| `flower.livenessProbe.successThreshold`                                 | Success threshold for livenessProbe                                                                                                                                                                                                             | `1`                        |
| `flower.readinessProbe.enabled`                                         | Enable readinessProbe on Superset celery flower containers                                                                                                                                                                                      | `true`                     |
| `flower.readinessProbe.initialDelaySeconds`                             | Initial delay seconds for readinessProbe                                                                                                                                                                                                        | `15`                       |
| `flower.readinessProbe.periodSeconds`                                   | Period seconds for readinessProbe                                                                                                                                                                                                               | `15`                       |
| `flower.readinessProbe.timeoutSeconds`                                  | Timeout seconds for readinessProbe                                                                                                                                                                                                              | `1`                        |
| `flower.readinessProbe.failureThreshold`                                | Failure threshold for readinessProbe                                                                                                                                                                                                            | `3`                        |
| `flower.readinessProbe.successThreshold`                                | Success threshold for readinessProbe                                                                                                                                                                                                            | `1`                        |
| `flower.startupProbe.enabled`                                           | Enable startupProbe on Superset celery flower containers                                                                                                                                                                                        | `false`                    |
| `flower.startupProbe.initialDelaySeconds`                               | Initial delay seconds for startupProbe                                                                                                                                                                                                          | `15`                       |
| `flower.startupProbe.periodSeconds`                                     | Period seconds for startupProbe                                                                                                                                                                                                                 | `5`                        |
| `flower.startupProbe.timeoutSeconds`                                    | Timeout seconds for startupProbe                                                                                                                                                                                                                | `1`                        |
| `flower.startupProbe.failureThreshold`                                  | Failure threshold for startupProbe                                                                                                                                                                                                              | `60`                       |
| `flower.startupProbe.successThreshold`                                  | Success threshold for startupProbe                                                                                                                                                                                                              | `1`                        |
| `flower.customLivenessProbe`                                            | Custom livenessProbe that overrides the default one                                                                                                                                                                                             | `{}`                       |
| `flower.customReadinessProbe`                                           | Custom readinessProbe that overrides the default one                                                                                                                                                                                            | `{}`                       |
| `flower.customStartupProbe`                                             | Custom startupProbe that overrides the default one                                                                                                                                                                                              | `{}`                       |
| `flower.resourcesPreset`                                                | Set Superset celery flower container resources according to one common preset (allowed values: none, nano, small, medium, large, xlarge, 2xlarge). This is ignored if flower.resources is set (flower.resources is recommended for production). | `small`                    |
| `flower.resources`                                                      | Set Superset celery flower container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                        | `{}`                       |
| `flower.podSecurityContext.enabled`                                     | Enable Superset celery flower pods' Security Context                                                                                                                                                                                            | `true`                     |
| `flower.podSecurityContext.fsGroupChangePolicy`                         | Set filesystem group change policy for Superset celery flower pods                                                                                                                                                                              | `Always`                   |
| `flower.podSecurityContext.sysctls`                                     | Set kernel settings using the sysctl interface for Superset celery flower pods                                                                                                                                                                  | `[]`                       |
| `flower.podSecurityContext.supplementalGroups`                          | Set filesystem extra groups for Superset celery flower pods                                                                                                                                                                                     | `[]`                       |
| `flower.podSecurityContext.fsGroup`                                     | Set fsGroup in Superset celery flower pods' Security Context                                                                                                                                                                                    | `1001`                     |
| `flower.containerSecurityContext.enabled`                               | Enabled Superset celery flower container' Security Context                                                                                                                                                                                      | `true`                     |
| `flower.containerSecurityContext.seLinuxOptions`                        | Set SELinux options in Superset celery flower container                                                                                                                                                                                         | `{}`                       |
| `flower.containerSecurityContext.runAsUser`                             | Set runAsUser in Superset celery flower container' Security Context                                                                                                                                                                             | `1001`                     |
| `flower.containerSecurityContext.runAsGroup`                            | Set runAsGroup in Superset celery flower container' Security Context                                                                                                                                                                            | `1001`                     |
| `flower.containerSecurityContext.runAsNonRoot`                          | Set runAsNonRoot in Superset celery flower container' Security Context                                                                                                                                                                          | `true`                     |
| `flower.containerSecurityContext.readOnlyRootFilesystem`                | Set readOnlyRootFilesystem in Superset celery flower container' Security Context                                                                                                                                                                | `false`                    |
| `flower.containerSecurityContext.privileged`                            | Set privileged in Superset celery flower container' Security Context                                                                                                                                                                            | `false`                    |
| `flower.containerSecurityContext.allowPrivilegeEscalation`              | Set allowPrivilegeEscalation in Superset celery flower container' Security Context                                                                                                                                                              | `false`                    |
| `flower.containerSecurityContext.capabilities.drop`                     | List of capabilities to be dropped in Superset celery flower container                                                                                                                                                                          | `["ALL"]`                  |
| `flower.containerSecurityContext.seccompProfile.type`                   | Set seccomp profile in Superset celery flower container                                                                                                                                                                                         | `RuntimeDefault`           |
| `flower.command`                                                        | Override default Superset celery flower container command (useful when using custom images)                                                                                                                                                     | `[]`                       |
| `flower.args`                                                           | Override default Superset celery flower container args (useful when using custom images)                                                                                                                                                        | `[]`                       |
| `flower.automountServiceAccountToken`                                   | Mount Service Account token in Superset celery flower pods                                                                                                                                                                                      | `false`                    |
| `flower.hostAliases`                                                    | Superset celery flower pods host aliases                                                                                                                                                                                                        | `[]`                       |
| `flower.deploymentAnnotations`                                          | Annotations for Superset celery flower deployment                                                                                                                                                                                               | `{}`                       |
| `flower.podLabels`                                                      | Extra labels for Superset celery flower pods                                                                                                                                                                                                    | `{}`                       |
| `flower.podAnnotations`                                                 | Annotations for Superset celery flower pods                                                                                                                                                                                                     | `{}`                       |
| `flower.podAffinityPreset`                                              | Pod affinity preset. Ignored if `flower.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                      | `""`                       |
| `flower.podAntiAffinityPreset`                                          | Pod anti-affinity preset. Ignored if `flower.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                 | `soft`                     |
| `flower.nodeAffinityPreset.type`                                        | Node affinity preset type. Ignored if `flower.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                                | `""`                       |
| `flower.nodeAffinityPreset.key`                                         | Node label key to match. Ignored if `flower.affinity` is set                                                                                                                                                                                    | `""`                       |
| `flower.nodeAffinityPreset.values`                                      | Node label values to match. Ignored if `flower.affinity` is set                                                                                                                                                                                 | `[]`                       |
| `flower.affinity`                                                       | Affinity for Superset celery flower pods assignment                                                                                                                                                                                             | `{}`                       |
| `flower.nodeSelector`                                                   | Node labels for Superset celery flower pods assignment                                                                                                                                                                                          | `{}`                       |
| `flower.tolerations`                                                    | Tolerations for Superset celery flower pods assignment                                                                                                                                                                                          | `[]`                       |
| `flower.updateStrategy.type`                                            | Superset celery flower deployment strategy type                                                                                                                                                                                                 | `RollingUpdate`            |
| `flower.priorityClassName`                                              | Superset celery flower pods' priorityClassName                                                                                                                                                                                                  | `""`                       |
| `flower.topologySpreadConstraints`                                      | Topology Spread Constraints for Superset celery flower pod assignment spread across your cluster among failure-domains                                                                                                                          | `[]`                       |
| `flower.schedulerName`                                                  | Name of the k8s scheduler (other than default) for Superset celery flower pods                                                                                                                                                                  | `""`                       |
| `flower.terminationGracePeriodSeconds`                                  | Seconds Superset celery flower pods need to terminate gracefully                                                                                                                                                                                | `""`                       |
| `flower.lifecycleHooks`                                                 | for Superset celery flower containers to automate configuration before or after startup                                                                                                                                                         | `{}`                       |
| `flower.extraEnvVars`                                                   | Array with extra environment variables to add to Superset celery flower containers                                                                                                                                                              | `[]`                       |
| `flower.extraEnvVarsCM`                                                 | Name of existing ConfigMap containing extra env vars for Superset celery flower containers                                                                                                                                                      | `""`                       |
| `flower.extraEnvVarsSecret`                                             | Name of existing Secret containing extra env vars for Superset celery flower containers                                                                                                                                                         | `""`                       |
| `flower.extraVolumes`                                                   | Optionally specify extra list of additional volumes for the Superset celery flower pods                                                                                                                                                         | `[]`                       |
| `flower.extraVolumeMounts`                                              | Optionally specify extra list of additional volumeMounts for the Superset celery flower containers                                                                                                                                              | `[]`                       |
| `flower.sidecars`                                                       | Add additional sidecar containers to the Superset celery flower pods                                                                                                                                                                            | `[]`                       |
| `flower.initContainers`                                                 | Add additional init containers to the Superset celery flower pods                                                                                                                                                                               | `[]`                       |
| `flower.pdb.create`                                                     | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                                 | `false`                    |
| `flower.pdb.minAvailable`                                               | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                                  | `1`                        |
| `flower.pdb.maxUnavailable`                                             | Maximum number/percentage of pods that may be made unavailable                                                                                                                                                                                  | `""`                       |
| `flower.autoscaling.vpa.enabled`                                        | Enable VPA                                                                                                                                                                                                                                      | `false`                    |
| `flower.autoscaling.vpa.annotations`                                    | Annotations for VPA resource                                                                                                                                                                                                                    | `{}`                       |
| `flower.autoscaling.vpa.controlledResources`                            | VPA List of resources that the vertical pod autoscaler can control. Defaults to cpu and memory                                                                                                                                                  | `[]`                       |
| `flower.autoscaling.vpa.maxAllowed`                                     | VPA Max allowed resources for the pod                                                                                                                                                                                                           | `{}`                       |
| `flower.autoscaling.vpa.minAllowed`                                     | VPA Min allowed resources for the pod                                                                                                                                                                                                           | `{}`                       |
| `flower.autoscaling.vpa.updatePolicy.updateMode`                        | Autoscaling update policy Specifies whether recommended updates are applied when a Pod is started and whether recommended updates are applied during the life of a Pod                                                                          | `Auto`                     |
| `flower.autoscaling.hpa.enabled`                                        | Enable HPA                                                                                                                                                                                                                                      | `false`                    |
| `flower.autoscaling.hpa.minReplicas`                                    | Minimum number of replicas                                                                                                                                                                                                                      | `""`                       |
| `flower.autoscaling.hpa.maxReplicas`                                    | Maximum number of replicas                                                                                                                                                                                                                      | `""`                       |
| `flower.autoscaling.hpa.targetCPU`                                      | Target CPU utilization percentage                                                                                                                                                                                                               | `""`                       |
| `flower.autoscaling.hpa.targetMemory`                                   | Target Memory utilization percentage                                                                                                                                                                                                            | `""`                       |
| `flower.service.type`                                                   | Superset celery flower service type                                                                                                                                                                                                             | `LoadBalancer`             |
| `flower.service.ports.flower`                                           | Superset celery flower service port                                                                                                                                                                                                             | `5555`                     |
| `flower.service.nodePorts.flower`                                       | Node port for flower                                                                                                                                                                                                                            | `""`                       |
| `flower.service.clusterIP`                                              | Superset celery flower service Cluster IP                                                                                                                                                                                                       | `""`                       |
| `flower.service.loadBalancerIP`                                         | Superset celery flower service Load Balancer IP                                                                                                                                                                                                 | `""`                       |
| `flower.service.loadBalancerSourceRanges`                               | Superset celery flower service Load Balancer sources                                                                                                                                                                                            | `[]`                       |
| `flower.service.externalTrafficPolicy`                                  | Superset celery flower service external traffic policy                                                                                                                                                                                          | `Cluster`                  |
| `flower.service.annotations`                                            | Additional custom annotations for Superset celery flower service                                                                                                                                                                                | `{}`                       |
| `flower.service.extraPorts`                                             | Extra ports to expose in Superset celery flower service (normally used with the `sidecars` value)                                                                                                                                               | `[]`                       |
| `flower.service.sessionAffinity`                                        | Control where client requests go, to the same pod or round-robin                                                                                                                                                                                | `None`                     |
| `flower.service.sessionAffinityConfig`                                  | Additional settings for the sessionAffinity                                                                                                                                                                                                     | `{}`                       |
| `flower.networkPolicy.enabled`                                          | Specifies whether a NetworkPolicy should be created                                                                                                                                                                                             | `true`                     |
| `flower.networkPolicy.allowExternal`                                    | Don't require server label for connections                                                                                                                                                                                                      | `true`                     |
| `flower.networkPolicy.allowExternalEgress`                              | Allow the pod to access any range of port and all destinations.                                                                                                                                                                                 | `true`                     |
| `flower.networkPolicy.addExternalClientAccess`                          | Allow access from pods with client label set to "true". Ignored if `networkPolicy.allowExternal` is true.                                                                                                                                       | `true`                     |
| `flower.networkPolicy.extraIngress`                                     | Add extra ingress rules to the NetworkPolicy                                                                                                                                                                                                    | `[]`                       |
| `flower.networkPolicy.extraEgress`                                      | Add extra ingress rules to the NetworkPolicy (ignored if allowExternalEgress=true)                                                                                                                                                              | `[]`                       |
| `flower.networkPolicy.ingressPodMatchLabels`                            | Labels to match to allow traffic from other pods. Ignored if `networkPolicy.allowExternal` is true.                                                                                                                                             | `{}`                       |
| `flower.networkPolicy.ingressNSMatchLabels`                             | Labels to match to allow traffic from other namespaces                                                                                                                                                                                          | `{}`                       |
| `flower.networkPolicy.ingressNSPodMatchLabels`                          | Pod labels to match to allow traffic from other namespaces                                                                                                                                                                                      | `{}`                       |
| `ingress.enabled`                                                       | Enable ingress record generation for Superset                                                                                                                                                                                                   | `false`                    |
| `ingress.pathType`                                                      | Ingress path type                                                                                                                                                                                                                               | `ImplementationSpecific`   |
| `ingress.apiVersion`                                                    | Force Ingress API version (automatically detected if not set)                                                                                                                                                                                   | `""`                       |
| `ingress.hostname`                                                      | Default host for the ingress record                                                                                                                                                                                                             | `superset.local`           |
| `ingress.ingressClassName`                                              | IngressClass that will be be used to implement the Ingress (Kubernetes 1.18+)                                                                                                                                                                   | `""`                       |
| `ingress.path`                                                          | Default path for the ingress record                                                                                                                                                                                                             | `/`                        |
| `ingress.annotations`                                                   | Additional annotations for the Ingress resource. To enable certificate autogeneration, place here your cert-manager annotations.                                                                                                                | `{}`                       |
| `ingress.tls`                                                           | Enable TLS configuration for the host defined at `ingress.hostname` parameter                                                                                                                                                                   | `false`                    |
| `ingress.selfSigned`                                                    | Create a TLS secret for this ingress record using self-signed certificates generated by Helm                                                                                                                                                    | `false`                    |
| `ingress.extraHosts`                                                    | An array with additional hostname(s) to be covered with the ingress record                                                                                                                                                                      | `[]`                       |
| `ingress.extraPaths`                                                    | An array with additional arbitrary paths that may need to be added to the ingress under the main host                                                                                                                                           | `[]`                       |
| `ingress.extraTls`                                                      | TLS configuration for additional hostname(s) to be covered with this ingress record                                                                                                                                                             | `[]`                       |
| `ingress.secrets`                                                       | Custom TLS certificates as secrets                                                                                                                                                                                                              | `[]`                       |
| `ingress.extraRules`                                                    | Additional rules to be covered with this ingress record                                                                                                                                                                                         | `[]`                       |

### Default Init Container Parameters

| Name                                                                                   | Description                                                                                                                                                                                                                               | Value            |
| -------------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ---------------- |
| `defaultInitContainers.waitForDB.enabled`                                              | Enable init container that waits for the Database to be available                                                                                                                                                                         | `true`           |
| `defaultInitContainers.waitForDB.resourcesPreset`                                      | Set init container resources according to one common preset (allowed values: none, nano, small, medium, large, xlarge, 2xlarge). This is ignored if waitForDB.resources is set (waitForDB.resources is recommended for production).       | `nano`           |
| `defaultInitContainers.waitForDB.resources`                                            | Set init container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                    | `{}`             |
| `defaultInitContainers.waitForDB.containerSecurityContext.enabled`                     | Enabled wait-for-db initcontainer's Security Context                                                                                                                                                                                      | `true`           |
| `defaultInitContainers.waitForDB.containerSecurityContext.seLinuxOptions`              | Set SELinux options in wait-for-db initcontainer                                                                                                                                                                                          | `{}`             |
| `defaultInitContainers.waitForDB.containerSecurityContext.runAsUser`                   | Set runAsUser in wait-for-db initcontainer's Security Context                                                                                                                                                                             | `1001`           |
| `defaultInitContainers.waitForDB.containerSecurityContext.runAsGroup`                  | Set runAsGroup in wait-for-db initcontainer's Security Context                                                                                                                                                                            | `1001`           |
| `defaultInitContainers.waitForDB.containerSecurityContext.runAsNonRoot`                | Set runAsNonRoot in wait-for-db initcontainer's Security Context                                                                                                                                                                          | `true`           |
| `defaultInitContainers.waitForDB.containerSecurityContext.readOnlyRootFilesystem`      | Set readOnlyRootFilesystem in wait-for-db initcontainer's Security Context                                                                                                                                                                | `false`          |
| `defaultInitContainers.waitForDB.containerSecurityContext.privileged`                  | Set privileged in wait-for-db initcontainer's Security Context                                                                                                                                                                            | `false`          |
| `defaultInitContainers.waitForDB.containerSecurityContext.allowPrivilegeEscalation`    | Set allowPrivilegeEscalation in wait-for-db initcontainer's Security Context                                                                                                                                                              | `false`          |
| `defaultInitContainers.waitForDB.containerSecurityContext.capabilities.drop`           | List of capabilities to be dropped in wait-for-db initcontainer                                                                                                                                                                           | `["ALL"]`        |
| `defaultInitContainers.waitForDB.containerSecurityContext.seccompProfile.type`         | Set seccomp profile in wait-for-db initcontainer                                                                                                                                                                                          | `RuntimeDefault` |
| `defaultInitContainers.waitForRedis.enabled`                                           | Enable init container that waits for Redis to be available                                                                                                                                                                                | `true`           |
| `defaultInitContainers.waitForRedis.resourcesPreset`                                   | Set init container resources according to one common preset (allowed values: none, nano, small, medium, large, xlarge, 2xlarge). This is ignored if waitForRedis.resources is set (waitForRedis.resources is recommended for production). | `nano`           |
| `defaultInitContainers.waitForRedis.resources`                                         | Set init container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                    | `{}`             |
| `defaultInitContainers.waitForRedis.containerSecurityContext.enabled`                  | Enabled wait-for-redis initcontainer's Security Context                                                                                                                                                                                   | `true`           |
| `defaultInitContainers.waitForRedis.containerSecurityContext.seLinuxOptions`           | Set SELinux options in wait-for-redis initcontainer                                                                                                                                                                                       | `{}`             |
| `defaultInitContainers.waitForRedis.containerSecurityContext.runAsUser`                | Set runAsUser in wait-for-redis initcontainer's Security Context                                                                                                                                                                          | `1001`           |
| `defaultInitContainers.waitForRedis.containerSecurityContext.runAsGroup`               | Set runAsGroup in wait-for-redis initcontainer's Security Context                                                                                                                                                                         | `1001`           |
| `defaultInitContainers.waitForRedis.containerSecurityContext.runAsNonRoot`             | Set runAsNonRoot in wait-for-redis initcontainer's Security Context                                                                                                                                                                       | `true`           |
| `defaultInitContainers.waitForRedis.containerSecurityContext.readOnlyRootFilesystem`   | Set readOnlyRootFilesystem in wait-for-redis initcontainer's Security Context                                                                                                                                                             | `false`          |
| `defaultInitContainers.waitForRedis.containerSecurityContext.privileged`               | Set privileged in wait-for-redis initcontainer's Security Context                                                                                                                                                                         | `false`          |
| `defaultInitContainers.waitForRedis.containerSecurityContext.allowPrivilegeEscalation` | Set allowPrivilegeEscalation in wait-for-redis initcontainer's Security Context                                                                                                                                                           | `false`          |
| `defaultInitContainers.waitForRedis.containerSecurityContext.capabilities.drop`        | List of capabilities to be dropped in wait-for-redis initcontainer                                                                                                                                                                        | `["ALL"]`        |
| `defaultInitContainers.waitForRedis.containerSecurityContext.seccompProfile.type`      | Set seccomp profile in wait-for-redis initcontainer                                                                                                                                                                                       | `RuntimeDefault` |

### Other Parameters

| Name                                          | Description                                                      | Value  |
| --------------------------------------------- | ---------------------------------------------------------------- | ------ |
| `serviceAccount.create`                       | Specifies whether a ServiceAccount should be created             | `true` |
| `serviceAccount.name`                         | The name of the ServiceAccount to use.                           | `""`   |
| `serviceAccount.annotations`                  | Additional Service Account annotations (evaluated as a template) | `{}`   |
| `serviceAccount.automountServiceAccountToken` | Automount service account token for the server service account   | `true` |

### Superset database parameters

| Name                                          | Description                                                                                                                                                                                                                | Value              |
| --------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------ |
| `postgresql.enabled`                          | Switch to enable or disable the PostgreSQL helm chart                                                                                                                                                                      | `true`             |
| `postgresql.auth.enablePostgresUser`          | Assign a password to the "postgres" admin user. Otherwise, remote access will be blocked for this user                                                                                                                     | `true`             |
| `postgresql.auth.username`                    | Name for a custom user to create                                                                                                                                                                                           | `bn_superset`      |
| `postgresql.auth.password`                    | Password for the custom user to create                                                                                                                                                                                     | `""`               |
| `postgresql.auth.database`                    | Name for a custom database to create                                                                                                                                                                                       | `bitnami_superset` |
| `postgresql.auth.existingSecret`              | Name of existing secret to use for PostgreSQL credentials                                                                                                                                                                  | `""`               |
| `postgresql.architecture`                     | PostgreSQL architecture (`standalone` or `replication`)                                                                                                                                                                    | `standalone`       |
| `postgresql.primary.service.ports.postgresql` | PostgreSQL service port                                                                                                                                                                                                    | `5432`             |
| `postgresql.primary.resourcesPreset`          | Set container resources according to one common preset (allowed values: none, nano, small, medium, large, xlarge, 2xlarge). This is ignored if primary.resources is set (primary.resources is recommended for production). | `nano`             |
| `postgresql.primary.resources`                | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                          | `{}`               |
| `externalDatabase.host`                       | Database host                                                                                                                                                                                                              | `""`               |
| `externalDatabase.port`                       | Database port number                                                                                                                                                                                                       | `5432`             |
| `externalDatabase.user`                       | Non-root username for Superset                                                                                                                                                                                             | `bn_superset`      |
| `externalDatabase.password`                   | Password for the non-root username for Superset                                                                                                                                                                            | `""`               |
| `externalDatabase.database`                   | Superset database name                                                                                                                                                                                                     | `bitnami_superset` |
| `externalDatabase.existingSecret`             | Name of an existing secret resource containing the database credentials                                                                                                                                                    | `""`               |
| `externalDatabase.existingSecretPasswordKey`  | Name of an existing secret key containing the database credentials                                                                                                                                                         | `db-password`      |
| `redis.enabled`                               | Switch to enable or disable the Redis&reg; helm                                                                                                                                                                            | `true`             |
| `redis.auth.enabled`                          | Enable password authentication                                                                                                                                                                                             | `true`             |
| `redis.auth.password`                         | Redis&reg; password                                                                                                                                                                                                        | `""`               |
| `redis.auth.existingSecret`                   | The name of an existing secret with Redis&reg; credentials                                                                                                                                                                 | `""`               |
| `redis.architecture`                          | Redis&reg; architecture. Allowed values: `standalone` or `replication`                                                                                                                                                     | `standalone`       |
| `redis.master.service.ports.redis`            | Redis&reg; port                                                                                                                                                                                                            | `6379`             |
| `redis.master.resourcesPreset`                | Set container resources according to one common preset (allowed values: none, nano, small, medium, large, xlarge, 2xlarge). This is ignored if master.resources is set (master.resources is recommended for production).   | `nano`             |
| `redis.master.resources`                      | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                          | `{}`               |
| `externalRedis.host`                          | Redis&reg; host                                                                                                                                                                                                            | `""`               |
| `externalRedis.port`                          | Redis&reg; port number                                                                                                                                                                                                     | `6379`             |
| `externalRedis.username`                      | Redis&reg; username                                                                                                                                                                                                        | `default`          |
| `externalRedis.password`                      | Redis&reg; password                                                                                                                                                                                                        | `""`               |
| `externalRedis.existingSecret`                | Name of an existing secret resource containing the Redis&trade credentials                                                                                                                                                 | `""`               |
| `externalRedis.existingSecretPasswordKey`     | Name of an existing secret key containing the Redis&trade credentials                                                                                                                                                      | `redis-password`   |

The above parameters map to the env variables defined in [bitnami/superset](https://github.com/bitnami/containers/tree/main/bitnami/superset). For more information please refer to the [bitnami/superset](https://github.com/bitnami/containers/tree/main/bitnami/superset) image documentation.

Specify each parameter using the `--set key=value[,key=value]` argument to `helm install`. For example,

```console
helm install my-release \
  --set auth.username=admin \
  --set auth.password=password \
  --set postgresql.auth.password=secretpassword \
    oci://REGISTRY_NAME/REPOSITORY_NAME/superset
```

> Note: You need to substitute the placeholders `REGISTRY_NAME` and `REPOSITORY_NAME` with a reference to your Helm chart registry and repository. For example, in the case of Bitnami, you need to use `REGISTRY_NAME=registry-1.docker.io` and `REPOSITORY_NAME=bitnamicharts`.

The above command sets the Superset administrator account username and password to `admin` and `password` respectively. Additionally, it sets the PostgreSQL user password to `secretpassword`.

> NOTE: Once this chart is deployed, it is not possible to change the application's access credentials, such as usernames or passwords, using Helm. To change these application credentials after deployment, delete any persistent volumes (PVs) used by the chart and re-deploy it, or use the application's built-in administrative tools if available.

Alternatively, a YAML file that specifies the values for the above parameters can be provided while installing the chart. For example,

```console
helm install my-release -f values.yaml oci://REGISTRY_NAME/REPOSITORY_NAME/superset
```

> Note: You need to substitute the placeholders `REGISTRY_NAME` and `REPOSITORY_NAME` with a reference to your Helm chart registry and repository. For example, in the case of Bitnami, you need to use `REGISTRY_NAME=registry-1.docker.io` and `REPOSITORY_NAME=bitnamicharts`.
> **Tip**: You can use the default [values.yaml](https://github.com/bitnami/charts/blob/main/template/superset/values.yaml)

## Troubleshooting

Find more information about how to deal with common errors related to Bitnami's Helm charts in [this troubleshooting guide](https://docs.bitnami.com/general/how-to/troubleshoot-helm-chart-issues).

## Upgrading

### To 3.0.0

This major updates the Redis&reg; subchart to its newest major, 21.0.0, which updates Redis&reg; from 7.4 to 8.0. [Here](https://redis.io/docs/latest/operate/oss_and_stack/install/upgrade/cluster/) you can find more information about the changes introduced in that version. No major issues are expected during the upgrade.

### To 2.0.0

This version replaces the value `flower.auth.usePasswordFiles` with the new value `usePasswordFiles`. When using `usePasswordFiles=true`, , all credentials will be mounted as files instead of using an environment variable.

## License

Copyright &copy; 2025 Broadcom. The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

<http://www.apache.org/licenses/LICENSE-2.0>

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.