<!--- app-name: VictoriaMetrics -->

# Bitnami package for VictoriaMetrics

VictoriaMetrics is a fast, cost-effective, and scalable monitoring solution and time series database, compatible with Prometheus and Graphite

[Overview of VictoriaMetrics](https://victoriametrics.com/)

Trademarks: This software listing is packaged by Bitnami. The respective trademarks mentioned in the offering are owned by the respective companies, and use of them does not imply any affiliation or endorsement.

## TL;DR

```console
helm install my-release oci://registry-1.docker.io/bitnamicharts/victoriametrics
```

Looking to use VictoriaMetrics in production? Try [VMware Tanzu Application Catalog](https://bitnami.com/enterprise), the commercial edition of the Bitnami catalog.

## Introduction

This chart bootstraps a [VictoriaMetrics](https://github.com/bitnami/containers/tree/main/bitnami/victoriametrics-vmselect) deployment on a [Kubernetes](https://kubernetes.io) cluster using the [Helm](https://helm.sh) package manager.

## Prerequisites

- Kubernetes 1.23+
- Helm 3.8.0+
- PV provisioner support in the underlying infrastructure

## Installing the Chart

To install the chart with the release name `my-release`:

```console
helm install my-release oci://REGISTRY_NAME/REPOSITORY_NAME/victoriametrics
```

> Note: You need to substitute the placeholders `REGISTRY_NAME` and `REPOSITORY_NAME` with a reference to your Helm chart registry and repository. For example, in the case of Bitnami, you need to use `REGISTRY_NAME=registry-1.docker.io` and `REPOSITORY_NAME=bitnamicharts`.

The command deploys VictoriaMetrics on the Kubernetes cluster in the default configuration. The [Parameters](#parameters) section lists the parameters that can be configured during installation.

> **Tip**: List all releases using `helm list`

## Configuration and installation details

### Available VictoriaMetrics components

The VictoriaMetrics chart always deploys the `vminsert`, `vmstorage` and `vmselect` components, as part of the basic [open-source VictoriaMetrics cluster installation](https://docs.victoriametrics.com/cluster-victoriametrics/). Additionally, it is possible to deploy the [`vmauth`](https://docs.victoriametrics.com/vmauth/), [`vmalert`](https://docs.victoriametrics.com/vmalert/) or [`vmagent`](https://docs.victoriametrics.com/vmagent/) components by setting `vmauth.enabled=true`, `vmagent.enabled=true` or `vmalert.enabled=true`.

### Resource requests and limits

Bitnami charts allow setting resource requests and limits for all containers inside the chart deployment. These are inside the `resources` value (check parameter table). Setting requests is essential for production workloads and these should be adapted to your specific use case.

To make this process easier, the chart contains the `resourcesPreset` values, which automatically sets the `resources` section according to different presets. Check these presets in [the bitnami/common chart](https://github.com/bitnami/charts/blob/main/bitnami/common/templates/_resources.tpl#L15). However, in production workloads using `resourcesPreset` is discouraged as it may not fully adapt to your specific needs. Find more information on container resource management in the [official Kubernetes documentation](https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/).

### [Rolling VS Immutable tags](https://techdocs.broadcom.com/us/en/vmware-tanzu/application-catalog/tanzu-application-catalog/services/tac-doc/apps-tutorials-understand-rolling-tags-containers-index.html)

It is strongly recommended to use immutable tags in a production environment. This ensures your deployment does not change automatically if the same tag is updated with a different image.

Bitnami will release a new chart updating its containers if a new version of the main container, significant changes, or critical vulnerabilities exist.

### Backup and restore

To back up and restore Helm chart deployments on Kubernetes, you need to back up the persistent volumes from the source deployment and attach them to a new deployment using [Velero](https://velero.io/), a Kubernetes backup/restore tool. Find the instructions for using Velero in [this guide](https://techdocs.broadcom.com/us/en/vmware-tanzu/application-catalog/tanzu-application-catalog/services/tac-doc/apps-tutorials-backup-restore-deployments-velero-index.html).

### Prometheus metrics

This chart can be integrated with Prometheus by setting `*.metrics.enabled` (under the `vminsert`, `vmselect`, `vmstorage`, `vmagent`, `vmalert` and `vmauth` sections) to `true`. This will expose VictoriaMetrics native Prometheus ports in the containers. Additionally, it will deploy several `metrics` services, which can be configured under the `*.metrics.service` section (under the `vminsert`, `vmselect`, `vmstorage`, `vmagent`, `vmalert` and `vmauth` sections). These `metrics` services will have the necessary annotations to be automatically scraped by Prometheus.

#### Prometheus requirements

It is necessary to have a working installation of Prometheus or Prometheus Operator for the integration to work. Install the [Bitnami Prometheus helm chart](https://github.com/bitnami/charts/tree/main/bitnami/prometheus) or the [Bitnami Kube Prometheus helm chart](https://github.com/bitnami/charts/tree/main/bitnami/kube-prometheus) to easily have a working Prometheus in your cluster.

#### Integration with Prometheus Operator

The chart can deploy `ServiceMonitor` objects for integration with Prometheus Operator installations. To do so, set the value `*.metrics.serviceMonitor.enabled=true`  (`vminsert`, `vmselect`, `vmstorage`, `vmagent`, `vmalert` and `vmauth`). Ensure that the Prometheus Operator `CustomResourceDefinitions` are installed in the cluster or it will fail with the following error:

```text
no matches for kind "ServiceMonitor" in version "monitoring.coreos.com/v1"
```

Install the [Bitnami Kube Prometheus helm chart](https://github.com/bitnami/charts/tree/main/bitnami/kube-prometheus) for having the necessary CRDs and the Prometheus Operator.

### Ingress

This chart provides support for Ingress resources. If you have an ingress controller installed on your cluster, such as [nginx-ingress-controller](https://github.com/bitnami/charts/tree/main/bitnami/nginx-ingress-controller) or [contour](https://github.com/bitnami/charts/tree/main/bitnami/contour) you can utilize the ingress controller to serve your application.To enable Ingress integration, set `*.ingress.enabled` (under the `vmselect`, `vmauth` and `vmselect` sections) to `true`.

The most common scenario is to have one host name mapped to the deployment. In this case, the `*.ingress.hostname` (under the `vmselect`, `vmauth` and `vmselect` sections) property can be used to set the host name. The `*.ingress.tls` parameter can be used to add the TLS configuration for this host.

However, it is also possible to have more than one host. To facilitate this, the `*.ingress.extraHosts` parameter (if available) can be set with the host names specified as an array. The `*.ingress.extraTLS` (under the `vmselect`, `vmauth` and `vmselect` sections) parameter (if available) can also be used to add the TLS configuration for extra hosts.

> NOTE: For each host specified in the `*.ingress.extraHosts` (under the `vmselect`, `vmauth` and `vmselect` sections) parameter, it is necessary to set a name, path, and any annotations that the Ingress controller should know about. Not all annotations are supported by all Ingress controllers, but [this annotation reference document](https://github.com/kubernetes/ingress-nginx/blob/master/docs/user-guide/nginx-configuration/annotations.md) lists the annotations supported by many popular Ingress controllers.

Adding the TLS parameter (where available) will cause the chart to generate HTTPS URLs, and the  application will be available on port 443. The actual TLS secrets do not have to be generated by this chart. However, if TLS is enabled, the Ingress record will not work until the TLS secret exists.

[Learn more about Ingress controllers](https://kubernetes.io/docs/concepts/services-networking/ingress-controllers/).

### Securing traffic using TLS

This chart facilitates the creation of TLS secrets for use with the Ingress controller (although this is not mandatory). There are several common use cases:

- Generate certificate secrets based on chart parameters.
- Enable externally generated certificates.
- Manage application certificates via an external service (like [cert-manager](https://github.com/jetstack/cert-manager/)).
- Create self-signed certificates within the chart (if supported).

In the first two cases, a certificate and a key are needed. Files are expected in `.pem` format.

Here is an example of a certificate file:

> NOTE: There may be more than one certificate if there is a certificate chain.

```text
-----BEGIN CERTIFICATE-----
MIID6TCCAtGgAwIBAgIJAIaCwivkeB5EMA0GCSqGSIb3DQEBCwUAMFYxCzAJBgNV
...
jScrvkiBO65F46KioCL9h5tDvomdU1aqpI/CBzhvZn1c0ZTf87tGQR8NK7v7
-----END CERTIFICATE-----
```

Here is an example of a certificate key:

```text
-----BEGIN RSA PRIVATE KEY-----
MIIEogIBAAKCAQEAvLYcyu8f3skuRyUgeeNpeDvYBCDcgq+LsWap6zbX5f8oLqp4
...
wrj2wDbCDCFmfqnSJ+dKI3vFLlEz44sAV8jX/kd4Y6ZTQhlLbYc=
-----END RSA PRIVATE KEY-----
```

- If using Helm to manage the certificates based on the parameters, copy these values into the `certificate` and `key` values for a given `*.ingress.secrets` (under the `vmselect`, `vmauth` and `vmselect` sections) entry.
- If managing TLS secrets separately, it is necessary to create a TLS secret with name `INGRESS_HOSTNAME-tls` (where INGRESS_HOSTNAME is a placeholder to be replaced with the hostname you set using the `*.ingress.hostname` (under the `vmselect`, `vmauth` and `vmselect` sections) parameter).
- If your cluster has a [cert-manager](https://github.com/jetstack/cert-manager) add-on to automate the management and issuance of TLS certificates, add to `*.ingress.annotations` (under the `vmselect`, `vmauth` and `vmselect` sections) the [corresponding ones](https://cert-manager.io/docs/usage/ingress/#supported-annotations) for cert-manager.
- If using self-signed certificates created by Helm, set both `*.ingress.tls` and `*.ingress.selfSigned` (under the `vmselect`, `vmauth` and `vmselect` sections) to `true`.

## Parameters

### Global parameters

| Name                                                  | Description                                                                                                                                                                                                                                                                                                                                                         | Value   |
| ----------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------- |
| `global.imageRegistry`                                | Global Docker image registry                                                                                                                                                                                                                                                                                                                                        | `""`    |
| `global.imagePullSecrets`                             | Global Docker registry secret names as an array                                                                                                                                                                                                                                                                                                                     | `[]`    |
| `global.defaultStorageClass`                          | Global default StorageClass for Persistent Volume(s)                                                                                                                                                                                                                                                                                                                | `""`    |
| `global.security.allowInsecureImages`                 | Allows skipping image verification                                                                                                                                                                                                                                                                                                                                  | `false` |
| `global.compatibility.openshift.adaptSecurityContext` | Adapt the securityContext sections of the deployment to make them compatible with Openshift restricted-v2 SCC: remove runAsUser, runAsGroup and fsGroup and let the platform use their allowed default IDs. Possible values: auto (apply if the detected running cluster is Openshift), force (perform the adaptation always), disabled (do not perform adaptation) | `auto`  |

### Common parameters

| Name                | Description                                                | Value           |
| ------------------- | ---------------------------------------------------------- | --------------- |
| `kubeVersion`       | Override Kubernetes version                                | `""`            |
| `apiVersions`       | Override Kubernetes API versions reported by .Capabilities | `[]`            |
| `nameOverride`      | String to partially override common.names.name             | `""`            |
| `fullnameOverride`  | String to fully override common.names.fullname             | `""`            |
| `namespaceOverride` | String to fully override common.names.namespace            | `""`            |
| `commonLabels`      | Labels to add to all deployed objects                      | `{}`            |
| `commonAnnotations` | Annotations to add to all deployed objects                 | `{}`            |
| `clusterDomain`     | Kubernetes cluster domain name                             | `cluster.local` |
| `extraDeploy`       | Array of extra objects to deploy with the release          | `[]`            |

### VictoriaMetrics common parameters

| Name            | Description                         | Value  |
| --------------- | ----------------------------------- | ------ |
| `envflagEnable` | Enable envflag                      | `true` |
| `envflagPrefix` | Prefix used for the envflag entries | `VM_`  |
| `loggerFormat`  | Set format of the logs              | `json` |

### VictoriaMetrics Select Parameters

| Name                                                         | Description                                                                                                                                                                                                                         | Value                                      |
| ------------------------------------------------------------ | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------ |
| `vmselect.image.registry`                                    | VictoriaMetrics Select image registry                                                                                                                                                                                               | `REGISTRY_NAME`                            |
| `vmselect.image.repository`                                  | VictoriaMetrics Select image repository                                                                                                                                                                                             | `REPOSITORY_NAME/victoriametrics-vmselect` |
| `vmselect.image.digest`                                      | VictoriaMetrics Select image digest in the way sha256:aa.... Please note this parameter, if set, will override the tag image tag (immutable tags are recommended)                                                                   | `""`                                       |
| `vmselect.image.pullPolicy`                                  | VictoriaMetrics Select image pull policy                                                                                                                                                                                            | `IfNotPresent`                             |
| `vmselect.image.pullSecrets`                                 | VictoriaMetrics Select image pull secrets                                                                                                                                                                                           | `[]`                                       |
| `vmselect.replicaCount`                                      | Number of VictoriaMetrics Select replicas to deploy                                                                                                                                                                                 | `1`                                        |
| `vmselect.containerPorts.http`                               | VictoriaMetrics Select http container port                                                                                                                                                                                          | `8481`                                     |
| `vmselect.livenessProbe.enabled`                             | Enable livenessProbe on VictoriaMetrics Select containers                                                                                                                                                                           | `true`                                     |
| `vmselect.livenessProbe.initialDelaySeconds`                 | Initial delay seconds for livenessProbe                                                                                                                                                                                             | `5`                                        |
| `vmselect.livenessProbe.periodSeconds`                       | Period seconds for livenessProbe                                                                                                                                                                                                    | `10`                                       |
| `vmselect.livenessProbe.timeoutSeconds`                      | Timeout seconds for livenessProbe                                                                                                                                                                                                   | `5`                                        |
| `vmselect.livenessProbe.failureThreshold`                    | Failure threshold for livenessProbe                                                                                                                                                                                                 | `5`                                        |
| `vmselect.livenessProbe.successThreshold`                    | Success threshold for livenessProbe                                                                                                                                                                                                 | `1`                                        |
| `vmselect.readinessProbe.enabled`                            | Enable readinessProbe on VictoriaMetrics Select containers                                                                                                                                                                          | `true`                                     |
| `vmselect.readinessProbe.initialDelaySeconds`                | Initial delay seconds for readinessProbe                                                                                                                                                                                            | `5`                                        |
| `vmselect.readinessProbe.periodSeconds`                      | Period seconds for readinessProbe                                                                                                                                                                                                   | `10`                                       |
| `vmselect.readinessProbe.timeoutSeconds`                     | Timeout seconds for readinessProbe                                                                                                                                                                                                  | `5`                                        |
| `vmselect.readinessProbe.failureThreshold`                   | Failure threshold for readinessProbe                                                                                                                                                                                                | `5`                                        |
| `vmselect.readinessProbe.successThreshold`                   | Success threshold for readinessProbe                                                                                                                                                                                                | `1`                                        |
| `vmselect.startupProbe.enabled`                              | Enable startupProbe on VictoriaMetrics Select containers                                                                                                                                                                            | `false`                                    |
| `vmselect.startupProbe.initialDelaySeconds`                  | Initial delay seconds for startupProbe                                                                                                                                                                                              | `5`                                        |
| `vmselect.startupProbe.periodSeconds`                        | Period seconds for startupProbe                                                                                                                                                                                                     | `10`                                       |
| `vmselect.startupProbe.timeoutSeconds`                       | Timeout seconds for startupProbe                                                                                                                                                                                                    | `5`                                        |
| `vmselect.startupProbe.failureThreshold`                     | Failure threshold for startupProbe                                                                                                                                                                                                  | `5`                                        |
| `vmselect.startupProbe.successThreshold`                     | Success threshold for startupProbe                                                                                                                                                                                                  | `1`                                        |
| `vmselect.customLivenessProbe`                               | Custom livenessProbe that overrides the default one                                                                                                                                                                                 | `{}`                                       |
| `vmselect.customReadinessProbe`                              | Custom readinessProbe that overrides the default one                                                                                                                                                                                | `{}`                                       |
| `vmselect.customStartupProbe`                                | Custom startupProbe that overrides the default one                                                                                                                                                                                  | `{}`                                       |
| `vmselect.resourcesPreset`                                   | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if vmselect.resources is set (vmselect.resources is recommended for production). | `nano`                                     |
| `vmselect.resources`                                         | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                   | `{}`                                       |
| `vmselect.kind`                                              | Define how to deploy VictoriaMetrics Select (allowed values: deployment or statefulset)                                                                                                                                             | `deployment`                               |
| `vmselect.podManagementPolicy`                               | Pod management policy for VictoriaMetrics Storage statefulset                                                                                                                                                                       | `Parallel`                                 |
| `vmselect.annotations`                                       | Annotations for VictoriaMetrics Select Deployment or StatefulSet                                                                                                                                                                    | `{}`                                       |
| `vmselect.podSecurityContext.enabled`                        | Enabled VictoriaMetrics Select pods' Security Context                                                                                                                                                                               | `true`                                     |
| `vmselect.podSecurityContext.fsGroupChangePolicy`            | Set filesystem group change policy                                                                                                                                                                                                  | `Always`                                   |
| `vmselect.podSecurityContext.sysctls`                        | Set kernel settings using the sysctl interface                                                                                                                                                                                      | `[]`                                       |
| `vmselect.podSecurityContext.supplementalGroups`             | Set filesystem extra groups                                                                                                                                                                                                         | `[]`                                       |
| `vmselect.podSecurityContext.fsGroup`                        | Set VictoriaMetrics Select pod's Security Context fsGroup                                                                                                                                                                           | `1001`                                     |
| `vmselect.containerSecurityContext.enabled`                  | Enabled VictoriaMetrics Select containers' Security Context                                                                                                                                                                         | `true`                                     |
| `vmselect.containerSecurityContext.seLinuxOptions`           | Set SELinux options in container                                                                                                                                                                                                    | `{}`                                       |
| `vmselect.containerSecurityContext.runAsUser`                | Set containers' Security Context runAsUser                                                                                                                                                                                          | `1001`                                     |
| `vmselect.containerSecurityContext.runAsGroup`               | Set containers' Security Context runAsGroup                                                                                                                                                                                         | `1001`                                     |
| `vmselect.containerSecurityContext.runAsNonRoot`             | Set VictoriaMetrics Select containers' Security Context runAsNonRoot                                                                                                                                                                | `true`                                     |
| `vmselect.containerSecurityContext.privileged`               | Set VictoriaMetrics Select containers' Security Context privileged                                                                                                                                                                  | `false`                                    |
| `vmselect.containerSecurityContext.readOnlyRootFilesystem`   | Set VictoriaMetrics Select containers' Security Context runAsNonRoot                                                                                                                                                                | `true`                                     |
| `vmselect.containerSecurityContext.allowPrivilegeEscalation` | Set VictoriaMetrics Select container's privilege escalation                                                                                                                                                                         | `false`                                    |
| `vmselect.containerSecurityContext.capabilities.drop`        | Set VictoriaMetrics Select container's Security Context runAsNonRoot                                                                                                                                                                | `["ALL"]`                                  |
| `vmselect.containerSecurityContext.seccompProfile.type`      | Set VictoriaMetrics Select container's Security Context seccomp profile                                                                                                                                                             | `RuntimeDefault`                           |
| `vmselect.command`                                           | Override default container command (useful when using custom images)                                                                                                                                                                | `[]`                                       |
| `vmselect.args`                                              | Override default container args (useful when using custom images)                                                                                                                                                                   | `[]`                                       |
| `vmselect.extraArgs`                                         | Add extra arguments to the default command                                                                                                                                                                                          | `[]`                                       |
| `vmselect.automountServiceAccountToken`                      | Mount Service Account token in pod                                                                                                                                                                                                  | `false`                                    |
| `vmselect.hostAliases`                                       | VictoriaMetrics Select pods host aliases                                                                                                                                                                                            | `[]`                                       |
| `vmselect.podLabels`                                         | Extra labels for VictoriaMetrics Select pods                                                                                                                                                                                        | `{}`                                       |
| `vmselect.podAnnotations`                                    | Annotations for VictoriaMetrics Select pods                                                                                                                                                                                         | `{}`                                       |
| `vmselect.podAffinityPreset`                                 | Pod affinity preset. Ignored if `vmselect.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                        | `""`                                       |
| `vmselect.podAntiAffinityPreset`                             | Pod anti-affinity preset. Ignored if `vmselect.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                   | `soft`                                     |
| `vmselect.pdb.create`                                        | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                     | `true`                                     |
| `vmselect.pdb.minAvailable`                                  | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                      | `""`                                       |
| `vmselect.pdb.maxUnavailable`                                | Maximum number/percentage of pods that may be made unavailable                                                                                                                                                                      | `""`                                       |
| `vmselect.autoscaling.vpa.enabled`                           | Enable VPA for VictoriaMetrics Select pods                                                                                                                                                                                          | `false`                                    |
| `vmselect.autoscaling.vpa.annotations`                       | Annotations for VPA resource                                                                                                                                                                                                        | `{}`                                       |
| `vmselect.autoscaling.vpa.controlledResources`               | VPA List of resources that the vertical pod autoscaler can control. Defaults to cpu and memory                                                                                                                                      | `[]`                                       |
| `vmselect.autoscaling.vpa.maxAllowed`                        | VPA Max allowed resources for the pod                                                                                                                                                                                               | `{}`                                       |
| `vmselect.autoscaling.vpa.minAllowed`                        | VPA Min allowed resources for the pod                                                                                                                                                                                               | `{}`                                       |
| `vmselect.autoscaling.vpa.updatePolicy.updateMode`           | Autoscaling update policy                                                                                                                                                                                                           | `Auto`                                     |
| `vmselect.autoscaling.hpa.enabled`                           | Enable HPA for VictoriaMetrics Select pods                                                                                                                                                                                          | `false`                                    |
| `vmselect.autoscaling.hpa.minReplicas`                       | Minimum number of replicas                                                                                                                                                                                                          | `""`                                       |
| `vmselect.autoscaling.hpa.maxReplicas`                       | Maximum number of replicas                                                                                                                                                                                                          | `""`                                       |
| `vmselect.autoscaling.hpa.targetCPU`                         | Target CPU utilization percentage                                                                                                                                                                                                   | `""`                                       |
| `vmselect.autoscaling.hpa.targetMemory`                      | Target Memory utilization percentage                                                                                                                                                                                                | `""`                                       |
| `vmselect.nodeAffinityPreset.type`                           | Node affinity preset type. Ignored if `vmselect.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                  | `""`                                       |
| `vmselect.nodeAffinityPreset.key`                            | Node label key to match. Ignored if `vmselect.affinity` is set                                                                                                                                                                      | `""`                                       |
| `vmselect.nodeAffinityPreset.values`                         | Node label values to match. Ignored if `vmselect.affinity` is set                                                                                                                                                                   | `[]`                                       |
| `vmselect.affinity`                                          | Affinity for VictoriaMetrics Select pods assignment                                                                                                                                                                                 | `{}`                                       |
| `vmselect.nodeSelector`                                      | Node labels for VictoriaMetrics Select pods assignment                                                                                                                                                                              | `{}`                                       |
| `vmselect.tolerations`                                       | Tolerations for VictoriaMetrics Select pods assignment                                                                                                                                                                              | `[]`                                       |
| `vmselect.updateStrategy.type`                               | VictoriaMetrics Select statefulset strategy type                                                                                                                                                                                    | `RollingUpdate`                            |
| `vmselect.priorityClassName`                                 | VictoriaMetrics Select pods' priorityClassName                                                                                                                                                                                      | `""`                                       |
| `vmselect.topologySpreadConstraints`                         | Topology Spread Constraints for pod assignment spread across your cluster among failure-domains. Evaluated as a template                                                                                                            | `[]`                                       |
| `vmselect.schedulerName`                                     | Name of the k8s scheduler (other than default) for VictoriaMetrics Select pods                                                                                                                                                      | `""`                                       |
| `vmselect.terminationGracePeriodSeconds`                     | Seconds Redmine pod needs to terminate gracefully                                                                                                                                                                                   | `""`                                       |
| `vmselect.lifecycleHooks`                                    | for the VictoriaMetrics Select container(s) to automate configuration before or after startup                                                                                                                                       | `{}`                                       |
| `vmselect.extraEnvVars`                                      | Array with extra environment variables to add to VictoriaMetrics Select nodes                                                                                                                                                       | `[]`                                       |
| `vmselect.extraEnvVarsCM`                                    | Name of existing ConfigMap containing extra env vars for VictoriaMetrics Select nodes                                                                                                                                               | `""`                                       |
| `vmselect.extraEnvVarsSecret`                                | Name of existing Secret containing extra env vars for VictoriaMetrics Select nodes                                                                                                                                                  | `""`                                       |
| `vmselect.extraVolumes`                                      | Optionally specify extra list of additional volumes for the VictoriaMetrics Select pod(s)                                                                                                                                           | `[]`                                       |
| `vmselect.extraVolumeMounts`                                 | Optionally specify extra list of additional volumeMounts for the VictoriaMetrics Select container(s)                                                                                                                                | `[]`                                       |
| `vmselect.sidecars`                                          | Add additional sidecar containers to the VictoriaMetrics Select pod(s)                                                                                                                                                              | `[]`                                       |
| `vmselect.initContainers`                                    | Add additional init containers to the VictoriaMetrics Select pod(s)                                                                                                                                                                 | `[]`                                       |

### VictoriaMetrics Select RBAC Parameters

| Name                                                   | Description                                                      | Value   |
| ------------------------------------------------------ | ---------------------------------------------------------------- | ------- |
| `vmselect.serviceAccount.create`                       | Specifies whether a ServiceAccount should be created             | `true`  |
| `vmselect.serviceAccount.name`                         | The name of the ServiceAccount to use.                           | `""`    |
| `vmselect.serviceAccount.annotations`                  | Additional Service Account annotations (evaluated as a template) | `{}`    |
| `vmselect.serviceAccount.automountServiceAccountToken` | Automount service account token for the server service account   | `false` |

### VictoriaMetrics Select Traffic Exposure Parameters

| Name                                             | Description                                                                                                                      | Value                    |
| ------------------------------------------------ | -------------------------------------------------------------------------------------------------------------------------------- | ------------------------ |
| `vmselect.service.type`                          | VictoriaMetrics Select service type                                                                                              | `ClusterIP`              |
| `vmselect.service.ports.http`                    | VictoriaMetrics Select service http port                                                                                         | `8481`                   |
| `vmselect.service.nodePorts.http`                | Node port for HTTP                                                                                                               | `""`                     |
| `vmselect.service.clusterIP`                     | VictoriaMetrics Select service Cluster IP                                                                                        | `""`                     |
| `vmselect.service.loadBalancerIP`                | VictoriaMetrics Select service Load Balancer IP                                                                                  | `""`                     |
| `vmselect.service.loadBalancerSourceRanges`      | VictoriaMetrics Select service Load Balancer sources                                                                             | `[]`                     |
| `vmselect.service.externalTrafficPolicy`         | VictoriaMetrics Select service external traffic policy                                                                           | `Cluster`                |
| `vmselect.service.annotations`                   | Additional custom annotations for VictoriaMetrics Select service                                                                 | `{}`                     |
| `vmselect.service.extraPorts`                    | Extra ports to expose in VictoriaMetrics Select service (normally used with the `sidecars` value)                                | `[]`                     |
| `vmselect.service.sessionAffinity`               | Control where client requests go, to the same pod or round-robin                                                                 | `None`                   |
| `vmselect.service.sessionAffinityConfig`         | Additional settings for the sessionAffinity                                                                                      | `{}`                     |
| `vmselect.service.headless.annotations`          | Annotations for the headless service.                                                                                            | `{}`                     |
| `vmselect.ingress.enabled`                       | Enable ingress record generation for VictoriaMetrics Select                                                                      | `false`                  |
| `vmselect.ingress.pathType`                      | Ingress path type                                                                                                                | `ImplementationSpecific` |
| `vmselect.ingress.apiVersion`                    | Force Ingress API version (automatically detected if not set)                                                                    | `""`                     |
| `vmselect.ingress.hostname`                      | Default host for the ingress record                                                                                              | `vmselect.local`         |
| `vmselect.ingress.ingressClassName`              | IngressClass that will be be used to implement the Ingress (Kubernetes 1.18+)                                                    | `""`                     |
| `vmselect.ingress.path`                          | Default path for the ingress record                                                                                              | `/`                      |
| `vmselect.ingress.annotations`                   | Additional annotations for the Ingress resource. To enable certificate autogeneration, place here your cert-manager annotations. | `{}`                     |
| `vmselect.ingress.tls`                           | Enable TLS configuration for the host defined at `vmselect.ingress.hostname` parameter                                           | `false`                  |
| `vmselect.ingress.selfSigned`                    | Create a TLS secret for this ingress record using self-signed certificates generated by Helm                                     | `false`                  |
| `vmselect.ingress.extraHosts`                    | An array with additional hostname(s) to be covered with the ingress record                                                       | `[]`                     |
| `vmselect.ingress.extraPaths`                    | An array with additional arbitrary paths that may need to be added to the ingress under the main host                            | `[]`                     |
| `vmselect.ingress.extraTls`                      | TLS configuration for additional hostname(s) to be covered with this ingress record                                              | `[]`                     |
| `vmselect.ingress.secrets`                       | Custom TLS certificates as secrets                                                                                               | `[]`                     |
| `vmselect.ingress.extraRules`                    | Additional rules to be covered with this ingress record                                                                          | `[]`                     |
| `vmselect.networkPolicy.enabled`                 | Specifies whether a NetworkPolicy should be created                                                                              | `true`                   |
| `vmselect.networkPolicy.allowExternal`           | Don't require server label for connections                                                                                       | `true`                   |
| `vmselect.networkPolicy.allowExternalEgress`     | Allow the pod to access any range of port and all destinations.                                                                  | `true`                   |
| `vmselect.networkPolicy.extraIngress`            | Add extra ingress rules to the NetworkPolicy                                                                                     | `[]`                     |
| `vmselect.networkPolicy.extraEgress`             | Add extra ingress rules to the NetworkPolicy                                                                                     | `[]`                     |
| `vmselect.networkPolicy.ingressNSMatchLabels`    | Labels to match to allow traffic from other namespaces                                                                           | `{}`                     |
| `vmselect.networkPolicy.ingressNSPodMatchLabels` | Pod labels to match to allow traffic from other namespaces                                                                       | `{}`                     |

### VictoriaMetrics Select Metrics Parameters

| Name                                                | Description                                                                                            | Value   |
| --------------------------------------------------- | ------------------------------------------------------------------------------------------------------ | ------- |
| `vmselect.metrics.enabled`                          | Enable the export of Prometheus metrics                                                                | `false` |
| `vmselect.metrics.annotations`                      | Additional custom annotations for the service                                                          | `{}`    |
| `vmselect.metrics.serviceMonitor.enabled`           | if `true`, creates a Prometheus Operator ServiceMonitor (also requires `metrics.enabled` to be `true`) | `false` |
| `vmselect.metrics.serviceMonitor.namespace`         | Namespace in which Prometheus is running                                                               | `""`    |
| `vmselect.metrics.serviceMonitor.annotations`       | Additional custom annotations for the ServiceMonitor                                                   | `{}`    |
| `vmselect.metrics.serviceMonitor.labels`            | Extra labels for the ServiceMonitor                                                                    | `{}`    |
| `vmselect.metrics.serviceMonitor.jobLabel`          | The name of the label on the target service to use as the job name in Prometheus                       | `""`    |
| `vmselect.metrics.serviceMonitor.honorLabels`       | honorLabels chooses the metric's labels on collisions with target labels                               | `false` |
| `vmselect.metrics.serviceMonitor.interval`          | Interval at which metrics should be scraped.                                                           | `""`    |
| `vmselect.metrics.serviceMonitor.scrapeTimeout`     | Timeout after which the scrape is ended                                                                | `""`    |
| `vmselect.metrics.serviceMonitor.metricRelabelings` | Specify additional relabeling of metrics                                                               | `[]`    |
| `vmselect.metrics.serviceMonitor.relabelings`       | Specify general relabeling                                                                             | `[]`    |
| `vmselect.metrics.serviceMonitor.selector`          | Prometheus instance selector labels                                                                    | `{}`    |

### VictoriaMetrics Insert Parameters

| Name                                                         | Description                                                                                                                                                                                                                         | Value                                      |
| ------------------------------------------------------------ | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------ |
| `vminsert.image.registry`                                    | VictoriaMetrics Insert image registry                                                                                                                                                                                               | `REGISTRY_NAME`                            |
| `vminsert.image.repository`                                  | VictoriaMetrics Insert image repository                                                                                                                                                                                             | `REPOSITORY_NAME/victoriametrics-vminsert` |
| `vminsert.image.digest`                                      | VictoriaMetrics Insert image digest in the way sha256:aa.... Please note this parameter, if set, will override the tag image tag (immutable tags are recommended)                                                                   | `""`                                       |
| `vminsert.image.pullPolicy`                                  | VictoriaMetrics Insert image pull policy                                                                                                                                                                                            | `IfNotPresent`                             |
| `vminsert.image.pullSecrets`                                 | VictoriaMetrics Insert image pull secrets                                                                                                                                                                                           | `[]`                                       |
| `vminsert.replicaCount`                                      | Number of VictoriaMetrics Insert replicas to deploy                                                                                                                                                                                 | `1`                                        |
| `vminsert.containerPorts.http`                               | VictoriaMetrics Insert http container port                                                                                                                                                                                          | `8480`                                     |
| `vminsert.livenessProbe.enabled`                             | Enable livenessProbe on VictoriaMetrics Insert containers                                                                                                                                                                           | `true`                                     |
| `vminsert.livenessProbe.initialDelaySeconds`                 | Initial delay seconds for livenessProbe                                                                                                                                                                                             | `5`                                        |
| `vminsert.livenessProbe.periodSeconds`                       | Period seconds for livenessProbe                                                                                                                                                                                                    | `10`                                       |
| `vminsert.livenessProbe.timeoutSeconds`                      | Timeout seconds for livenessProbe                                                                                                                                                                                                   | `5`                                        |
| `vminsert.livenessProbe.failureThreshold`                    | Failure threshold for livenessProbe                                                                                                                                                                                                 | `5`                                        |
| `vminsert.livenessProbe.successThreshold`                    | Success threshold for livenessProbe                                                                                                                                                                                                 | `1`                                        |
| `vminsert.readinessProbe.enabled`                            | Enable readinessProbe on VictoriaMetrics Insert containers                                                                                                                                                                          | `true`                                     |
| `vminsert.readinessProbe.initialDelaySeconds`                | Initial delay seconds for readinessProbe                                                                                                                                                                                            | `5`                                        |
| `vminsert.readinessProbe.periodSeconds`                      | Period seconds for readinessProbe                                                                                                                                                                                                   | `10`                                       |
| `vminsert.readinessProbe.timeoutSeconds`                     | Timeout seconds for readinessProbe                                                                                                                                                                                                  | `5`                                        |
| `vminsert.readinessProbe.failureThreshold`                   | Failure threshold for readinessProbe                                                                                                                                                                                                | `5`                                        |
| `vminsert.readinessProbe.successThreshold`                   | Success threshold for readinessProbe                                                                                                                                                                                                | `1`                                        |
| `vminsert.startupProbe.enabled`                              | Enable startupProbe on VictoriaMetrics Insert containers                                                                                                                                                                            | `false`                                    |
| `vminsert.startupProbe.initialDelaySeconds`                  | Initial delay seconds for startupProbe                                                                                                                                                                                              | `5`                                        |
| `vminsert.startupProbe.periodSeconds`                        | Period seconds for startupProbe                                                                                                                                                                                                     | `10`                                       |
| `vminsert.startupProbe.timeoutSeconds`                       | Timeout seconds for startupProbe                                                                                                                                                                                                    | `5`                                        |
| `vminsert.startupProbe.failureThreshold`                     | Failure threshold for startupProbe                                                                                                                                                                                                  | `5`                                        |
| `vminsert.startupProbe.successThreshold`                     | Success threshold for startupProbe                                                                                                                                                                                                  | `1`                                        |
| `vminsert.customLivenessProbe`                               | Custom livenessProbe that overrides the default one                                                                                                                                                                                 | `{}`                                       |
| `vminsert.customReadinessProbe`                              | Custom readinessProbe that overrides the default one                                                                                                                                                                                | `{}`                                       |
| `vminsert.customStartupProbe`                                | Custom startupProbe that overrides the default one                                                                                                                                                                                  | `{}`                                       |
| `vminsert.resourcesPreset`                                   | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if vminsert.resources is set (vminsert.resources is recommended for production). | `nano`                                     |
| `vminsert.resources`                                         | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                   | `{}`                                       |
| `vminsert.deploymentAnnotations`                             | Annotations for VictoriaMetrics Insert Deployment                                                                                                                                                                                   | `{}`                                       |
| `vminsert.podSecurityContext.enabled`                        | Enabled VictoriaMetrics Insert pods' Security Context                                                                                                                                                                               | `true`                                     |
| `vminsert.podSecurityContext.fsGroupChangePolicy`            | Set filesystem group change policy                                                                                                                                                                                                  | `Always`                                   |
| `vminsert.podSecurityContext.sysctls`                        | Set kernel settings using the sysctl interface                                                                                                                                                                                      | `[]`                                       |
| `vminsert.podSecurityContext.supplementalGroups`             | Set filesystem extra groups                                                                                                                                                                                                         | `[]`                                       |
| `vminsert.podSecurityContext.fsGroup`                        | Set VictoriaMetrics Insert pod's Security Context fsGroup                                                                                                                                                                           | `1001`                                     |
| `vminsert.containerSecurityContext.enabled`                  | Enabled VictoriaMetrics Insert containers' Security Context                                                                                                                                                                         | `true`                                     |
| `vminsert.containerSecurityContext.seLinuxOptions`           | Set SELinux options in container                                                                                                                                                                                                    | `{}`                                       |
| `vminsert.containerSecurityContext.runAsUser`                | Set containers' Security Context runAsUser                                                                                                                                                                                          | `1001`                                     |
| `vminsert.containerSecurityContext.runAsGroup`               | Set containers' Security Context runAsGroup                                                                                                                                                                                         | `1001`                                     |
| `vminsert.containerSecurityContext.runAsNonRoot`             | Set VictoriaMetrics Insert containers' Security Context runAsNonRoot                                                                                                                                                                | `true`                                     |
| `vminsert.containerSecurityContext.privileged`               | Set VictoriaMetrics Insert containers' Security Context privileged                                                                                                                                                                  | `false`                                    |
| `vminsert.containerSecurityContext.readOnlyRootFilesystem`   | Set VictoriaMetrics Insert containers' Security Context runAsNonRoot                                                                                                                                                                | `true`                                     |
| `vminsert.containerSecurityContext.allowPrivilegeEscalation` | Set VictoriaMetrics Insert container's privilege escalation                                                                                                                                                                         | `false`                                    |
| `vminsert.containerSecurityContext.capabilities.drop`        | Set VictoriaMetrics Insert container's Security Context runAsNonRoot                                                                                                                                                                | `["ALL"]`                                  |
| `vminsert.containerSecurityContext.seccompProfile.type`      | Set VictoriaMetrics Insert container's Security Context seccomp profile                                                                                                                                                             | `RuntimeDefault`                           |
| `vminsert.command`                                           | Override default container command (useful when using custom images)                                                                                                                                                                | `[]`                                       |
| `vminsert.args`                                              | Override default container args (useful when using custom images)                                                                                                                                                                   | `[]`                                       |
| `vminsert.extraArgs`                                         | Add extra arguments to the default command                                                                                                                                                                                          | `[]`                                       |
| `vminsert.automountServiceAccountToken`                      | Mount Service Account token in pod                                                                                                                                                                                                  | `false`                                    |
| `vminsert.hostAliases`                                       | VictoriaMetrics Insert pods host aliases                                                                                                                                                                                            | `[]`                                       |
| `vminsert.podLabels`                                         | Extra labels for VictoriaMetrics Insert pods                                                                                                                                                                                        | `{}`                                       |
| `vminsert.podAnnotations`                                    | Annotations for VictoriaMetrics Insert pods                                                                                                                                                                                         | `{}`                                       |
| `vminsert.podAffinityPreset`                                 | Pod affinity preset. Ignored if `vminsert.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                        | `""`                                       |
| `vminsert.podAntiAffinityPreset`                             | Pod anti-affinity preset. Ignored if `vminsert.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                   | `soft`                                     |
| `vminsert.pdb.create`                                        | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                     | `true`                                     |
| `vminsert.pdb.minAvailable`                                  | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                      | `""`                                       |
| `vminsert.pdb.maxUnavailable`                                | Maximum number/percentage of pods that may be made unavailable                                                                                                                                                                      | `""`                                       |
| `vminsert.autoscaling.vpa.enabled`                           | Enable VPA for VictoriaMetrics Insert pods                                                                                                                                                                                          | `false`                                    |
| `vminsert.autoscaling.vpa.annotations`                       | Annotations for VPA resource                                                                                                                                                                                                        | `{}`                                       |
| `vminsert.autoscaling.vpa.controlledResources`               | VPA List of resources that the vertical pod autoscaler can control. Defaults to cpu and memory                                                                                                                                      | `[]`                                       |
| `vminsert.autoscaling.vpa.maxAllowed`                        | VPA Max allowed resources for the pod                                                                                                                                                                                               | `{}`                                       |
| `vminsert.autoscaling.vpa.minAllowed`                        | VPA Min allowed resources for the pod                                                                                                                                                                                               | `{}`                                       |
| `vminsert.autoscaling.vpa.updatePolicy.updateMode`           | Autoscaling update policy                                                                                                                                                                                                           | `Auto`                                     |
| `vminsert.autoscaling.hpa.enabled`                           | Enable HPA for VictoriaMetrics Insert pods                                                                                                                                                                                          | `false`                                    |
| `vminsert.autoscaling.hpa.minReplicas`                       | Minimum number of replicas                                                                                                                                                                                                          | `""`                                       |
| `vminsert.autoscaling.hpa.maxReplicas`                       | Maximum number of replicas                                                                                                                                                                                                          | `""`                                       |
| `vminsert.autoscaling.hpa.targetCPU`                         | Target CPU utilization percentage                                                                                                                                                                                                   | `""`                                       |
| `vminsert.autoscaling.hpa.targetMemory`                      | Target Memory utilization percentage                                                                                                                                                                                                | `""`                                       |
| `vminsert.nodeAffinityPreset.type`                           | Node affinity preset type. Ignored if `vminsert.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                  | `""`                                       |
| `vminsert.nodeAffinityPreset.key`                            | Node label key to match. Ignored if `vminsert.affinity` is set                                                                                                                                                                      | `""`                                       |
| `vminsert.nodeAffinityPreset.values`                         | Node label values to match. Ignored if `vminsert.affinity` is set                                                                                                                                                                   | `[]`                                       |
| `vminsert.affinity`                                          | Affinity for VictoriaMetrics Insert pods assignment                                                                                                                                                                                 | `{}`                                       |
| `vminsert.nodeSelector`                                      | Node labels for VictoriaMetrics Insert pods assignment                                                                                                                                                                              | `{}`                                       |
| `vminsert.tolerations`                                       | Tolerations for VictoriaMetrics Insert pods assignment                                                                                                                                                                              | `[]`                                       |
| `vminsert.updateStrategy.type`                               | VictoriaMetrics Insert statefulset strategy type                                                                                                                                                                                    | `RollingUpdate`                            |
| `vminsert.priorityClassName`                                 | VictoriaMetrics Insert pods' priorityClassName                                                                                                                                                                                      | `""`                                       |
| `vminsert.topologySpreadConstraints`                         | Topology Spread Constraints for pod assignment spread across your cluster among failure-domains. Evaluated as a template                                                                                                            | `[]`                                       |
| `vminsert.schedulerName`                                     | Name of the k8s scheduler (other than default) for VictoriaMetrics Insert pods                                                                                                                                                      | `""`                                       |
| `vminsert.terminationGracePeriodSeconds`                     | Seconds Redmine pod needs to terminate gracefully                                                                                                                                                                                   | `""`                                       |
| `vminsert.lifecycleHooks`                                    | for the VictoriaMetrics Insert container(s) to automate configuration before or after startup                                                                                                                                       | `{}`                                       |
| `vminsert.extraEnvVars`                                      | Array with extra environment variables to add to VictoriaMetrics Insert nodes                                                                                                                                                       | `[]`                                       |
| `vminsert.extraEnvVarsCM`                                    | Name of existing ConfigMap containing extra env vars for VictoriaMetrics Insert nodes                                                                                                                                               | `""`                                       |
| `vminsert.extraEnvVarsSecret`                                | Name of existing Secret containing extra env vars for VictoriaMetrics Insert nodes                                                                                                                                                  | `""`                                       |
| `vminsert.extraVolumes`                                      | Optionally specify extra list of additional volumes for the VictoriaMetrics Insert pod(s)                                                                                                                                           | `[]`                                       |
| `vminsert.extraVolumeMounts`                                 | Optionally specify extra list of additional volumeMounts for the VictoriaMetrics Insert container(s)                                                                                                                                | `[]`                                       |
| `vminsert.sidecars`                                          | Add additional sidecar containers to the VictoriaMetrics Insert pod(s)                                                                                                                                                              | `[]`                                       |
| `vminsert.initContainers`                                    | Add additional init containers to the VictoriaMetrics Insert pod(s)                                                                                                                                                                 | `[]`                                       |
| `vminsert.serviceAccount.create`                             | Specifies whether a ServiceAccount should be created                                                                                                                                                                                | `true`                                     |
| `vminsert.serviceAccount.name`                               | The name of the ServiceAccount to use.                                                                                                                                                                                              | `""`                                       |
| `vminsert.serviceAccount.annotations`                        | Additional Service Account annotations (evaluated as a template)                                                                                                                                                                    | `{}`                                       |
| `vminsert.serviceAccount.automountServiceAccountToken`       | Automount service account token for the server service account                                                                                                                                                                      | `false`                                    |

### VictoriaMetrics Insert Traffic Exposure Parameters

| Name                                             | Description                                                                                                                      | Value                    |
| ------------------------------------------------ | -------------------------------------------------------------------------------------------------------------------------------- | ------------------------ |
| `vminsert.service.type`                          | VictoriaMetrics Insert service type                                                                                              | `ClusterIP`              |
| `vminsert.service.ports.http`                    | VictoriaMetrics Insert service http port                                                                                         | `8480`                   |
| `vminsert.service.nodePorts.http`                | Node port for HTTP                                                                                                               | `""`                     |
| `vminsert.service.clusterIP`                     | VictoriaMetrics Insert service Cluster IP                                                                                        | `""`                     |
| `vminsert.service.loadBalancerIP`                | VictoriaMetrics Insert service Load Balancer IP                                                                                  | `""`                     |
| `vminsert.service.loadBalancerSourceRanges`      | VictoriaMetrics Insert service Load Balancer sources                                                                             | `[]`                     |
| `vminsert.service.externalTrafficPolicy`         | VictoriaMetrics Insert service external traffic policy                                                                           | `Cluster`                |
| `vminsert.service.annotations`                   | Additional custom annotations for VictoriaMetrics Insert service                                                                 | `{}`                     |
| `vminsert.service.extraPorts`                    | Extra ports to expose in VictoriaMetrics Insert service (normally used with the `sidecars` value)                                | `[]`                     |
| `vminsert.service.sessionAffinity`               | Control where client requests go, to the same pod or round-robin                                                                 | `None`                   |
| `vminsert.service.sessionAffinityConfig`         | Additional settings for the sessionAffinity                                                                                      | `{}`                     |
| `vminsert.ingress.enabled`                       | Enable ingress record generation for VictoriaMetrics Insert                                                                      | `false`                  |
| `vminsert.ingress.pathType`                      | Ingress path type                                                                                                                | `ImplementationSpecific` |
| `vminsert.ingress.apiVersion`                    | Force Ingress API version (automatically detected if not set)                                                                    | `""`                     |
| `vminsert.ingress.hostname`                      | Default host for the ingress record                                                                                              | `vminsert.local`         |
| `vminsert.ingress.ingressClassName`              | IngressClass that will be be used to implement the Ingress (Kubernetes 1.18+)                                                    | `""`                     |
| `vminsert.ingress.path`                          | Default path for the ingress record                                                                                              | `/`                      |
| `vminsert.ingress.annotations`                   | Additional annotations for the Ingress resource. To enable certificate autogeneration, place here your cert-manager annotations. | `{}`                     |
| `vminsert.ingress.tls`                           | Enable TLS configuration for the host defined at `vminsert.ingress.hostname` parameter                                           | `false`                  |
| `vminsert.ingress.selfSigned`                    | Create a TLS secret for this ingress record using self-signed certificates generated by Helm                                     | `false`                  |
| `vminsert.ingress.extraHosts`                    | An array with additional hostname(s) to be covered with the ingress record                                                       | `[]`                     |
| `vminsert.ingress.extraPaths`                    | An array with additional arbitrary paths that may need to be added to the ingress under the main host                            | `[]`                     |
| `vminsert.ingress.extraTls`                      | TLS configuration for additional hostname(s) to be covered with this ingress record                                              | `[]`                     |
| `vminsert.ingress.secrets`                       | Custom TLS certificates as secrets                                                                                               | `[]`                     |
| `vminsert.ingress.extraRules`                    | Additional rules to be covered with this ingress record                                                                          | `[]`                     |
| `vminsert.networkPolicy.enabled`                 | Specifies whether a NetworkPolicy should be created                                                                              | `true`                   |
| `vminsert.networkPolicy.allowExternal`           | Don't require server label for connections                                                                                       | `true`                   |
| `vminsert.networkPolicy.allowExternalEgress`     | Allow the pod to access any range of port and all destinations.                                                                  | `true`                   |
| `vminsert.networkPolicy.extraIngress`            | Add extra ingress rules to the NetworkPolicy                                                                                     | `[]`                     |
| `vminsert.networkPolicy.extraEgress`             | Add extra ingress rules to the NetworkPolicy                                                                                     | `[]`                     |
| `vminsert.networkPolicy.ingressNSMatchLabels`    | Labels to match to allow traffic from other namespaces                                                                           | `{}`                     |
| `vminsert.networkPolicy.ingressNSPodMatchLabels` | Pod labels to match to allow traffic from other namespaces                                                                       | `{}`                     |

### VictoriaMetrics Insert Metrics Parameters

| Name                                                | Description                                                                                            | Value   |
| --------------------------------------------------- | ------------------------------------------------------------------------------------------------------ | ------- |
| `vminsert.metrics.enabled`                          | Enable the export of Prometheus metrics                                                                | `false` |
| `vminsert.metrics.annotations`                      | Additional custom annotations for the service                                                          | `{}`    |
| `vminsert.metrics.serviceMonitor.enabled`           | if `true`, creates a Prometheus Operator ServiceMonitor (also requires `metrics.enabled` to be `true`) | `false` |
| `vminsert.metrics.serviceMonitor.namespace`         | Namespace in which Prometheus is running                                                               | `""`    |
| `vminsert.metrics.serviceMonitor.annotations`       | Additional custom annotations for the ServiceMonitor                                                   | `{}`    |
| `vminsert.metrics.serviceMonitor.labels`            | Extra labels for the ServiceMonitor                                                                    | `{}`    |
| `vminsert.metrics.serviceMonitor.jobLabel`          | The name of the label on the target service to use as the job name in Prometheus                       | `""`    |
| `vminsert.metrics.serviceMonitor.honorLabels`       | honorLabels chooses the metric's labels on collisions with target labels                               | `false` |
| `vminsert.metrics.serviceMonitor.interval`          | Interval at which metrics should be scraped.                                                           | `""`    |
| `vminsert.metrics.serviceMonitor.scrapeTimeout`     | Timeout after which the scrape is ended                                                                | `""`    |
| `vminsert.metrics.serviceMonitor.metricRelabelings` | Specify additional relabeling of metrics                                                               | `[]`    |
| `vminsert.metrics.serviceMonitor.relabelings`       | Specify general relabeling                                                                             | `[]`    |
| `vminsert.metrics.serviceMonitor.selector`          | Prometheus instance selector labels                                                                    | `{}`    |

### VictoriaMetrics Storage Parameters

| Name                                                          | Description                                                                                                                                                                                                                           | Value                                       |
| ------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------- |
| `vmstorage.image.registry`                                    | VictoriaMetrics Storage image registry                                                                                                                                                                                                | `REGISTRY_NAME`                             |
| `vmstorage.image.repository`                                  | VictoriaMetrics Storage image repository                                                                                                                                                                                              | `REPOSITORY_NAME/victoriametrics-vmstorage` |
| `vmstorage.image.digest`                                      | VictoriaMetrics Storage image digest in the way sha256:aa.... Please note this parameter, if set, will override the tag image tag (immutable tags are recommended)                                                                    | `""`                                        |
| `vmstorage.image.pullPolicy`                                  | VictoriaMetrics Storage image pull policy                                                                                                                                                                                             | `IfNotPresent`                              |
| `vmstorage.image.pullSecrets`                                 | VictoriaMetrics Storage image pull secrets                                                                                                                                                                                            | `[]`                                        |
| `vmstorage.replicaCount`                                      | Number of VictoriaMetrics Storage replicas to deploy                                                                                                                                                                                  | `1`                                         |
| `vmstorage.containerPorts.http`                               | VictoriaMetrics Storage http container port                                                                                                                                                                                           | `8482`                                      |
| `vmstorage.containerPorts.vmselect`                           | VictoriaMetrics Storage vmselect container port                                                                                                                                                                                       | `8401`                                      |
| `vmstorage.containerPorts.vminsert`                           | VictoriaMetrics Storage vminsert container port                                                                                                                                                                                       | `8400`                                      |
| `vmstorage.livenessProbe.enabled`                             | Enable livenessProbe on VictoriaMetrics Storage containers                                                                                                                                                                            | `true`                                      |
| `vmstorage.livenessProbe.initialDelaySeconds`                 | Initial delay seconds for livenessProbe                                                                                                                                                                                               | `5`                                         |
| `vmstorage.livenessProbe.periodSeconds`                       | Period seconds for livenessProbe                                                                                                                                                                                                      | `10`                                        |
| `vmstorage.livenessProbe.timeoutSeconds`                      | Timeout seconds for livenessProbe                                                                                                                                                                                                     | `5`                                         |
| `vmstorage.livenessProbe.failureThreshold`                    | Failure threshold for livenessProbe                                                                                                                                                                                                   | `5`                                         |
| `vmstorage.livenessProbe.successThreshold`                    | Success threshold for livenessProbe                                                                                                                                                                                                   | `1`                                         |
| `vmstorage.readinessProbe.enabled`                            | Enable readinessProbe on VictoriaMetrics Storage containers                                                                                                                                                                           | `true`                                      |
| `vmstorage.readinessProbe.initialDelaySeconds`                | Initial delay seconds for readinessProbe                                                                                                                                                                                              | `5`                                         |
| `vmstorage.readinessProbe.periodSeconds`                      | Period seconds for readinessProbe                                                                                                                                                                                                     | `10`                                        |
| `vmstorage.readinessProbe.timeoutSeconds`                     | Timeout seconds for readinessProbe                                                                                                                                                                                                    | `5`                                         |
| `vmstorage.readinessProbe.failureThreshold`                   | Failure threshold for readinessProbe                                                                                                                                                                                                  | `5`                                         |
| `vmstorage.readinessProbe.successThreshold`                   | Success threshold for readinessProbe                                                                                                                                                                                                  | `1`                                         |
| `vmstorage.startupProbe.enabled`                              | Enable startupProbe on VictoriaMetrics Storage containers                                                                                                                                                                             | `false`                                     |
| `vmstorage.startupProbe.initialDelaySeconds`                  | Initial delay seconds for startupProbe                                                                                                                                                                                                | `5`                                         |
| `vmstorage.startupProbe.periodSeconds`                        | Period seconds for startupProbe                                                                                                                                                                                                       | `10`                                        |
| `vmstorage.startupProbe.timeoutSeconds`                       | Timeout seconds for startupProbe                                                                                                                                                                                                      | `5`                                         |
| `vmstorage.startupProbe.failureThreshold`                     | Failure threshold for startupProbe                                                                                                                                                                                                    | `5`                                         |
| `vmstorage.startupProbe.successThreshold`                     | Success threshold for startupProbe                                                                                                                                                                                                    | `1`                                         |
| `vmstorage.customLivenessProbe`                               | Custom livenessProbe that overrides the default one                                                                                                                                                                                   | `{}`                                        |
| `vmstorage.customReadinessProbe`                              | Custom readinessProbe that overrides the default one                                                                                                                                                                                  | `{}`                                        |
| `vmstorage.customStartupProbe`                                | Custom startupProbe that overrides the default one                                                                                                                                                                                    | `{}`                                        |
| `vmstorage.resourcesPreset`                                   | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if vmstorage.resources is set (vmstorage.resources is recommended for production). | `small`                                     |
| `vmstorage.resources`                                         | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                     | `{}`                                        |
| `vmstorage.retentionPeriod`                                   | Data retention period                                                                                                                                                                                                                 | `1`                                         |
| `vmstorage.statefulsetAnnotations`                            | Annotations for VictoriaMetrics Storage statefulset                                                                                                                                                                                   | `{}`                                        |
| `vmstorage.podSecurityContext.enabled`                        | Enabled VictoriaMetrics Storage pods' Security Context                                                                                                                                                                                | `true`                                      |
| `vmstorage.podSecurityContext.fsGroupChangePolicy`            | Set filesystem group change policy                                                                                                                                                                                                    | `Always`                                    |
| `vmstorage.podSecurityContext.sysctls`                        | Set kernel settings using the sysctl interface                                                                                                                                                                                        | `[]`                                        |
| `vmstorage.podSecurityContext.supplementalGroups`             | Set filesystem extra groups                                                                                                                                                                                                           | `[]`                                        |
| `vmstorage.podSecurityContext.fsGroup`                        | Set VictoriaMetrics Storage pod's Security Context fsGroup                                                                                                                                                                            | `1001`                                      |
| `vmstorage.containerSecurityContext.enabled`                  | Enabled VictoriaMetrics Storage containers' Security Context                                                                                                                                                                          | `true`                                      |
| `vmstorage.containerSecurityContext.seLinuxOptions`           | Set SELinux options in container                                                                                                                                                                                                      | `{}`                                        |
| `vmstorage.containerSecurityContext.runAsUser`                | Set containers' Security Context runAsUser                                                                                                                                                                                            | `1001`                                      |
| `vmstorage.containerSecurityContext.runAsGroup`               | Set containers' Security Context runAsGroup                                                                                                                                                                                           | `1001`                                      |
| `vmstorage.containerSecurityContext.runAsNonRoot`             | Set VictoriaMetrics Storage containers' Security Context runAsNonRoot                                                                                                                                                                 | `true`                                      |
| `vmstorage.containerSecurityContext.privileged`               | Set VictoriaMetrics Storage containers' Security Context privileged                                                                                                                                                                   | `false`                                     |
| `vmstorage.containerSecurityContext.readOnlyRootFilesystem`   | Set VictoriaMetrics Storage containers' Security Context runAsNonRoot                                                                                                                                                                 | `true`                                      |
| `vmstorage.containerSecurityContext.allowPrivilegeEscalation` | Set VictoriaMetrics Storage container's privilege escalation                                                                                                                                                                          | `false`                                     |
| `vmstorage.containerSecurityContext.capabilities.drop`        | Set VictoriaMetrics Storage container's Security Context runAsNonRoot                                                                                                                                                                 | `["ALL"]`                                   |
| `vmstorage.containerSecurityContext.seccompProfile.type`      | Set VictoriaMetrics Storage container's Security Context seccomp profile                                                                                                                                                              | `RuntimeDefault`                            |
| `vmstorage.command`                                           | Override default container command (useful when using custom images)                                                                                                                                                                  | `[]`                                        |
| `vmstorage.args`                                              | Override default container args (useful when using custom images)                                                                                                                                                                     | `[]`                                        |
| `vmstorage.extraArgs`                                         | Add extra arguments to the default command                                                                                                                                                                                            | `[]`                                        |
| `vmstorage.automountServiceAccountToken`                      | Mount Service Account token in pod                                                                                                                                                                                                    | `false`                                     |
| `vmstorage.hostAliases`                                       | VictoriaMetrics Storage pods host aliases                                                                                                                                                                                             | `[]`                                        |
| `vmstorage.podLabels`                                         | Extra labels for VictoriaMetrics Storage pods                                                                                                                                                                                         | `{}`                                        |
| `vmstorage.podAnnotations`                                    | Annotations for VictoriaMetrics Storage pods                                                                                                                                                                                          | `{}`                                        |
| `vmstorage.podAffinityPreset`                                 | Pod affinity preset. Ignored if `vmstorage.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                         | `""`                                        |
| `vmstorage.podAntiAffinityPreset`                             | Pod anti-affinity preset. Ignored if `vmstorage.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                    | `soft`                                      |
| `vmstorage.pdb.create`                                        | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                       | `true`                                      |
| `vmstorage.pdb.minAvailable`                                  | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                        | `""`                                        |
| `vmstorage.pdb.maxUnavailable`                                | Maximum number/percentage of pods that may be made unavailable                                                                                                                                                                        | `""`                                        |
| `vmstorage.autoscaling.vpa.enabled`                           | Enable VPA for VictoriaMetrics Storage pods                                                                                                                                                                                           | `false`                                     |
| `vmstorage.autoscaling.vpa.annotations`                       | Annotations for VPA resource                                                                                                                                                                                                          | `{}`                                        |
| `vmstorage.autoscaling.vpa.controlledResources`               | VPA List of resources that the vertical pod autoscaler can control. Defaults to cpu and memory                                                                                                                                        | `[]`                                        |
| `vmstorage.autoscaling.vpa.maxAllowed`                        | VPA Max allowed resources for the pod                                                                                                                                                                                                 | `{}`                                        |
| `vmstorage.autoscaling.vpa.minAllowed`                        | VPA Min allowed resources for the pod                                                                                                                                                                                                 | `{}`                                        |
| `vmstorage.autoscaling.vpa.updatePolicy.updateMode`           | Autoscaling update policy                                                                                                                                                                                                             | `Auto`                                      |
| `vmstorage.autoscaling.hpa.enabled`                           | Enable HPA for VictoriaMetrics Storage pods                                                                                                                                                                                           | `false`                                     |
| `vmstorage.autoscaling.hpa.minReplicas`                       | Minimum number of replicas                                                                                                                                                                                                            | `""`                                        |
| `vmstorage.autoscaling.hpa.maxReplicas`                       | Maximum number of replicas                                                                                                                                                                                                            | `""`                                        |
| `vmstorage.autoscaling.hpa.targetCPU`                         | Target CPU utilization percentage                                                                                                                                                                                                     | `""`                                        |
| `vmstorage.autoscaling.hpa.targetMemory`                      | Target Memory utilization percentage                                                                                                                                                                                                  | `""`                                        |
| `vmstorage.nodeAffinityPreset.type`                           | Node affinity preset type. Ignored if `vmstorage.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                   | `""`                                        |
| `vmstorage.nodeAffinityPreset.key`                            | Node label key to match. Ignored if `vmstorage.affinity` is set                                                                                                                                                                       | `""`                                        |
| `vmstorage.nodeAffinityPreset.values`                         | Node label values to match. Ignored if `vmstorage.affinity` is set                                                                                                                                                                    | `[]`                                        |
| `vmstorage.affinity`                                          | Affinity for VictoriaMetrics Storage pods assignment                                                                                                                                                                                  | `{}`                                        |
| `vmstorage.nodeSelector`                                      | Node labels for VictoriaMetrics Storage pods assignment                                                                                                                                                                               | `{}`                                        |
| `vmstorage.podManagementPolicy`                               | Pod management policy for VictoriaMetrics Storage statefulset                                                                                                                                                                         | `Parallel`                                  |
| `vmstorage.tolerations`                                       | Tolerations for VictoriaMetrics Storage pods assignment                                                                                                                                                                               | `[]`                                        |
| `vmstorage.updateStrategy.type`                               | VictoriaMetrics Storage statefulset strategy type                                                                                                                                                                                     | `RollingUpdate`                             |
| `vmstorage.priorityClassName`                                 | VictoriaMetrics Storage pods' priorityClassName                                                                                                                                                                                       | `""`                                        |
| `vmstorage.topologySpreadConstraints`                         | Topology Spread Constraints for pod assignment spread across your cluster among failure-domains. Evaluated as a template                                                                                                              | `[]`                                        |
| `vmstorage.schedulerName`                                     | Name of the k8s scheduler (other than default) for VictoriaMetrics Storage pods                                                                                                                                                       | `""`                                        |
| `vmstorage.terminationGracePeriodSeconds`                     | Seconds Redmine pod needs to terminate gracefully                                                                                                                                                                                     | `""`                                        |
| `vmstorage.lifecycleHooks`                                    | for the VictoriaMetrics Storage container(s) to automate configuration before or after startup                                                                                                                                        | `{}`                                        |
| `vmstorage.extraEnvVars`                                      | Array with extra environment variables to add to VictoriaMetrics Storage nodes                                                                                                                                                        | `[]`                                        |
| `vmstorage.extraEnvVarsCM`                                    | Name of existing ConfigMap containing extra env vars for VictoriaMetrics Storage nodes                                                                                                                                                | `""`                                        |
| `vmstorage.extraEnvVarsSecret`                                | Name of existing Secret containing extra env vars for VictoriaMetrics Storage nodes                                                                                                                                                   | `""`                                        |
| `vmstorage.extraVolumes`                                      | Optionally specify extra list of additional volumes for the VictoriaMetrics Storage pod(s)                                                                                                                                            | `[]`                                        |
| `vmstorage.extraVolumeMounts`                                 | Optionally specify extra list of additional volumeMounts for the VictoriaMetrics Storage container(s)                                                                                                                                 | `[]`                                        |
| `vmstorage.sidecars`                                          | Add additional sidecar containers to the VictoriaMetrics Storage pod(s)                                                                                                                                                               | `[]`                                        |
| `vmstorage.initContainers`                                    | Add additional init containers to the VictoriaMetrics Storage pod(s)                                                                                                                                                                  | `[]`                                        |
| `vmstorage.serviceAccount.create`                             | Specifies whether a ServiceAccount should be created                                                                                                                                                                                  | `true`                                      |
| `vmstorage.serviceAccount.name`                               | The name of the ServiceAccount to use.                                                                                                                                                                                                | `""`                                        |
| `vmstorage.serviceAccount.annotations`                        | Additional Service Account annotations (evaluated as a template)                                                                                                                                                                      | `{}`                                        |
| `vmstorage.serviceAccount.automountServiceAccountToken`       | Automount service account token for the server service account                                                                                                                                                                        | `false`                                     |

### VictoriaMetrics Storage Traffic Exposure Parameters

| Name                                              | Description                                                                                        | Value       |
| ------------------------------------------------- | -------------------------------------------------------------------------------------------------- | ----------- |
| `vmstorage.service.type`                          | VictoriaMetrics Storage service type                                                               | `ClusterIP` |
| `vmstorage.service.ports.http`                    | VictoriaMetrics Storage service http port                                                          | `80`        |
| `vmstorage.service.nodePorts.http`                | Node port for HTTP                                                                                 | `""`        |
| `vmstorage.service.clusterIP`                     | VictoriaMetrics Storage service Cluster IP                                                         | `""`        |
| `vmstorage.service.loadBalancerIP`                | VictoriaMetrics Storage service Load Balancer IP                                                   | `""`        |
| `vmstorage.service.loadBalancerSourceRanges`      | VictoriaMetrics Storage service Load Balancer sources                                              | `[]`        |
| `vmstorage.service.externalTrafficPolicy`         | VictoriaMetrics Storage service external traffic policy                                            | `Cluster`   |
| `vmstorage.service.annotations`                   | Additional custom annotations for VictoriaMetrics Storage service                                  | `{}`        |
| `vmstorage.service.extraPorts`                    | Extra ports to expose in VictoriaMetrics Storage service (normally used with the `sidecars` value) | `[]`        |
| `vmstorage.service.sessionAffinity`               | Control where client requests go, to the same pod or round-robin                                   | `None`      |
| `vmstorage.service.sessionAffinityConfig`         | Additional settings for the sessionAffinity                                                        | `{}`        |
| `vmstorage.service.headless.annotations`          | Annotations for the headless service.                                                              | `{}`        |
| `vmstorage.networkPolicy.enabled`                 | Specifies whether a NetworkPolicy should be created                                                | `true`      |
| `vmstorage.networkPolicy.allowExternal`           | Don't require server label for connections                                                         | `true`      |
| `vmstorage.networkPolicy.allowExternalEgress`     | Allow the pod to access any range of port and all destinations.                                    | `true`      |
| `vmstorage.networkPolicy.extraIngress`            | Add extra ingress rules to the NetworkPolicy                                                       | `[]`        |
| `vmstorage.networkPolicy.extraEgress`             | Add extra ingress rules to the NetworkPolicy                                                       | `[]`        |
| `vmstorage.networkPolicy.ingressNSMatchLabels`    | Labels to match to allow traffic from other namespaces                                             | `{}`        |
| `vmstorage.networkPolicy.ingressNSPodMatchLabels` | Pod labels to match to allow traffic from other namespaces                                         | `{}`        |

### VictoriaMetrics Storage Persistence Parameters

| Name                                              | Description                                                                             | Value   |
| ------------------------------------------------- | --------------------------------------------------------------------------------------- | ------- |
| `vmstorage.persistence.enabled`                   | Enable persistence using Persistent Volume Claims                                       | `true`  |
| `vmstorage.persistence.mountPath`                 | Persistent Volume mount root path                                                       | `/data` |
| `vmstorage.persistence.storageClass`              | Persistent Volume storage class                                                         | `""`    |
| `vmstorage.persistence.accessModes`               | Persistent Volume access modes                                                          | `[]`    |
| `vmstorage.persistence.size`                      | Persistent Volume size                                                                  | `10Gi`  |
| `vmstorage.persistence.dataSource`                | Custom PVC data source                                                                  | `{}`    |
| `vmstorage.persistence.annotations`               | Annotations for the PVC                                                                 | `{}`    |
| `vmstorage.persistence.selector`                  | Selector to match an existing Persistent Volume (this value is evaluated as a template) | `{}`    |
| `vmstorage.persistence.existingClaim`             | The name of an existing PVC to use for persistence                                      | `""`    |
| `vmstorage.persistence.extraVolumeClaimTemplates` | Add additional VolumeClaimTemplates for enabling any plugins or any other purpose       | `[]`    |

### VictoriaMetrics Storage Metrics Parameters

| Name                                                 | Description                                                                                            | Value   |
| ---------------------------------------------------- | ------------------------------------------------------------------------------------------------------ | ------- |
| `vmstorage.metrics.enabled`                          | Enable the export of Prometheus metrics                                                                | `false` |
| `vmstorage.metrics.annotations`                      | Additional custom annotations for the service                                                          | `{}`    |
| `vmstorage.metrics.serviceMonitor.enabled`           | if `true`, creates a Prometheus Operator ServiceMonitor (also requires `metrics.enabled` to be `true`) | `false` |
| `vmstorage.metrics.serviceMonitor.namespace`         | Namespace in which Prometheus is running                                                               | `""`    |
| `vmstorage.metrics.serviceMonitor.annotations`       | Additional custom annotations for the ServiceMonitor                                                   | `{}`    |
| `vmstorage.metrics.serviceMonitor.labels`            | Extra labels for the ServiceMonitor                                                                    | `{}`    |
| `vmstorage.metrics.serviceMonitor.jobLabel`          | The name of the label on the target service to use as the job name in Prometheus                       | `""`    |
| `vmstorage.metrics.serviceMonitor.honorLabels`       | honorLabels chooses the metric's labels on collisions with target labels                               | `false` |
| `vmstorage.metrics.serviceMonitor.interval`          | Interval at which metrics should be scraped.                                                           | `""`    |
| `vmstorage.metrics.serviceMonitor.scrapeTimeout`     | Timeout after which the scrape is ended                                                                | `""`    |
| `vmstorage.metrics.serviceMonitor.metricRelabelings` | Specify additional relabeling of metrics                                                               | `[]`    |
| `vmstorage.metrics.serviceMonitor.relabelings`       | Specify general relabeling                                                                             | `[]`    |
| `vmstorage.metrics.serviceMonitor.selector`          | Prometheus instance selector labels                                                                    | `{}`    |

### VictoriaMetrics Auth Parameters

| Name                                                       | Description                                                                                                                                                                                                                     | Value                                    |
| ---------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ---------------------------------------- |
| `vmauth.enabled`                                           | Enable VictoriaMetrics Auth                                                                                                                                                                                                     | `true`                                   |
| `vmauth.image.registry`                                    | VictoriaMetrics Auth image registry                                                                                                                                                                                             | `REGISTRY_NAME`                          |
| `vmauth.image.repository`                                  | VictoriaMetrics Auth image repository                                                                                                                                                                                           | `REPOSITORY_NAME/victoriametrics-vmauth` |
| `vmauth.image.digest`                                      | VictoriaMetrics Auth image digest in the way sha256:aa.... Please note this parameter, if set, will override the tag image tag (immutable tags are recommended)                                                                 | `""`                                     |
| `vmauth.image.pullPolicy`                                  | VictoriaMetrics Auth image pull policy                                                                                                                                                                                          | `IfNotPresent`                           |
| `vmauth.image.pullSecrets`                                 | VictoriaMetrics Auth image pull secrets                                                                                                                                                                                         | `[]`                                     |
| `vmauth.replicaCount`                                      | Number of VictoriaMetrics Auth replicas to deploy                                                                                                                                                                               | `1`                                      |
| `vmauth.containerPorts.http`                               | VictoriaMetrics Auth http container port                                                                                                                                                                                        | `8427`                                   |
| `vmauth.livenessProbe.enabled`                             | Enable livenessProbe on VictoriaMetrics Auth containers                                                                                                                                                                         | `true`                                   |
| `vmauth.livenessProbe.initialDelaySeconds`                 | Initial delay seconds for livenessProbe                                                                                                                                                                                         | `5`                                      |
| `vmauth.livenessProbe.periodSeconds`                       | Period seconds for livenessProbe                                                                                                                                                                                                | `10`                                     |
| `vmauth.livenessProbe.timeoutSeconds`                      | Timeout seconds for livenessProbe                                                                                                                                                                                               | `5`                                      |
| `vmauth.livenessProbe.failureThreshold`                    | Failure threshold for livenessProbe                                                                                                                                                                                             | `5`                                      |
| `vmauth.livenessProbe.successThreshold`                    | Success threshold for livenessProbe                                                                                                                                                                                             | `1`                                      |
| `vmauth.readinessProbe.enabled`                            | Enable readinessProbe on VictoriaMetrics Auth containers                                                                                                                                                                        | `true`                                   |
| `vmauth.readinessProbe.initialDelaySeconds`                | Initial delay seconds for readinessProbe                                                                                                                                                                                        | `5`                                      |
| `vmauth.readinessProbe.periodSeconds`                      | Period seconds for readinessProbe                                                                                                                                                                                               | `10`                                     |
| `vmauth.readinessProbe.timeoutSeconds`                     | Timeout seconds for readinessProbe                                                                                                                                                                                              | `5`                                      |
| `vmauth.readinessProbe.failureThreshold`                   | Failure threshold for readinessProbe                                                                                                                                                                                            | `5`                                      |
| `vmauth.readinessProbe.successThreshold`                   | Success threshold for readinessProbe                                                                                                                                                                                            | `1`                                      |
| `vmauth.startupProbe.enabled`                              | Enable startupProbe on VictoriaMetrics Auth containers                                                                                                                                                                          | `false`                                  |
| `vmauth.startupProbe.initialDelaySeconds`                  | Initial delay seconds for startupProbe                                                                                                                                                                                          | `5`                                      |
| `vmauth.startupProbe.periodSeconds`                        | Period seconds for startupProbe                                                                                                                                                                                                 | `10`                                     |
| `vmauth.startupProbe.timeoutSeconds`                       | Timeout seconds for startupProbe                                                                                                                                                                                                | `5`                                      |
| `vmauth.startupProbe.failureThreshold`                     | Failure threshold for startupProbe                                                                                                                                                                                              | `5`                                      |
| `vmauth.startupProbe.successThreshold`                     | Success threshold for startupProbe                                                                                                                                                                                              | `1`                                      |
| `vmauth.customLivenessProbe`                               | Custom livenessProbe that overrides the default one                                                                                                                                                                             | `{}`                                     |
| `vmauth.customReadinessProbe`                              | Custom readinessProbe that overrides the default one                                                                                                                                                                            | `{}`                                     |
| `vmauth.customStartupProbe`                                | Custom startupProbe that overrides the default one                                                                                                                                                                              | `{}`                                     |
| `vmauth.resourcesPreset`                                   | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if vmauth.resources is set (vmauth.resources is recommended for production). | `nano`                                   |
| `vmauth.resources`                                         | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                               | `{}`                                     |
| `vmauth.kind`                                              | Define how to deploy VictoriaMetrics Auth (allowed values: deployment or daemonset)                                                                                                                                             | `deployment`                             |
| `vmauth.annotations`                                       | Annotations for VictoriaMetrics Auth Deployment or StatefulSet                                                                                                                                                                  | `{}`                                     |
| `vmauth.podSecurityContext.enabled`                        | Enabled VictoriaMetrics Auth pods' Security Context                                                                                                                                                                             | `true`                                   |
| `vmauth.podSecurityContext.fsGroupChangePolicy`            | Set filesystem group change policy                                                                                                                                                                                              | `Always`                                 |
| `vmauth.podSecurityContext.sysctls`                        | Set kernel settings using the sysctl interface                                                                                                                                                                                  | `[]`                                     |
| `vmauth.podSecurityContext.supplementalGroups`             | Set filesystem extra groups                                                                                                                                                                                                     | `[]`                                     |
| `vmauth.podSecurityContext.fsGroup`                        | Set VictoriaMetrics Auth pod's Security Context fsGroup                                                                                                                                                                         | `1001`                                   |
| `vmauth.containerSecurityContext.enabled`                  | Enabled VictoriaMetrics Auth containers' Security Context                                                                                                                                                                       | `true`                                   |
| `vmauth.containerSecurityContext.seLinuxOptions`           | Set SELinux options in container                                                                                                                                                                                                | `{}`                                     |
| `vmauth.containerSecurityContext.runAsUser`                | Set containers' Security Context runAsUser                                                                                                                                                                                      | `1001`                                   |
| `vmauth.containerSecurityContext.runAsGroup`               | Set containers' Security Context runAsGroup                                                                                                                                                                                     | `1001`                                   |
| `vmauth.containerSecurityContext.runAsNonRoot`             | Set VictoriaMetrics Auth containers' Security Context runAsNonRoot                                                                                                                                                              | `true`                                   |
| `vmauth.containerSecurityContext.privileged`               | Set VictoriaMetrics Auth containers' Security Context privileged                                                                                                                                                                | `false`                                  |
| `vmauth.containerSecurityContext.readOnlyRootFilesystem`   | Set VictoriaMetrics Auth containers' Security Context runAsNonRoot                                                                                                                                                              | `true`                                   |
| `vmauth.containerSecurityContext.allowPrivilegeEscalation` | Set VictoriaMetrics Auth container's privilege escalation                                                                                                                                                                       | `false`                                  |
| `vmauth.containerSecurityContext.capabilities.drop`        | Set VictoriaMetrics Auth container's Security Context runAsNonRoot                                                                                                                                                              | `["ALL"]`                                |
| `vmauth.containerSecurityContext.seccompProfile.type`      | Set VictoriaMetrics Auth container's Security Context seccomp profile                                                                                                                                                           | `RuntimeDefault`                         |
| `vmauth.command`                                           | Override default container command (useful when using custom images)                                                                                                                                                            | `[]`                                     |
| `vmauth.args`                                              | Override default container args (useful when using custom images)                                                                                                                                                               | `[]`                                     |
| `vmauth.extraArgs`                                         | Add extra arguments to the default command                                                                                                                                                                                      | `[]`                                     |
| `vmauth.automountServiceAccountToken`                      | Mount Service Account token in pod                                                                                                                                                                                              | `false`                                  |
| `vmauth.hostAliases`                                       | VictoriaMetrics Auth pods host aliases                                                                                                                                                                                          | `[]`                                     |
| `vmauth.podLabels`                                         | Extra labels for VictoriaMetrics Auth pods                                                                                                                                                                                      | `{}`                                     |
| `vmauth.podAnnotations`                                    | Annotations for VictoriaMetrics Auth pods                                                                                                                                                                                       | `{}`                                     |
| `vmauth.podAffinityPreset`                                 | Pod affinity preset. Ignored if `vmauth.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                      | `""`                                     |
| `vmauth.podAntiAffinityPreset`                             | Pod anti-affinity preset. Ignored if `vmauth.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                 | `soft`                                   |
| `vmauth.pdb.create`                                        | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                 | `true`                                   |
| `vmauth.pdb.minAvailable`                                  | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                  | `""`                                     |
| `vmauth.pdb.maxUnavailable`                                | Maximum number/percentage of pods that may be made unavailable                                                                                                                                                                  | `""`                                     |
| `vmauth.configOverrides`                                   | Overwrite or add extra configuration options to the chart default                                                                                                                                                               | `{}`                                     |
| `vmauth.existingSecret`                                    | The name of an existing Secret with configuration                                                                                                                                                                               | `""`                                     |
| `vmauth.autoscaling.vpa.enabled`                           | Enable VPA for VictoriaMetrics Auth pods                                                                                                                                                                                        | `false`                                  |
| `vmauth.autoscaling.vpa.annotations`                       | Annotations for VPA resource                                                                                                                                                                                                    | `{}`                                     |
| `vmauth.autoscaling.vpa.controlledResources`               | VPA List of resources that the vertical pod autoscaler can control. Defaults to cpu and memory                                                                                                                                  | `[]`                                     |
| `vmauth.autoscaling.vpa.maxAllowed`                        | VPA Max allowed resources for the pod                                                                                                                                                                                           | `{}`                                     |
| `vmauth.autoscaling.vpa.minAllowed`                        | VPA Min allowed resources for the pod                                                                                                                                                                                           | `{}`                                     |
| `vmauth.autoscaling.vpa.updatePolicy.updateMode`           | Autoscaling update policy                                                                                                                                                                                                       | `Auto`                                   |
| `vmauth.autoscaling.hpa.enabled`                           | Enable HPA for VictoriaMetrics Auth pods                                                                                                                                                                                        | `false`                                  |
| `vmauth.autoscaling.hpa.minReplicas`                       | Minimum number of replicas                                                                                                                                                                                                      | `""`                                     |
| `vmauth.autoscaling.hpa.maxReplicas`                       | Maximum number of replicas                                                                                                                                                                                                      | `""`                                     |
| `vmauth.autoscaling.hpa.targetCPU`                         | Target CPU utilization percentage                                                                                                                                                                                               | `""`                                     |
| `vmauth.autoscaling.hpa.targetMemory`                      | Target Memory utilization percentage                                                                                                                                                                                            | `""`                                     |
| `vmauth.nodeAffinityPreset.type`                           | Node affinity preset type. Ignored if `vmauth.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                | `""`                                     |
| `vmauth.nodeAffinityPreset.key`                            | Node label key to match. Ignored if `vmauth.affinity` is set                                                                                                                                                                    | `""`                                     |
| `vmauth.nodeAffinityPreset.values`                         | Node label values to match. Ignored if `vmauth.affinity` is set                                                                                                                                                                 | `[]`                                     |
| `vmauth.affinity`                                          | Affinity for VictoriaMetrics Auth pods assignment                                                                                                                                                                               | `{}`                                     |
| `vmauth.nodeSelector`                                      | Node labels for VictoriaMetrics Auth pods assignment                                                                                                                                                                            | `{}`                                     |
| `vmauth.tolerations`                                       | Tolerations for VictoriaMetrics Auth pods assignment                                                                                                                                                                            | `[]`                                     |
| `vmauth.updateStrategy.type`                               | VictoriaMetrics Auth statefulset strategy type                                                                                                                                                                                  | `RollingUpdate`                          |
| `vmauth.priorityClassName`                                 | VictoriaMetrics Auth pods' priorityClassName                                                                                                                                                                                    | `""`                                     |
| `vmauth.topologySpreadConstraints`                         | Topology Spread Constraints for pod assignment spread across your cluster among failure-domains. Evaluated as a template                                                                                                        | `[]`                                     |
| `vmauth.schedulerName`                                     | Name of the k8s scheduler (other than default) for VictoriaMetrics Auth pods                                                                                                                                                    | `""`                                     |
| `vmauth.terminationGracePeriodSeconds`                     | Seconds Redmine pod needs to terminate gracefully                                                                                                                                                                               | `""`                                     |
| `vmauth.lifecycleHooks`                                    | for the VictoriaMetrics Auth container(s) to automate configuration before or after startup                                                                                                                                     | `{}`                                     |
| `vmauth.extraEnvVars`                                      | Array with extra environment variables to add to VictoriaMetrics Auth nodes                                                                                                                                                     | `[]`                                     |
| `vmauth.extraEnvVarsCM`                                    | Name of existing ConfigMap containing extra env vars for VictoriaMetrics Auth nodes                                                                                                                                             | `""`                                     |
| `vmauth.extraEnvVarsSecret`                                | Name of existing Secret containing extra env vars for VictoriaMetrics Auth nodes                                                                                                                                                | `""`                                     |
| `vmauth.extraVolumes`                                      | Optionally specify extra list of additional volumes for the VictoriaMetrics Auth pod(s)                                                                                                                                         | `[]`                                     |
| `vmauth.extraVolumeMounts`                                 | Optionally specify extra list of additional volumeMounts for the VictoriaMetrics Auth container(s)                                                                                                                              | `[]`                                     |
| `vmauth.sidecars`                                          | Add additional sidecar containers to the VictoriaMetrics Auth pod(s)                                                                                                                                                            | `[]`                                     |
| `vmauth.initContainers`                                    | Add additional init containers to the VictoriaMetrics Auth pod(s)                                                                                                                                                               | `[]`                                     |

### VictoriaMetrics Auth RBAC Parameters

| Name                                                 | Description                                                      | Value   |
| ---------------------------------------------------- | ---------------------------------------------------------------- | ------- |
| `vmauth.serviceAccount.create`                       | Specifies whether a ServiceAccount should be created             | `true`  |
| `vmauth.serviceAccount.name`                         | The name of the ServiceAccount to use.                           | `""`    |
| `vmauth.serviceAccount.annotations`                  | Additional Service Account annotations (evaluated as a template) | `{}`    |
| `vmauth.serviceAccount.automountServiceAccountToken` | Automount service account token for the server service account   | `false` |

### VictoriaMetrics Auth Traffic Exposure Parameters

| Name                                           | Description                                                                                                                      | Value                    |
| ---------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------- | ------------------------ |
| `vmauth.service.type`                          | VictoriaMetrics Auth service type                                                                                                | `ClusterIP`              |
| `vmauth.service.ports.http`                    | VictoriaMetrics Auth service http port                                                                                           | `8427`                   |
| `vmauth.service.nodePorts.http`                | Node port for HTTP                                                                                                               | `""`                     |
| `vmauth.service.clusterIP`                     | VictoriaMetrics Auth service Cluster IP                                                                                          | `""`                     |
| `vmauth.service.loadBalancerIP`                | VictoriaMetrics Auth service Load Balancer IP                                                                                    | `""`                     |
| `vmauth.service.loadBalancerSourceRanges`      | VictoriaMetrics Auth service Load Balancer sources                                                                               | `[]`                     |
| `vmauth.service.externalTrafficPolicy`         | VictoriaMetrics Auth service external traffic policy                                                                             | `Cluster`                |
| `vmauth.service.annotations`                   | Additional custom annotations for VictoriaMetrics Auth service                                                                   | `{}`                     |
| `vmauth.service.extraPorts`                    | Extra ports to expose in VictoriaMetrics Auth service (normally used with the `sidecars` value)                                  | `[]`                     |
| `vmauth.service.sessionAffinity`               | Control where client requests go, to the same pod or round-robin                                                                 | `None`                   |
| `vmauth.service.sessionAffinityConfig`         | Additional settings for the sessionAffinity                                                                                      | `{}`                     |
| `vmauth.ingress.enabled`                       | Enable ingress record generation for VictoriaMetrics Auth                                                                        | `false`                  |
| `vmauth.ingress.pathType`                      | Ingress path type                                                                                                                | `ImplementationSpecific` |
| `vmauth.ingress.apiVersion`                    | Force Ingress API version (automatically detected if not set)                                                                    | `""`                     |
| `vmauth.ingress.hostname`                      | Default host for the ingress record                                                                                              | `vmauth.local`           |
| `vmauth.ingress.ingressClassName`              | IngressClass that will be be used to implement the Ingress (Kubernetes 1.18+)                                                    | `""`                     |
| `vmauth.ingress.path`                          | Default path for the ingress record                                                                                              | `/`                      |
| `vmauth.ingress.annotations`                   | Additional annotations for the Ingress resource. To enable certificate autogeneration, place here your cert-manager annotations. | `{}`                     |
| `vmauth.ingress.tls`                           | Enable TLS configuration for the host defined at `vmauth.ingress.hostname` parameter                                             | `false`                  |
| `vmauth.ingress.selfSigned`                    | Create a TLS secret for this ingress record using self-signed certificates generated by Helm                                     | `false`                  |
| `vmauth.ingress.extraHosts`                    | An array with additional hostname(s) to be covered with the ingress record                                                       | `[]`                     |
| `vmauth.ingress.extraPaths`                    | An array with additional arbitrary paths that may need to be added to the ingress under the main host                            | `[]`                     |
| `vmauth.ingress.extraTls`                      | TLS configuration for additional hostname(s) to be covered with this ingress record                                              | `[]`                     |
| `vmauth.ingress.secrets`                       | Custom TLS certificates as secrets                                                                                               | `[]`                     |
| `vmauth.ingress.extraRules`                    | Additional rules to be covered with this ingress record                                                                          | `[]`                     |
| `vmauth.networkPolicy.enabled`                 | Specifies whether a NetworkPolicy should be created                                                                              | `true`                   |
| `vmauth.networkPolicy.allowExternal`           | Don't require server label for connections                                                                                       | `true`                   |
| `vmauth.networkPolicy.allowExternalEgress`     | Allow the pod to access any range of port and all destinations.                                                                  | `true`                   |
| `vmauth.networkPolicy.extraIngress`            | Add extra ingress rules to the NetworkPolicy                                                                                     | `[]`                     |
| `vmauth.networkPolicy.extraEgress`             | Add extra ingress rules to the NetworkPolicy                                                                                     | `[]`                     |
| `vmauth.networkPolicy.ingressNSMatchLabels`    | Labels to match to allow traffic from other namespaces                                                                           | `{}`                     |
| `vmauth.networkPolicy.ingressNSPodMatchLabels` | Pod labels to match to allow traffic from other namespaces                                                                       | `{}`                     |

### VictoriaMetrics Auth Metrics Parameters

| Name                                              | Description                                                                                            | Value   |
| ------------------------------------------------- | ------------------------------------------------------------------------------------------------------ | ------- |
| `vmauth.metrics.enabled`                          | Enable the export of Prometheus metrics                                                                | `false` |
| `vmauth.metrics.annotations`                      | Additional custom annotations for the service                                                          | `{}`    |
| `vmauth.metrics.serviceMonitor.enabled`           | if `true`, creates a Prometheus Operator ServiceMonitor (also requires `metrics.enabled` to be `true`) | `false` |
| `vmauth.metrics.serviceMonitor.namespace`         | Namespace in which Prometheus is running                                                               | `""`    |
| `vmauth.metrics.serviceMonitor.annotations`       | Additional custom annotations for the ServiceMonitor                                                   | `{}`    |
| `vmauth.metrics.serviceMonitor.labels`            | Extra labels for the ServiceMonitor                                                                    | `{}`    |
| `vmauth.metrics.serviceMonitor.jobLabel`          | The name of the label on the target service to use as the job name in Prometheus                       | `""`    |
| `vmauth.metrics.serviceMonitor.honorLabels`       | honorLabels chooses the metric's labels on collisions with target labels                               | `false` |
| `vmauth.metrics.serviceMonitor.interval`          | Interval at which metrics should be scraped.                                                           | `""`    |
| `vmauth.metrics.serviceMonitor.scrapeTimeout`     | Timeout after which the scrape is ended                                                                | `""`    |
| `vmauth.metrics.serviceMonitor.metricRelabelings` | Specify additional relabeling of metrics                                                               | `[]`    |
| `vmauth.metrics.serviceMonitor.relabelings`       | Specify general relabeling                                                                             | `[]`    |
| `vmauth.metrics.serviceMonitor.selector`          | Prometheus instance selector labels                                                                    | `{}`    |

### VictoriaMetrics Agent Parameters

| Name                                                        | Description                                                                                                                                                                                                                       | Value                                     |
| ----------------------------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ----------------------------------------- |
| `vmagent.enabled`                                           | Enable VictoriaMetrics Agent                                                                                                                                                                                                      | `true`                                    |
| `vmagent.image.registry`                                    | VictoriaMetrics Agent image registry                                                                                                                                                                                              | `REGISTRY_NAME`                           |
| `vmagent.image.repository`                                  | VictoriaMetrics Agent image repository                                                                                                                                                                                            | `REPOSITORY_NAME/victoriametrics-vmagent` |
| `vmagent.image.digest`                                      | VictoriaMetrics Agent image digest in the way sha256:aa.... Please note this parameter, if set, will override the tag image tag (immutable tags are recommended)                                                                  | `""`                                      |
| `vmagent.image.pullPolicy`                                  | VictoriaMetrics Agent image pull policy                                                                                                                                                                                           | `IfNotPresent`                            |
| `vmagent.image.pullSecrets`                                 | VictoriaMetrics Agent image pull secrets                                                                                                                                                                                          | `[]`                                      |
| `vmagent.replicaCount`                                      | Number of VictoriaMetrics Agent replicas to deploy                                                                                                                                                                                | `1`                                       |
| `vmagent.containerPorts.http`                               | VictoriaMetrics Agent http container port                                                                                                                                                                                         | `8429`                                    |
| `vmagent.containerPorts.graphite`                           | VictoriaMetrics Agent graphite container port                                                                                                                                                                                     | `2003`                                    |
| `vmagent.containerPorts.opentsdb`                           | VictoriaMetrics Agent opentsdb container port                                                                                                                                                                                     | `4242`                                    |
| `vmagent.containerPorts.influxdb`                           | VictoriaMetrics Agent influxdb container port                                                                                                                                                                                     | `8089`                                    |
| `vmagent.livenessProbe.enabled`                             | Enable livenessProbe on VictoriaMetrics Agent containers                                                                                                                                                                          | `true`                                    |
| `vmagent.livenessProbe.initialDelaySeconds`                 | Initial delay seconds for livenessProbe                                                                                                                                                                                           | `5`                                       |
| `vmagent.livenessProbe.periodSeconds`                       | Period seconds for livenessProbe                                                                                                                                                                                                  | `10`                                      |
| `vmagent.livenessProbe.timeoutSeconds`                      | Timeout seconds for livenessProbe                                                                                                                                                                                                 | `5`                                       |
| `vmagent.livenessProbe.failureThreshold`                    | Failure threshold for livenessProbe                                                                                                                                                                                               | `5`                                       |
| `vmagent.livenessProbe.successThreshold`                    | Success threshold for livenessProbe                                                                                                                                                                                               | `1`                                       |
| `vmagent.readinessProbe.enabled`                            | Enable readinessProbe on VictoriaMetrics Agent containers                                                                                                                                                                         | `true`                                    |
| `vmagent.readinessProbe.initialDelaySeconds`                | Initial delay seconds for readinessProbe                                                                                                                                                                                          | `5`                                       |
| `vmagent.readinessProbe.periodSeconds`                      | Period seconds for readinessProbe                                                                                                                                                                                                 | `10`                                      |
| `vmagent.readinessProbe.timeoutSeconds`                     | Timeout seconds for readinessProbe                                                                                                                                                                                                | `5`                                       |
| `vmagent.readinessProbe.failureThreshold`                   | Failure threshold for readinessProbe                                                                                                                                                                                              | `5`                                       |
| `vmagent.readinessProbe.successThreshold`                   | Success threshold for readinessProbe                                                                                                                                                                                              | `1`                                       |
| `vmagent.startupProbe.enabled`                              | Enable startupProbe on VictoriaMetrics Agent containers                                                                                                                                                                           | `false`                                   |
| `vmagent.startupProbe.initialDelaySeconds`                  | Initial delay seconds for startupProbe                                                                                                                                                                                            | `5`                                       |
| `vmagent.startupProbe.periodSeconds`                        | Period seconds for startupProbe                                                                                                                                                                                                   | `10`                                      |
| `vmagent.startupProbe.timeoutSeconds`                       | Timeout seconds for startupProbe                                                                                                                                                                                                  | `5`                                       |
| `vmagent.startupProbe.failureThreshold`                     | Failure threshold for startupProbe                                                                                                                                                                                                | `5`                                       |
| `vmagent.startupProbe.successThreshold`                     | Success threshold for startupProbe                                                                                                                                                                                                | `1`                                       |
| `vmagent.customLivenessProbe`                               | Custom livenessProbe that overrides the default one                                                                                                                                                                               | `{}`                                      |
| `vmagent.customReadinessProbe`                              | Custom readinessProbe that overrides the default one                                                                                                                                                                              | `{}`                                      |
| `vmagent.customStartupProbe`                                | Custom startupProbe that overrides the default one                                                                                                                                                                                | `{}`                                      |
| `vmagent.resourcesPreset`                                   | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if vmagent.resources is set (vmagent.resources is recommended for production). | `nano`                                    |
| `vmagent.resources`                                         | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                 | `{}`                                      |
| `vmagent.kind`                                              | Define how to deploy VictoriaMetrics Agent (allowed values: deployment or daemonset)                                                                                                                                              | `deployment`                              |
| `vmagent.annotations`                                       | Annotations for VictoriaMetrics Agent Deployment or StatefulSet                                                                                                                                                                   | `{}`                                      |
| `vmagent.podSecurityContext.enabled`                        | Enabled VictoriaMetrics Agent pods' Security Context                                                                                                                                                                              | `true`                                    |
| `vmagent.podSecurityContext.fsGroupChangePolicy`            | Set filesystem group change policy                                                                                                                                                                                                | `Always`                                  |
| `vmagent.podSecurityContext.sysctls`                        | Set kernel settings using the sysctl interface                                                                                                                                                                                    | `[]`                                      |
| `vmagent.podSecurityContext.supplementalGroups`             | Set filesystem extra groups                                                                                                                                                                                                       | `[]`                                      |
| `vmagent.podSecurityContext.fsGroup`                        | Set VictoriaMetrics Agent pod's Security Context fsGroup                                                                                                                                                                          | `1001`                                    |
| `vmagent.containerSecurityContext.enabled`                  | Enabled VictoriaMetrics Agent containers' Security Context                                                                                                                                                                        | `true`                                    |
| `vmagent.containerSecurityContext.seLinuxOptions`           | Set SELinux options in container                                                                                                                                                                                                  | `{}`                                      |
| `vmagent.containerSecurityContext.runAsUser`                | Set containers' Security Context runAsUser                                                                                                                                                                                        | `1001`                                    |
| `vmagent.containerSecurityContext.runAsGroup`               | Set containers' Security Context runAsGroup                                                                                                                                                                                       | `1001`                                    |
| `vmagent.containerSecurityContext.runAsNonRoot`             | Set VictoriaMetrics Agent containers' Security Context runAsNonRoot                                                                                                                                                               | `true`                                    |
| `vmagent.containerSecurityContext.privileged`               | Set VictoriaMetrics Agent containers' Security Context privileged                                                                                                                                                                 | `false`                                   |
| `vmagent.containerSecurityContext.readOnlyRootFilesystem`   | Set VictoriaMetrics Agent containers' Security Context runAsNonRoot                                                                                                                                                               | `true`                                    |
| `vmagent.containerSecurityContext.allowPrivilegeEscalation` | Set VictoriaMetrics Agent container's privilege escalation                                                                                                                                                                        | `false`                                   |
| `vmagent.containerSecurityContext.capabilities.drop`        | Set VictoriaMetrics Agent container's Security Context runAsNonRoot                                                                                                                                                               | `["ALL"]`                                 |
| `vmagent.containerSecurityContext.seccompProfile.type`      | Set VictoriaMetrics Agent container's Security Context seccomp profile                                                                                                                                                            | `RuntimeDefault`                          |
| `vmagent.command`                                           | Override default container command (useful when using custom images)                                                                                                                                                              | `[]`                                      |
| `vmagent.args`                                              | Override default container args (useful when using custom images)                                                                                                                                                                 | `[]`                                      |
| `vmagent.extraArgs`                                         | Add extra arguments to the default command                                                                                                                                                                                        | `[]`                                      |
| `vmagent.automountServiceAccountToken`                      | Mount Service Account token in pod                                                                                                                                                                                                | `true`                                    |
| `vmagent.hostAliases`                                       | VictoriaMetrics Agent pods host aliases                                                                                                                                                                                           | `[]`                                      |
| `vmagent.podLabels`                                         | Extra labels for VictoriaMetrics Agent pods                                                                                                                                                                                       | `{}`                                      |
| `vmagent.podAnnotations`                                    | Annotations for VictoriaMetrics Agent pods                                                                                                                                                                                        | `{}`                                      |
| `vmagent.podAffinityPreset`                                 | Pod affinity preset. Ignored if `vmagent.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                       | `""`                                      |
| `vmagent.podAntiAffinityPreset`                             | Pod anti-affinity preset. Ignored if `vmagent.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                  | `soft`                                    |
| `vmagent.pdb.create`                                        | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                   | `true`                                    |
| `vmagent.pdb.minAvailable`                                  | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                    | `""`                                      |
| `vmagent.pdb.maxUnavailable`                                | Maximum number/percentage of pods that may be made unavailable                                                                                                                                                                    | `""`                                      |
| `vmagent.scrapeConfigOverrides`                             | Overwrite or add extra scraping configuration options to the chart default                                                                                                                                                        | `{}`                                      |
| `vmagent.enableListeners.influxdb`                          | Enable influxdb listener                                                                                                                                                                                                          | `false`                                   |
| `vmagent.enableListeners.opentsdb`                          | Enable graphite listener                                                                                                                                                                                                          | `false`                                   |
| `vmagent.enableListeners.graphite`                          | Enable opentsdb listener                                                                                                                                                                                                          | `false`                                   |
| `vmagent.existingScrapeConfigMap`                           | The name of an existing ConfigMap with the scrape configuration                                                                                                                                                                   | `""`                                      |
| `vmagent.namespaced`                                        | Only scrape in the deployed namespace                                                                                                                                                                                             | `false`                                   |
| `vmagent.allowedMetricsEndpoints`                           | Allowed metrics endpoints to scrape (when not namespaced)                                                                                                                                                                         | `[]`                                      |
| `vmagent.autoscaling.vpa.enabled`                           | Enable VPA for VictoriaMetrics Agent pods                                                                                                                                                                                         | `false`                                   |
| `vmagent.autoscaling.vpa.annotations`                       | Annotations for VPA resource                                                                                                                                                                                                      | `{}`                                      |
| `vmagent.autoscaling.vpa.controlledResources`               | VPA List of resources that the vertical pod autoscaler can control. Defaults to cpu and memory                                                                                                                                    | `[]`                                      |
| `vmagent.autoscaling.vpa.maxAllowed`                        | VPA Max allowed resources for the pod                                                                                                                                                                                             | `{}`                                      |
| `vmagent.autoscaling.vpa.minAllowed`                        | VPA Min allowed resources for the pod                                                                                                                                                                                             | `{}`                                      |
| `vmagent.autoscaling.vpa.updatePolicy.updateMode`           | Autoscaling update policy                                                                                                                                                                                                         | `Auto`                                    |
| `vmagent.autoscaling.hpa.enabled`                           | Enable HPA for VictoriaMetrics Agent pods                                                                                                                                                                                         | `false`                                   |
| `vmagent.autoscaling.hpa.minReplicas`                       | Minimum number of replicas                                                                                                                                                                                                        | `""`                                      |
| `vmagent.autoscaling.hpa.maxReplicas`                       | Maximum number of replicas                                                                                                                                                                                                        | `""`                                      |
| `vmagent.autoscaling.hpa.targetCPU`                         | Target CPU utilization percentage                                                                                                                                                                                                 | `""`                                      |
| `vmagent.autoscaling.hpa.targetMemory`                      | Target Memory utilization percentage                                                                                                                                                                                              | `""`                                      |
| `vmagent.nodeAffinityPreset.type`                           | Node affinity preset type. Ignored if `vmagent.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                 | `""`                                      |
| `vmagent.nodeAffinityPreset.key`                            | Node label key to match. Ignored if `vmagent.affinity` is set                                                                                                                                                                     | `""`                                      |
| `vmagent.nodeAffinityPreset.values`                         | Node label values to match. Ignored if `vmagent.affinity` is set                                                                                                                                                                  | `[]`                                      |
| `vmagent.affinity`                                          | Affinity for VictoriaMetrics Agent pods assignment                                                                                                                                                                                | `{}`                                      |
| `vmagent.nodeSelector`                                      | Node labels for VictoriaMetrics Agent pods assignment                                                                                                                                                                             | `{}`                                      |
| `vmagent.tolerations`                                       | Tolerations for VictoriaMetrics Agent pods assignment                                                                                                                                                                             | `[]`                                      |
| `vmagent.updateStrategy.type`                               | VictoriaMetrics Agent statefulset strategy type                                                                                                                                                                                   | `RollingUpdate`                           |
| `vmagent.priorityClassName`                                 | VictoriaMetrics Agent pods' priorityClassName                                                                                                                                                                                     | `""`                                      |
| `vmagent.topologySpreadConstraints`                         | Topology Spread Constraints for pod assignment spread across your cluster among failure-domains. Evaluated as a template                                                                                                          | `[]`                                      |
| `vmagent.schedulerName`                                     | Name of the k8s scheduler (other than default) for VictoriaMetrics Agent pods                                                                                                                                                     | `""`                                      |
| `vmagent.terminationGracePeriodSeconds`                     | Seconds Redmine pod needs to terminate gracefully                                                                                                                                                                                 | `""`                                      |
| `vmagent.lifecycleHooks`                                    | for the VictoriaMetrics Agent container(s) to automate configuration before or after startup                                                                                                                                      | `{}`                                      |
| `vmagent.extraEnvVars`                                      | Array with extra environment variables to add to VictoriaMetrics Agent nodes                                                                                                                                                      | `[]`                                      |
| `vmagent.extraEnvVarsCM`                                    | Name of existing ConfigMap containing extra env vars for VictoriaMetrics Agent nodes                                                                                                                                              | `""`                                      |
| `vmagent.extraEnvVarsSecret`                                | Name of existing Secret containing extra env vars for VictoriaMetrics Agent nodes                                                                                                                                                 | `""`                                      |
| `vmagent.extraVolumes`                                      | Optionally specify extra list of additional volumes for the VictoriaMetrics Agent pod(s)                                                                                                                                          | `[]`                                      |
| `vmagent.extraVolumeMounts`                                 | Optionally specify extra list of additional volumeMounts for the VictoriaMetrics Agent container(s)                                                                                                                               | `[]`                                      |
| `vmagent.sidecars`                                          | Add additional sidecar containers to the VictoriaMetrics Agent pod(s)                                                                                                                                                             | `[]`                                      |
| `vmagent.initContainers`                                    | Add additional init containers to the VictoriaMetrics Agent pod(s)                                                                                                                                                                | `[]`                                      |

### VictoriaMetrics Agent RBAC Parameters

| Name                                                  | Description                                                      | Value   |
| ----------------------------------------------------- | ---------------------------------------------------------------- | ------- |
| `vmagent.rbac.create`                                 | Specifies whether RBAC resources should be created               | `true`  |
| `vmagent.rbac.rules`                                  | Custom RBAC rules to set                                         | `[]`    |
| `vmagent.serviceAccount.create`                       | Specifies whether a ServiceAccount should be created             | `true`  |
| `vmagent.serviceAccount.name`                         | The name of the ServiceAccount to use.                           | `""`    |
| `vmagent.serviceAccount.annotations`                  | Additional Service Account annotations (evaluated as a template) | `{}`    |
| `vmagent.serviceAccount.automountServiceAccountToken` | Automount service account token for the server service account   | `false` |

### VictoriaMetrics Agent Traffic Exposure Parameters

| Name                                            | Description                                                                                      | Value       |
| ----------------------------------------------- | ------------------------------------------------------------------------------------------------ | ----------- |
| `vmagent.service.type`                          | VictoriaMetrics Agent service type                                                               | `ClusterIP` |
| `vmagent.service.ports.http`                    | VictoriaMetrics Agent service http port                                                          | `8429`      |
| `vmagent.service.ports.graphite`                | VictoriaMetrics Agent service graphite port                                                      | `2003`      |
| `vmagent.service.ports.opentsdb`                | VictoriaMetrics Agent service opentsdb port                                                      | `4242`      |
| `vmagent.service.ports.influxdb`                | VictoriaMetrics Agent service influxdb port                                                      | `8089`      |
| `vmagent.service.nodePorts.http`                | Node port for HTTP                                                                               | `""`        |
| `vmagent.service.nodePorts.graphite`            | Node port for graphite                                                                           | `""`        |
| `vmagent.service.nodePorts.opentsdb`            | Node port for opentsdb                                                                           | `""`        |
| `vmagent.service.nodePorts.influxdb`            | Node port for influxdb                                                                           | `""`        |
| `vmagent.service.clusterIP`                     | VictoriaMetrics Agent service Cluster IP                                                         | `""`        |
| `vmagent.service.loadBalancerIP`                | VictoriaMetrics Agent service Load Balancer IP                                                   | `""`        |
| `vmagent.service.loadBalancerSourceRanges`      | VictoriaMetrics Agent service Load Balancer sources                                              | `[]`        |
| `vmagent.service.externalTrafficPolicy`         | VictoriaMetrics Agent service external traffic policy                                            | `Cluster`   |
| `vmagent.service.annotations`                   | Additional custom annotations for VictoriaMetrics Agent service                                  | `{}`        |
| `vmagent.service.extraPorts`                    | Extra ports to expose in VictoriaMetrics Agent service (normally used with the `sidecars` value) | `[]`        |
| `vmagent.service.sessionAffinity`               | Control where client requests go, to the same pod or round-robin                                 | `None`      |
| `vmagent.service.sessionAffinityConfig`         | Additional settings for the sessionAffinity                                                      | `{}`        |
| `vmagent.networkPolicy.enabled`                 | Specifies whether a NetworkPolicy should be created                                              | `true`      |
| `vmagent.networkPolicy.allowExternal`           | Don't require server label for connections                                                       | `true`      |
| `vmagent.networkPolicy.allowExternalEgress`     | Allow the pod to access any range of port and all destinations.                                  | `true`      |
| `vmagent.networkPolicy.extraIngress`            | Add extra ingress rules to the NetworkPolicy                                                     | `[]`        |
| `vmagent.networkPolicy.extraEgress`             | Add extra ingress rules to the NetworkPolicy                                                     | `[]`        |
| `vmagent.networkPolicy.ingressNSMatchLabels`    | Labels to match to allow traffic from other namespaces                                           | `{}`        |
| `vmagent.networkPolicy.ingressNSPodMatchLabels` | Pod labels to match to allow traffic from other namespaces                                       | `{}`        |

### VictoriaMetrics Agent Metrics Parameters

| Name                                               | Description                                                                                            | Value   |
| -------------------------------------------------- | ------------------------------------------------------------------------------------------------------ | ------- |
| `vmagent.metrics.enabled`                          | Enable the export of Prometheus metrics                                                                | `false` |
| `vmagent.metrics.annotations`                      | Additional custom annotations for the service                                                          | `{}`    |
| `vmagent.metrics.serviceMonitor.enabled`           | if `true`, creates a Prometheus Operator ServiceMonitor (also requires `metrics.enabled` to be `true`) | `false` |
| `vmagent.metrics.serviceMonitor.namespace`         | Namespace in which Prometheus is running                                                               | `""`    |
| `vmagent.metrics.serviceMonitor.annotations`       | Additional custom annotations for the ServiceMonitor                                                   | `{}`    |
| `vmagent.metrics.serviceMonitor.labels`            | Extra labels for the ServiceMonitor                                                                    | `{}`    |
| `vmagent.metrics.serviceMonitor.jobLabel`          | The name of the label on the target service to use as the job name in Prometheus                       | `""`    |
| `vmagent.metrics.serviceMonitor.honorLabels`       | honorLabels chooses the metric's labels on collisions with target labels                               | `false` |
| `vmagent.metrics.serviceMonitor.interval`          | Interval at which metrics should be scraped.                                                           | `""`    |
| `vmagent.metrics.serviceMonitor.scrapeTimeout`     | Timeout after which the scrape is ended                                                                | `""`    |
| `vmagent.metrics.serviceMonitor.metricRelabelings` | Specify additional relabeling of metrics                                                               | `[]`    |
| `vmagent.metrics.serviceMonitor.relabelings`       | Specify general relabeling                                                                             | `[]`    |
| `vmagent.metrics.serviceMonitor.selector`          | Prometheus instance selector labels                                                                    | `{}`    |

### VictoriaMetrics Alert Parameters

| Name                                                        | Description                                                                                                                                                                                                                       | Value                                     |
| ----------------------------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ----------------------------------------- |
| `vmalert.enabled`                                           | Enable VictoriaMetrics Alert                                                                                                                                                                                                      | `false`                                   |
| `vmalert.image.registry`                                    | VictoriaMetrics Alert image registry                                                                                                                                                                                              | `REGISTRY_NAME`                           |
| `vmalert.image.repository`                                  | VictoriaMetrics Alert image repository                                                                                                                                                                                            | `REPOSITORY_NAME/victoriametrics-vmalert` |
| `vmalert.image.digest`                                      | VictoriaMetrics Alert image digest in the way sha256:aa.... Please note this parameter, if set, will override the tag image tag (immutable tags are recommended)                                                                  | `""`                                      |
| `vmalert.image.pullPolicy`                                  | VictoriaMetrics Alert image pull policy                                                                                                                                                                                           | `IfNotPresent`                            |
| `vmalert.image.pullSecrets`                                 | VictoriaMetrics Alert image pull secrets                                                                                                                                                                                          | `[]`                                      |
| `vmalert.replicaCount`                                      | Number of VictoriaMetrics Alert replicas to deploy                                                                                                                                                                                | `1`                                       |
| `vmalert.containerPorts.http`                               | VictoriaMetrics Alert http container port                                                                                                                                                                                         | `8429`                                    |
| `vmalert.livenessProbe.enabled`                             | Enable livenessProbe on VictoriaMetrics Alert containers                                                                                                                                                                          | `true`                                    |
| `vmalert.livenessProbe.initialDelaySeconds`                 | Initial delay seconds for livenessProbe                                                                                                                                                                                           | `5`                                       |
| `vmalert.livenessProbe.periodSeconds`                       | Period seconds for livenessProbe                                                                                                                                                                                                  | `10`                                      |
| `vmalert.livenessProbe.timeoutSeconds`                      | Timeout seconds for livenessProbe                                                                                                                                                                                                 | `5`                                       |
| `vmalert.livenessProbe.failureThreshold`                    | Failure threshold for livenessProbe                                                                                                                                                                                               | `5`                                       |
| `vmalert.livenessProbe.successThreshold`                    | Success threshold for livenessProbe                                                                                                                                                                                               | `1`                                       |
| `vmalert.readinessProbe.enabled`                            | Enable readinessProbe on VictoriaMetrics Alert containers                                                                                                                                                                         | `true`                                    |
| `vmalert.readinessProbe.initialDelaySeconds`                | Initial delay seconds for readinessProbe                                                                                                                                                                                          | `5`                                       |
| `vmalert.readinessProbe.periodSeconds`                      | Period seconds for readinessProbe                                                                                                                                                                                                 | `10`                                      |
| `vmalert.readinessProbe.timeoutSeconds`                     | Timeout seconds for readinessProbe                                                                                                                                                                                                | `5`                                       |
| `vmalert.readinessProbe.failureThreshold`                   | Failure threshold for readinessProbe                                                                                                                                                                                              | `5`                                       |
| `vmalert.readinessProbe.successThreshold`                   | Success threshold for readinessProbe                                                                                                                                                                                              | `1`                                       |
| `vmalert.startupProbe.enabled`                              | Enable startupProbe on VictoriaMetrics Alert containers                                                                                                                                                                           | `false`                                   |
| `vmalert.startupProbe.initialDelaySeconds`                  | Initial delay seconds for startupProbe                                                                                                                                                                                            | `5`                                       |
| `vmalert.startupProbe.periodSeconds`                        | Period seconds for startupProbe                                                                                                                                                                                                   | `10`                                      |
| `vmalert.startupProbe.timeoutSeconds`                       | Timeout seconds for startupProbe                                                                                                                                                                                                  | `5`                                       |
| `vmalert.startupProbe.failureThreshold`                     | Failure threshold for startupProbe                                                                                                                                                                                                | `5`                                       |
| `vmalert.startupProbe.successThreshold`                     | Success threshold for startupProbe                                                                                                                                                                                                | `1`                                       |
| `vmalert.customLivenessProbe`                               | Custom livenessProbe that overrides the default one                                                                                                                                                                               | `{}`                                      |
| `vmalert.customReadinessProbe`                              | Custom readinessProbe that overrides the default one                                                                                                                                                                              | `{}`                                      |
| `vmalert.customStartupProbe`                                | Custom startupProbe that overrides the default one                                                                                                                                                                                | `{}`                                      |
| `vmalert.resourcesPreset`                                   | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if vmalert.resources is set (vmalert.resources is recommended for production). | `nano`                                    |
| `vmalert.resources`                                         | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                 | `{}`                                      |
| `vmalert.datasourceUrl`                                     | URL to an external datasource (uses VictoriaMetrics Insert if not set)                                                                                                                                                            | `""`                                      |
| `vmalert.notifierUrl`                                       | URL to a notifier like AlertManager (necessary when alert rules are set)                                                                                                                                                          | `""`                                      |
| `vmalert.deploymentAnnotations`                             | Annotations for VictoriaMetrics Alert Deployment                                                                                                                                                                                  | `{}`                                      |
| `vmalert.podSecurityContext.enabled`                        | Enabled VictoriaMetrics Alert pods' Security Context                                                                                                                                                                              | `true`                                    |
| `vmalert.podSecurityContext.fsGroupChangePolicy`            | Set filesystem group change policy                                                                                                                                                                                                | `Always`                                  |
| `vmalert.podSecurityContext.sysctls`                        | Set kernel settings using the sysctl interface                                                                                                                                                                                    | `[]`                                      |
| `vmalert.podSecurityContext.supplementalGroups`             | Set filesystem extra groups                                                                                                                                                                                                       | `[]`                                      |
| `vmalert.podSecurityContext.fsGroup`                        | Set VictoriaMetrics Alert pod's Security Context fsGroup                                                                                                                                                                          | `1001`                                    |
| `vmalert.containerSecurityContext.enabled`                  | Enabled VictoriaMetrics Alert containers' Security Context                                                                                                                                                                        | `true`                                    |
| `vmalert.containerSecurityContext.seLinuxOptions`           | Set SELinux options in container                                                                                                                                                                                                  | `{}`                                      |
| `vmalert.containerSecurityContext.runAsUser`                | Set containers' Security Context runAsUser                                                                                                                                                                                        | `1001`                                    |
| `vmalert.containerSecurityContext.runAsGroup`               | Set containers' Security Context runAsGroup                                                                                                                                                                                       | `1001`                                    |
| `vmalert.containerSecurityContext.runAsNonRoot`             | Set VictoriaMetrics Alert containers' Security Context runAsNonRoot                                                                                                                                                               | `true`                                    |
| `vmalert.containerSecurityContext.privileged`               | Set VictoriaMetrics Alert containers' Security Context privileged                                                                                                                                                                 | `false`                                   |
| `vmalert.containerSecurityContext.readOnlyRootFilesystem`   | Set VictoriaMetrics Alert containers' Security Context runAsNonRoot                                                                                                                                                               | `true`                                    |
| `vmalert.containerSecurityContext.allowPrivilegeEscalation` | Set VictoriaMetrics Alert container's privilege escalation                                                                                                                                                                        | `false`                                   |
| `vmalert.containerSecurityContext.capabilities.drop`        | Set VictoriaMetrics Alert container's Security Context runAsNonRoot                                                                                                                                                               | `["ALL"]`                                 |
| `vmalert.containerSecurityContext.seccompProfile.type`      | Set VictoriaMetrics Alert container's Security Context seccomp profile                                                                                                                                                            | `RuntimeDefault`                          |
| `vmalert.command`                                           | Override default container command (useful when using custom images)                                                                                                                                                              | `[]`                                      |
| `vmalert.args`                                              | Override default container args (useful when using custom images)                                                                                                                                                                 | `[]`                                      |
| `vmalert.extraArgs`                                         | Add extra arguments to the default command                                                                                                                                                                                        | `[]`                                      |
| `vmalert.automountServiceAccountToken`                      | Mount Service Account token in pod                                                                                                                                                                                                | `true`                                    |
| `vmalert.hostAliases`                                       | VictoriaMetrics Alert pods host aliases                                                                                                                                                                                           | `[]`                                      |
| `vmalert.podLabels`                                         | Extra labels for VictoriaMetrics Alert pods                                                                                                                                                                                       | `{}`                                      |
| `vmalert.podAnnotations`                                    | Annotations for VictoriaMetrics Alert pods                                                                                                                                                                                        | `{}`                                      |
| `vmalert.podAffinityPreset`                                 | Pod affinity preset. Ignored if `vmalert.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                       | `""`                                      |
| `vmalert.podAntiAffinityPreset`                             | Pod anti-affinity preset. Ignored if `vmalert.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                  | `soft`                                    |
| `vmalert.pdb.create`                                        | Enable/disable a Pod Disruption Budget creation                                                                                                                                                                                   | `true`                                    |
| `vmalert.pdb.minAvailable`                                  | Minimum number/percentage of pods that should remain scheduled                                                                                                                                                                    | `""`                                      |
| `vmalert.pdb.maxUnavailable`                                | Maximum number/percentage of pods that may be made unavailable                                                                                                                                                                    | `""`                                      |
| `vmalert.rulesConfigOverrides`                              | Overwrite or add extra rules configuration options to the chart default                                                                                                                                                           | `{}`                                      |
| `vmalert.existingRulesConfigMap`                            | The name of an existing ConfigMap with the rules configuration                                                                                                                                                                    | `""`                                      |
| `vmalert.autoscaling.vpa.enabled`                           | Enable VPA for VictoriaMetrics Alert pods                                                                                                                                                                                         | `false`                                   |
| `vmalert.autoscaling.vpa.annotations`                       | Annotations for VPA resource                                                                                                                                                                                                      | `{}`                                      |
| `vmalert.autoscaling.vpa.controlledResources`               | VPA List of resources that the vertical pod autoscaler can control. Defaults to cpu and memory                                                                                                                                    | `[]`                                      |
| `vmalert.autoscaling.vpa.maxAllowed`                        | VPA Max allowed resources for the pod                                                                                                                                                                                             | `{}`                                      |
| `vmalert.autoscaling.vpa.minAllowed`                        | VPA Min allowed resources for the pod                                                                                                                                                                                             | `{}`                                      |
| `vmalert.autoscaling.vpa.updatePolicy.updateMode`           | Autoscaling update policy                                                                                                                                                                                                         | `Auto`                                    |
| `vmalert.autoscaling.hpa.enabled`                           | Enable HPA for VictoriaMetrics Alert pods                                                                                                                                                                                         | `false`                                   |
| `vmalert.autoscaling.hpa.minReplicas`                       | Minimum number of replicas                                                                                                                                                                                                        | `""`                                      |
| `vmalert.autoscaling.hpa.maxReplicas`                       | Maximum number of replicas                                                                                                                                                                                                        | `""`                                      |
| `vmalert.autoscaling.hpa.targetCPU`                         | Target CPU utilization percentage                                                                                                                                                                                                 | `""`                                      |
| `vmalert.autoscaling.hpa.targetMemory`                      | Target Memory utilization percentage                                                                                                                                                                                              | `""`                                      |
| `vmalert.nodeAffinityPreset.type`                           | Node affinity preset type. Ignored if `vmalert.affinity` is set. Allowed values: `soft` or `hard`                                                                                                                                 | `""`                                      |
| `vmalert.nodeAffinityPreset.key`                            | Node label key to match. Ignored if `vmalert.affinity` is set                                                                                                                                                                     | `""`                                      |
| `vmalert.nodeAffinityPreset.values`                         | Node label values to match. Ignored if `vmalert.affinity` is set                                                                                                                                                                  | `[]`                                      |
| `vmalert.affinity`                                          | Affinity for VictoriaMetrics Alert pods assignment                                                                                                                                                                                | `{}`                                      |
| `vmalert.nodeSelector`                                      | Node labels for VictoriaMetrics Alert pods assignment                                                                                                                                                                             | `{}`                                      |
| `vmalert.tolerations`                                       | Tolerations for VictoriaMetrics Alert pods assignment                                                                                                                                                                             | `[]`                                      |
| `vmalert.updateStrategy.type`                               | VictoriaMetrics Alert statefulset strategy type                                                                                                                                                                                   | `RollingUpdate`                           |
| `vmalert.priorityClassName`                                 | VictoriaMetrics Alert pods' priorityClassName                                                                                                                                                                                     | `""`                                      |
| `vmalert.topologySpreadConstraints`                         | Topology Spread Constraints for pod assignment spread across your cluster among failure-domains. Evaluated as a template                                                                                                          | `[]`                                      |
| `vmalert.schedulerName`                                     | Name of the k8s scheduler (other than default) for VictoriaMetrics Alert pods                                                                                                                                                     | `""`                                      |
| `vmalert.terminationGracePeriodSeconds`                     | Seconds Redmine pod needs to terminate gracefully                                                                                                                                                                                 | `""`                                      |
| `vmalert.lifecycleHooks`                                    | for the VictoriaMetrics Alert container(s) to automate configuration before or after startup                                                                                                                                      | `{}`                                      |
| `vmalert.extraEnvVars`                                      | Array with extra environment variables to add to VictoriaMetrics Alert nodes                                                                                                                                                      | `[]`                                      |
| `vmalert.extraEnvVarsCM`                                    | Name of existing ConfigMap containing extra env vars for VictoriaMetrics Alert nodes                                                                                                                                              | `""`                                      |
| `vmalert.extraEnvVarsSecret`                                | Name of existing Secret containing extra env vars for VictoriaMetrics Alert nodes                                                                                                                                                 | `""`                                      |
| `vmalert.extraVolumes`                                      | Optionally specify extra list of additional volumes for the VictoriaMetrics Alert pod(s)                                                                                                                                          | `[]`                                      |
| `vmalert.extraVolumeMounts`                                 | Optionally specify extra list of additional volumeMounts for the VictoriaMetrics Alert container(s)                                                                                                                               | `[]`                                      |
| `vmalert.sidecars`                                          | Add additional sidecar containers to the VictoriaMetrics Alert pod(s)                                                                                                                                                             | `[]`                                      |
| `vmalert.initContainers`                                    | Add additional init containers to the VictoriaMetrics Alert pod(s)                                                                                                                                                                | `[]`                                      |
| `vmalert.serviceAccount.create`                             | Specifies whether a ServiceAccount should be created                                                                                                                                                                              | `true`                                    |
| `vmalert.serviceAccount.name`                               | The name of the ServiceAccount to use.                                                                                                                                                                                            | `""`                                      |
| `vmalert.serviceAccount.annotations`                        | Additional Service Account annotations (evaluated as a template)                                                                                                                                                                  | `{}`                                      |
| `vmalert.serviceAccount.automountServiceAccountToken`       | Automount service account token for the server service account                                                                                                                                                                    | `false`                                   |

### VictoriaMetrics Alert Traffic Exposure Parameters

| Name                                            | Description                                                                                      | Value       |
| ----------------------------------------------- | ------------------------------------------------------------------------------------------------ | ----------- |
| `vmalert.service.type`                          | VictoriaMetrics Alert service type                                                               | `ClusterIP` |
| `vmalert.service.ports.http`                    | VictoriaMetrics Alert service http port                                                          | `8429`      |
| `vmalert.service.nodePorts.http`                | Node port for HTTP                                                                               | `""`        |
| `vmalert.service.clusterIP`                     | VictoriaMetrics Alert service Cluster IP                                                         | `""`        |
| `vmalert.service.loadBalancerIP`                | VictoriaMetrics Alert service Load Balancer IP                                                   | `""`        |
| `vmalert.service.loadBalancerSourceRanges`      | VictoriaMetrics Alert service Load Balancer sources                                              | `[]`        |
| `vmalert.service.externalTrafficPolicy`         | VictoriaMetrics Alert service external traffic policy                                            | `Cluster`   |
| `vmalert.service.annotations`                   | Additional custom annotations for VictoriaMetrics Alert service                                  | `{}`        |
| `vmalert.service.extraPorts`                    | Extra ports to expose in VictoriaMetrics Alert service (normally used with the `sidecars` value) | `[]`        |
| `vmalert.service.sessionAffinity`               | Control where client requests go, to the same pod or round-robin                                 | `None`      |
| `vmalert.service.sessionAffinityConfig`         | Additional settings for the sessionAffinity                                                      | `{}`        |
| `vmalert.networkPolicy.enabled`                 | Specifies whether a NetworkPolicy should be created                                              | `true`      |
| `vmalert.networkPolicy.allowExternal`           | Don't require server label for connections                                                       | `true`      |
| `vmalert.networkPolicy.allowExternalEgress`     | Allow the pod to access any range of port and all destinations.                                  | `true`      |
| `vmalert.networkPolicy.extraIngress`            | Add extra ingress rules to the NetworkPolicy                                                     | `[]`        |
| `vmalert.networkPolicy.extraEgress`             | Add extra ingress rules to the NetworkPolicy                                                     | `[]`        |
| `vmalert.networkPolicy.ingressNSMatchLabels`    | Labels to match to allow traffic from other namespaces                                           | `{}`        |
| `vmalert.networkPolicy.ingressNSPodMatchLabels` | Pod labels to match to allow traffic from other namespaces                                       | `{}`        |

### VictoriaMetrics Alert Metrics Parameters

| Name                                               | Description                                                                                            | Value   |
| -------------------------------------------------- | ------------------------------------------------------------------------------------------------------ | ------- |
| `vmalert.metrics.enabled`                          | Enable the export of Prometheus metrics                                                                | `false` |
| `vmalert.metrics.annotations`                      | Additional custom annotations for the service                                                          | `{}`    |
| `vmalert.metrics.serviceMonitor.enabled`           | if `true`, creates a Prometheus Operator ServiceMonitor (also requires `metrics.enabled` to be `true`) | `false` |
| `vmalert.metrics.serviceMonitor.namespace`         | Namespace in which Prometheus is running                                                               | `""`    |
| `vmalert.metrics.serviceMonitor.annotations`       | Additional custom annotations for the ServiceMonitor                                                   | `{}`    |
| `vmalert.metrics.serviceMonitor.labels`            | Extra labels for the ServiceMonitor                                                                    | `{}`    |
| `vmalert.metrics.serviceMonitor.jobLabel`          | The name of the label on the target service to use as the job name in Prometheus                       | `""`    |
| `vmalert.metrics.serviceMonitor.honorLabels`       | honorLabels chooses the metric's labels on collisions with target labels                               | `false` |
| `vmalert.metrics.serviceMonitor.interval`          | Interval at which metrics should be rulesd.                                                            | `""`    |
| `vmalert.metrics.serviceMonitor.scrapeTimeout`     | Timeout after which the scrape is ended                                                                | `""`    |
| `vmalert.metrics.serviceMonitor.metricRelabelings` | Specify additional relabeling of metrics                                                               | `[]`    |
| `vmalert.metrics.serviceMonitor.relabelings`       | Specify general relabeling                                                                             | `[]`    |
| `vmalert.metrics.serviceMonitor.selector`          | Prometheus instance selector labels                                                                    | `{}`    |

### Default Init Containers Parameters

| Name                                                                              | Description                                                                                                                                                                                                                                           | Value                      |
| --------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | -------------------------- |
| `defaultInitContainers.volumePermissions.enabled`                                 | Enable init container that changes the owner/group of the PV mount point to `runAsUser:fsGroup`                                                                                                                                                       | `false`                    |
| `defaultInitContainers.volumePermissions.image.registry`                          | OS Shell + Utility image registry                                                                                                                                                                                                                     | `REGISTRY_NAME`            |
| `defaultInitContainers.volumePermissions.image.repository`                        | OS Shell + Utility image repository                                                                                                                                                                                                                   | `REPOSITORY_NAME/os-shell` |
| `defaultInitContainers.volumePermissions.image.digest`                            | OS Shell + Utility image digest in the way sha256:aa.... Please note this parameter, if set, will override the tag                                                                                                                                    | `""`                       |
| `defaultInitContainers.volumePermissions.image.pullPolicy`                        | OS Shell + Utility image pull policy                                                                                                                                                                                                                  | `IfNotPresent`             |
| `defaultInitContainers.volumePermissions.image.pullSecrets`                       | OS Shell + Utility image pull secrets                                                                                                                                                                                                                 | `[]`                       |
| `defaultInitContainers.volumePermissions.resourcesPreset`                         | Set container resources according to one common preset (allowed values: none, nano, micro, small, medium, large, xlarge, 2xlarge). This is ignored if volumePermissions.resources is set (volumePermissions.resources is recommended for production). | `nano`                     |
| `defaultInitContainers.volumePermissions.resources`                               | Set container requests and limits for different resources like CPU or memory (essential for production workloads)                                                                                                                                     | `{}`                       |
| `defaultInitContainers.volumePermissions.containerSecurityContext.enabled`        | Enable securityContext in the init container                                                                                                                                                                                                          | `true`                     |
| `defaultInitContainers.volumePermissions.containerSecurityContext.seLinuxOptions` | Set SELinux options in container                                                                                                                                                                                                                      | `{}`                       |
| `defaultInitContainers.volumePermissions.containerSecurityContext.runAsUser`      | User ID for the init container                                                                                                                                                                                                                        | `0`                        |

Specify each parameter using the `--set key=value[,key=value]` argument to `helm install`. For example,

```console
helm install my-release --set vmagent.enableListeners.influxdb=true oci://REGISTRY_NAME/REPOSITORY_NAME/victoriametrics
```

> Note: You need to substitute the placeholders `REGISTRY_NAME` and `REPOSITORY_NAME` with a reference to your Helm chart registry and repository. For example, in the case of Bitnami, you need to use `REGISTRY_NAME=registry-1.docker.io` and `REPOSITORY_NAME=bitnamicharts`.

The above command install VictoriaMetrics chart with the InfluxDB listener enabled in the `vmagent` component.

Alternatively, a YAML file that specifies the values for the parameters can be provided while installing the chart. For example,

```console
helm install my-release -f values.yaml oci://REGISTRY_NAME/REPOSITORY_NAME/victoriametrics
```

> Note: You need to substitute the placeholders `REGISTRY_NAME` and `REPOSITORY_NAME` with a reference to your Helm chart registry and repository. For example, in the case of Bitnami, you need to use `REGISTRY_NAME=registry-1.docker.io` and `REPOSITORY_NAME=bitnamicharts`.
> **Tip**: You can use the default [values.yaml](https://github.com/bitnami/charts/tree/main/bitnami/victoriametrics/values.yaml)

## Troubleshooting

Find more information about how to deal with common errors related to Bitnami's Helm charts in [this troubleshooting guide](https://docs.bitnami.com/general/how-to/troubleshoot-helm-chart-issues).

## License

Copyright &copy; 2025 Broadcom. The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

<http://www.apache.org/licenses/LICENSE-2.0>

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.